#[repr(C)]pub struct AliasedStruct {
pub value: AnotherEmptyStruct,
}Fields
value: AnotherEmptyStructTrait Implementations
Sourceimpl Clone for AliasedStruct
impl Clone for AliasedStruct
Sourcefn clone(&self) -> AliasedStruct
fn clone(&self) -> AliasedStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<AliasedStruct> for AliasedStruct
impl CompatFrom<AliasedStruct> for AliasedStruct
Sourcefn compat_from(value: AliasedStruct) -> Self
fn compat_from(value: AliasedStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<AliasedStruct> for AliasedStruct
impl CompatFrom<AliasedStruct> for AliasedStruct
Sourcefn compat_from(value: AliasedStruct) -> Self
fn compat_from(value: AliasedStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for AliasedStruct
impl Debug for AliasedStruct
Sourceimpl<'a, ___E> Encode<AliasedStruct, ___E> for &'a AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedStruct, ___E> for &'a AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedStruct, ___E> for AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedStruct, ___E> for AliasedStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, AliasedStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, AliasedStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AliasedStruct>, ___E> for &'a AliasedStruct
impl<'a, ___E> EncodeOption<Box<'static, AliasedStruct>, ___E> for &'a AliasedStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, AliasedStruct>, ___E> for AliasedStruct
impl<___E> EncodeOption<Box<'static, AliasedStruct>, ___E> for AliasedStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<AliasedStruct> for AliasedStruct
impl FromWire<AliasedStruct> for AliasedStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<AliasedStruct, Self>
Sourcefn from_wire(wire: AliasedStruct) -> Self
fn from_wire(wire: AliasedStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedStruct> for AliasedStruct
impl FromWireRef<AliasedStruct> for AliasedStruct
Sourcefn from_wire_ref(wire: &AliasedStruct) -> Self
fn from_wire_ref(wire: &AliasedStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for AliasedStruct
impl Hash for AliasedStruct
Sourceimpl Ord for AliasedStruct
impl Ord for AliasedStruct
Sourcefn cmp(&self, other: &AliasedStruct) -> Ordering
fn cmp(&self, other: &AliasedStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AliasedStruct
impl PartialEq for AliasedStruct
Sourceimpl PartialOrd for AliasedStruct
impl PartialOrd for AliasedStruct
impl Copy for AliasedStruct
impl Eq for AliasedStruct
impl StructuralPartialEq for AliasedStruct