#[repr(C)]pub struct AliasedUint64 {
pub value: u64,
}Fields
value: u64Trait Implementations
Sourceimpl Clone for AliasedUint64
impl Clone for AliasedUint64
Sourcefn clone(&self) -> AliasedUint64
fn clone(&self) -> AliasedUint64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<AliasedUint64> for AliasedUint64
impl CompatFrom<AliasedUint64> for AliasedUint64
Sourcefn compat_from(value: AliasedUint64) -> Self
fn compat_from(value: AliasedUint64) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<AliasedUint64> for AliasedUint64
impl CompatFrom<AliasedUint64> for AliasedUint64
Sourcefn compat_from(value: AliasedUint64) -> Self
fn compat_from(value: AliasedUint64) -> Self
Converts
value into a value of this type.Sourceimpl Debug for AliasedUint64
impl Debug for AliasedUint64
Sourceimpl<'a, ___E> Encode<AliasedUint64, ___E> for &'a AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AliasedUint64, ___E> for &'a AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedUint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedUint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AliasedUint64, ___E> for AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AliasedUint64, ___E> for AliasedUint64where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, AliasedUint64>
const COPY_OPTIMIZATION: CopyOptimization<Self, AliasedUint64>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AliasedUint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AliasedUint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, AliasedUint64>, ___E> for &'a AliasedUint64
impl<'a, ___E> EncodeOption<Box<'static, AliasedUint64>, ___E> for &'a AliasedUint64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedUint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedUint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, AliasedUint64>, ___E> for AliasedUint64
impl<___E> EncodeOption<Box<'static, AliasedUint64>, ___E> for AliasedUint64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, AliasedUint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, AliasedUint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<AliasedUint64> for AliasedUint64
impl FromWire<AliasedUint64> for AliasedUint64
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, Self>
const COPY_OPTIMIZATION: CopyOptimization<AliasedUint64, Self>
Sourcefn from_wire(wire: AliasedUint64) -> Self
fn from_wire(wire: AliasedUint64) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<AliasedUint64> for AliasedUint64
impl FromWireRef<AliasedUint64> for AliasedUint64
Sourcefn from_wire_ref(wire: &AliasedUint64) -> Self
fn from_wire_ref(wire: &AliasedUint64) -> Self
Converts the given reference to this type.
Sourceimpl Hash for AliasedUint64
impl Hash for AliasedUint64
Sourceimpl Ord for AliasedUint64
impl Ord for AliasedUint64
Sourcefn cmp(&self, other: &AliasedUint64) -> Ordering
fn cmp(&self, other: &AliasedUint64) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for AliasedUint64
impl PartialEq for AliasedUint64
Sourceimpl PartialOrd for AliasedUint64
impl PartialOrd for AliasedUint64
impl Copy for AliasedUint64
impl Eq for AliasedUint64
impl StructuralPartialEq for AliasedUint64