pub struct ArrayStruct {
pub unions: [StringUnion; 3],
pub optional_unions: [Option<Box<StringUnion>>; 3],
}Fields
unions: [StringUnion; 3]optional_unions: [Option<Box<StringUnion>>; 3]Trait Implementations
Sourceimpl Clone for ArrayStruct
impl Clone for ArrayStruct
Sourcefn clone(&self) -> ArrayStruct
fn clone(&self) -> ArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ArrayStruct> for ArrayStruct
impl CompatFrom<ArrayStruct> for ArrayStruct
Sourcefn compat_from(value: ArrayStruct) -> Self
fn compat_from(value: ArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayStruct> for ArrayStruct
impl CompatFrom<ArrayStruct> for ArrayStruct
Sourcefn compat_from(value: ArrayStruct) -> Self
fn compat_from(value: ArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for ArrayStruct
impl Debug for ArrayStruct
Sourceimpl<'a, ___E> Encode<ArrayStruct<'static>, ___E> for &'a ArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ArrayStruct<'static>, ___E> for &'a ArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ArrayStruct<'static>, ___E> for ArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ArrayStruct<'static>, ___E> for ArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArrayStruct<'static>>, ___E> for &'a ArrayStruct
impl<'a, ___E> EncodeOption<Box<'static, ArrayStruct<'static>>, ___E> for &'a ArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ArrayStruct<'static>>, ___E> for ArrayStruct
impl<___E> EncodeOption<Box<'static, ArrayStruct<'static>>, ___E> for ArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ArrayStruct<'de>> for ArrayStruct
impl<'de> FromWire<ArrayStruct<'de>> for ArrayStruct
Sourcefn from_wire(wire: ArrayStruct<'de>) -> Self
fn from_wire(wire: ArrayStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ArrayStruct<'de>> for ArrayStruct
impl<'de> FromWireRef<ArrayStruct<'de>> for ArrayStruct
Sourcefn from_wire_ref(wire: &ArrayStruct<'de>) -> Self
fn from_wire_ref(wire: &ArrayStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ArrayStruct
impl Hash for ArrayStruct
Sourceimpl Ord for ArrayStruct
impl Ord for ArrayStruct
Sourcefn cmp(&self, other: &ArrayStruct) -> Ordering
fn cmp(&self, other: &ArrayStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArrayStruct
impl PartialEq for ArrayStruct
Sourceimpl PartialOrd for ArrayStruct
impl PartialOrd for ArrayStruct
impl Eq for ArrayStruct
impl StructuralPartialEq for ArrayStruct