pub struct ArrayWithInternalPadding {
pub v: [OneLayerStructWithPaddingAlign4; 2],
}Fields
v: [OneLayerStructWithPaddingAlign4; 2]Trait Implementations
Sourceimpl Clone for ArrayWithInternalPadding
impl Clone for ArrayWithInternalPadding
Sourcefn clone(&self) -> ArrayWithInternalPadding
fn clone(&self) -> ArrayWithInternalPadding
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl CompatFrom<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn compat_from(value: ArrayWithInternalPadding) -> Self
fn compat_from(value: ArrayWithInternalPadding) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl CompatFrom<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn compat_from(value: ArrayWithInternalPadding) -> Self
fn compat_from(value: ArrayWithInternalPadding) -> Self
Converts
value into a value of this type.Sourceimpl Debug for ArrayWithInternalPadding
impl Debug for ArrayWithInternalPadding
Sourceimpl<'a, ___E> Encode<ArrayWithInternalPadding, ___E> for &'a ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ArrayWithInternalPadding, ___E> for &'a ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayWithInternalPadding>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayWithInternalPadding>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ArrayWithInternalPadding, ___E> for ArrayWithInternalPaddingwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ArrayWithInternalPadding>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ArrayWithInternalPadding>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ArrayWithInternalPadding>, ___E> for &'a ArrayWithInternalPadding
impl<'a, ___E> EncodeOption<Box<'static, ArrayWithInternalPadding>, ___E> for &'a ArrayWithInternalPadding
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayWithInternalPadding>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayWithInternalPadding>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ArrayWithInternalPadding>, ___E> for ArrayWithInternalPadding
impl<___E> EncodeOption<Box<'static, ArrayWithInternalPadding>, ___E> for ArrayWithInternalPadding
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ArrayWithInternalPadding>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ArrayWithInternalPadding>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl FromWire<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn from_wire(wire: ArrayWithInternalPadding) -> Self
fn from_wire(wire: ArrayWithInternalPadding) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<ArrayWithInternalPadding> for ArrayWithInternalPadding
impl FromWireRef<ArrayWithInternalPadding> for ArrayWithInternalPadding
Sourcefn from_wire_ref(wire: &ArrayWithInternalPadding) -> Self
fn from_wire_ref(wire: &ArrayWithInternalPadding) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ArrayWithInternalPadding
impl Hash for ArrayWithInternalPadding
Sourceimpl Ord for ArrayWithInternalPadding
impl Ord for ArrayWithInternalPadding
Sourcefn cmp(&self, other: &ArrayWithInternalPadding) -> Ordering
fn cmp(&self, other: &ArrayWithInternalPadding) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ArrayWithInternalPadding
impl PartialEq for ArrayWithInternalPadding
Sourceimpl PartialOrd for ArrayWithInternalPadding
impl PartialOrd for ArrayWithInternalPadding
impl Copy for ArrayWithInternalPadding
impl Eq for ArrayWithInternalPadding
impl StructuralPartialEq for ArrayWithInternalPadding