#[repr(C)]pub struct EmptyBitsStruct {
pub b: EmptyBits,
}Fields
b: EmptyBitsTrait Implementations
Sourceimpl Clone for EmptyBitsStruct
impl Clone for EmptyBitsStruct
Sourcefn clone(&self) -> EmptyBitsStruct
fn clone(&self) -> EmptyBitsStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EmptyBitsStruct> for EmptyBitsStruct
impl CompatFrom<EmptyBitsStruct> for EmptyBitsStruct
Sourcefn compat_from(value: EmptyBitsStruct) -> Self
fn compat_from(value: EmptyBitsStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EmptyBitsStruct> for EmptyBitsStruct
impl CompatFrom<EmptyBitsStruct> for EmptyBitsStruct
Sourcefn compat_from(value: EmptyBitsStruct) -> Self
fn compat_from(value: EmptyBitsStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for EmptyBitsStruct
impl Debug for EmptyBitsStruct
Sourceimpl<'a, ___E> Encode<EmptyBitsStruct, ___E> for &'a EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmptyBitsStruct, ___E> for &'a EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyBitsStruct, ___E> for EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmptyBitsStruct, ___E> for EmptyBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, EmptyBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, EmptyBitsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EmptyBitsStruct>, ___E> for &'a EmptyBitsStruct
impl<'a, ___E> EncodeOption<Box<'static, EmptyBitsStruct>, ___E> for &'a EmptyBitsStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyBitsStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyBitsStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EmptyBitsStruct>, ___E> for EmptyBitsStruct
impl<___E> EncodeOption<Box<'static, EmptyBitsStruct>, ___E> for EmptyBitsStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyBitsStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyBitsStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EmptyBitsStruct> for EmptyBitsStruct
impl FromWire<EmptyBitsStruct> for EmptyBitsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<EmptyBitsStruct, Self>
Sourcefn from_wire(wire: EmptyBitsStruct) -> Self
fn from_wire(wire: EmptyBitsStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmptyBitsStruct> for EmptyBitsStruct
impl FromWireRef<EmptyBitsStruct> for EmptyBitsStruct
Sourcefn from_wire_ref(wire: &EmptyBitsStruct) -> Self
fn from_wire_ref(wire: &EmptyBitsStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EmptyBitsStruct
impl Hash for EmptyBitsStruct
Sourceimpl Ord for EmptyBitsStruct
impl Ord for EmptyBitsStruct
Sourcefn cmp(&self, other: &EmptyBitsStruct) -> Ordering
fn cmp(&self, other: &EmptyBitsStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EmptyBitsStruct
impl PartialEq for EmptyBitsStruct
Sourceimpl PartialOrd for EmptyBitsStruct
impl PartialOrd for EmptyBitsStruct
impl Copy for EmptyBitsStruct
impl Eq for EmptyBitsStruct
impl StructuralPartialEq for EmptyBitsStruct