pub struct EmptyStructSandwich {
pub before: String,
pub es: EmptyStruct,
pub after: String,
}Fields
before: Stringes: EmptyStructafter: StringTrait Implementations
Sourceimpl Clone for EmptyStructSandwich
impl Clone for EmptyStructSandwich
Sourcefn clone(&self) -> EmptyStructSandwich
fn clone(&self) -> EmptyStructSandwich
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EmptyStructSandwich> for EmptyStructSandwich
impl CompatFrom<EmptyStructSandwich> for EmptyStructSandwich
Sourcefn compat_from(value: EmptyStructSandwich) -> Self
fn compat_from(value: EmptyStructSandwich) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EmptyStructSandwich> for EmptyStructSandwich
impl CompatFrom<EmptyStructSandwich> for EmptyStructSandwich
Sourcefn compat_from(value: EmptyStructSandwich) -> Self
fn compat_from(value: EmptyStructSandwich) -> Self
Converts
value into a value of this type.Sourceimpl Debug for EmptyStructSandwich
impl Debug for EmptyStructSandwich
Sourceimpl<'a, ___E> Encode<EmptyStructSandwich<'static>, ___E> for &'a EmptyStructSandwichwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<EmptyStructSandwich<'static>, ___E> for &'a EmptyStructSandwichwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructSandwich<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructSandwich<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyStructSandwich<'static>, ___E> for EmptyStructSandwichwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<EmptyStructSandwich<'static>, ___E> for EmptyStructSandwichwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructSandwich<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructSandwich<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EmptyStructSandwich<'static>>, ___E> for &'a EmptyStructSandwich
impl<'a, ___E> EncodeOption<Box<'static, EmptyStructSandwich<'static>>, ___E> for &'a EmptyStructSandwich
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructSandwich<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructSandwich<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EmptyStructSandwich<'static>>, ___E> for EmptyStructSandwich
impl<___E> EncodeOption<Box<'static, EmptyStructSandwich<'static>>, ___E> for EmptyStructSandwich
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructSandwich<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructSandwich<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EmptyStructSandwich<'de>> for EmptyStructSandwich
impl<'de> FromWire<EmptyStructSandwich<'de>> for EmptyStructSandwich
Sourcefn from_wire(wire: EmptyStructSandwich<'de>) -> Self
fn from_wire(wire: EmptyStructSandwich<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<EmptyStructSandwich<'de>> for EmptyStructSandwich
impl<'de> FromWireRef<EmptyStructSandwich<'de>> for EmptyStructSandwich
Sourcefn from_wire_ref(wire: &EmptyStructSandwich<'de>) -> Self
fn from_wire_ref(wire: &EmptyStructSandwich<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EmptyStructSandwich
impl Hash for EmptyStructSandwich
Sourceimpl Ord for EmptyStructSandwich
impl Ord for EmptyStructSandwich
Sourcefn cmp(&self, other: &EmptyStructSandwich) -> Ordering
fn cmp(&self, other: &EmptyStructSandwich) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EmptyStructSandwich
impl PartialEq for EmptyStructSandwich
Sourceimpl PartialOrd for EmptyStructSandwich
impl PartialOrd for EmptyStructSandwich
impl Eq for EmptyStructSandwich
impl StructuralPartialEq for EmptyStructSandwich