pub struct EmptyStructsInVectorInStruct {
pub v: Vec<EmptyStruct>,
}Fields
v: Vec<EmptyStruct>Trait Implementations
Sourceimpl Clone for EmptyStructsInVectorInStruct
impl Clone for EmptyStructsInVectorInStruct
Sourcefn clone(&self) -> EmptyStructsInVectorInStruct
fn clone(&self) -> EmptyStructsInVectorInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<EmptyStructsInVectorInStruct> for EmptyStructsInVectorInStruct
impl CompatFrom<EmptyStructsInVectorInStruct> for EmptyStructsInVectorInStruct
Sourcefn compat_from(value: EmptyStructsInVectorInStruct) -> Self
fn compat_from(value: EmptyStructsInVectorInStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<EmptyStructsInVectorInStruct> for EmptyStructsInVectorInStruct
impl CompatFrom<EmptyStructsInVectorInStruct> for EmptyStructsInVectorInStruct
Sourcefn compat_from(value: EmptyStructsInVectorInStruct) -> Self
fn compat_from(value: EmptyStructsInVectorInStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for EmptyStructsInVectorInStruct
impl Debug for EmptyStructsInVectorInStruct
Sourceimpl<'a, ___E> Encode<EmptyStructsInVectorInStruct<'static>, ___E> for &'a EmptyStructsInVectorInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<EmptyStructsInVectorInStruct<'static>, ___E> for &'a EmptyStructsInVectorInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInVectorInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInVectorInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyStructsInVectorInStruct<'static>, ___E> for EmptyStructsInVectorInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<EmptyStructsInVectorInStruct<'static>, ___E> for EmptyStructsInVectorInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructsInVectorInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructsInVectorInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EmptyStructsInVectorInStruct<'static>>, ___E> for &'a EmptyStructsInVectorInStructwhere
___E: Encoder + ?Sized,
&'a EmptyStructsInVectorInStruct: Encode<EmptyStructsInVectorInStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, EmptyStructsInVectorInStruct<'static>>, ___E> for &'a EmptyStructsInVectorInStructwhere
___E: Encoder + ?Sized,
&'a EmptyStructsInVectorInStruct: Encode<EmptyStructsInVectorInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructsInVectorInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructsInVectorInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EmptyStructsInVectorInStruct<'static>>, ___E> for EmptyStructsInVectorInStructwhere
___E: Encoder + ?Sized,
EmptyStructsInVectorInStruct: Encode<EmptyStructsInVectorInStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, EmptyStructsInVectorInStruct<'static>>, ___E> for EmptyStructsInVectorInStructwhere
___E: Encoder + ?Sized,
EmptyStructsInVectorInStruct: Encode<EmptyStructsInVectorInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmptyStructsInVectorInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmptyStructsInVectorInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<EmptyStructsInVectorInStruct<'de>> for EmptyStructsInVectorInStruct
impl<'de> FromWire<EmptyStructsInVectorInStruct<'de>> for EmptyStructsInVectorInStruct
Sourcefn from_wire(wire: EmptyStructsInVectorInStruct<'de>) -> Self
fn from_wire(wire: EmptyStructsInVectorInStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<EmptyStructsInVectorInStruct<'de>> for EmptyStructsInVectorInStruct
impl<'de> FromWireRef<EmptyStructsInVectorInStruct<'de>> for EmptyStructsInVectorInStruct
Sourcefn from_wire_ref(wire: &EmptyStructsInVectorInStruct<'de>) -> Self
fn from_wire_ref(wire: &EmptyStructsInVectorInStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for EmptyStructsInVectorInStruct
impl Hash for EmptyStructsInVectorInStruct
Sourceimpl Ord for EmptyStructsInVectorInStruct
impl Ord for EmptyStructsInVectorInStruct
Sourcefn cmp(&self, other: &EmptyStructsInVectorInStruct) -> Ordering
fn cmp(&self, other: &EmptyStructsInVectorInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EmptyStructsInVectorInStruct
impl PartialEq for EmptyStructsInVectorInStruct
Sourcefn eq(&self, other: &EmptyStructsInVectorInStruct) -> bool
fn eq(&self, other: &EmptyStructsInVectorInStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for EmptyStructsInVectorInStruct
impl PartialOrd for EmptyStructsInVectorInStruct
impl Eq for EmptyStructsInVectorInStruct
impl StructuralPartialEq for EmptyStructsInVectorInStruct