pub struct FileGetAttrResponse {
pub s: i32,
pub attributes: NodeAttributes,
}Fields
s: i32attributes: NodeAttributesTrait Implementations
Sourceimpl Clone for FileGetAttrResponse
impl Clone for FileGetAttrResponse
Sourcefn clone(&self) -> FileGetAttrResponse
fn clone(&self) -> FileGetAttrResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<FileGetAttrResponse> for FileGetAttrResponse
impl CompatFrom<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn compat_from(value: FileGetAttrResponse) -> Self
fn compat_from(value: FileGetAttrResponse) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<FileGetAttrResponse> for FileGetAttrResponse
impl CompatFrom<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn compat_from(value: FileGetAttrResponse) -> Self
fn compat_from(value: FileGetAttrResponse) -> Self
Converts
value into a value of this type.Sourceimpl Debug for FileGetAttrResponse
impl Debug for FileGetAttrResponse
Sourceimpl<'a, ___E> Encode<FileGetAttrResponse, ___E> for &'a FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FileGetAttrResponse, ___E> for &'a FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileGetAttrResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileGetAttrResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FileGetAttrResponse, ___E> for FileGetAttrResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FileGetAttrResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FileGetAttrResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FileGetAttrResponse>, ___E> for &'a FileGetAttrResponse
impl<'a, ___E> EncodeOption<Box<'static, FileGetAttrResponse>, ___E> for &'a FileGetAttrResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FileGetAttrResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FileGetAttrResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, FileGetAttrResponse>, ___E> for FileGetAttrResponse
impl<___E> EncodeOption<Box<'static, FileGetAttrResponse>, ___E> for FileGetAttrResponse
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FileGetAttrResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FileGetAttrResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<FileGetAttrResponse> for FileGetAttrResponse
impl FromWire<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn from_wire(wire: FileGetAttrResponse) -> Self
fn from_wire(wire: FileGetAttrResponse) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FileGetAttrResponse> for FileGetAttrResponse
impl FromWireRef<FileGetAttrResponse> for FileGetAttrResponse
Sourcefn from_wire_ref(wire: &FileGetAttrResponse) -> Self
fn from_wire_ref(wire: &FileGetAttrResponse) -> Self
Converts the given reference to this type.
Sourceimpl Hash for FileGetAttrResponse
impl Hash for FileGetAttrResponse
Sourceimpl Ord for FileGetAttrResponse
impl Ord for FileGetAttrResponse
Sourcefn cmp(&self, other: &FileGetAttrResponse) -> Ordering
fn cmp(&self, other: &FileGetAttrResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FileGetAttrResponse
impl PartialEq for FileGetAttrResponse
Sourceimpl PartialOrd for FileGetAttrResponse
impl PartialOrd for FileGetAttrResponse
impl Copy for FileGetAttrResponse
impl Eq for FileGetAttrResponse
impl StructuralPartialEq for FileGetAttrResponse