pub struct FiveByte {
pub elem1: u32,
pub elem2: u8,
}Fields
elem1: u32elem2: u8Trait Implementations
Sourceimpl CompatFrom<FiveByte> for FiveByte
impl CompatFrom<FiveByte> for FiveByte
Sourcefn compat_from(value: FiveByte) -> Self
fn compat_from(value: FiveByte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<FiveByte> for FiveByte
impl CompatFrom<FiveByte> for FiveByte
Sourcefn compat_from(value: FiveByte) -> Self
fn compat_from(value: FiveByte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<FiveByte, ___E> for &'a FiveBytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FiveByte, ___E> for &'a FiveBytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<FiveByte, ___E> for FiveBytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FiveByte, ___E> for FiveBytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<'a, ___E> EncodeOption<Box<'static, FiveByte>, ___E> for &'a FiveByte
impl<'a, ___E> EncodeOption<Box<'static, FiveByte>, ___E> for &'a FiveByte
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, FiveByte>, ___E> for FiveByte
impl<___E> EncodeOption<Box<'static, FiveByte>, ___E> for FiveByte
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, FiveByte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, FiveByte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<FiveByte> for FiveByte
impl FromWireRef<FiveByte> for FiveByte
Sourcefn from_wire_ref(wire: &FiveByte) -> Self
fn from_wire_ref(wire: &FiveByte) -> Self
Converts the given reference to this type.
Sourceimpl Ord for FiveByte
impl Ord for FiveByte
Sourceimpl PartialOrd for FiveByte
impl PartialOrd for FiveByte
impl Copy for FiveByte
impl Eq for FiveByte
impl StructuralPartialEq for FiveByte