#[repr(C)]pub struct GoldenBoolStruct {
pub v: bool,
}Fields
v: boolTrait Implementations
Sourceimpl Clone for GoldenBoolStruct
impl Clone for GoldenBoolStruct
Sourcefn clone(&self) -> GoldenBoolStruct
fn clone(&self) -> GoldenBoolStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenBoolStruct> for GoldenBoolStruct
impl CompatFrom<GoldenBoolStruct> for GoldenBoolStruct
Sourcefn compat_from(value: GoldenBoolStruct) -> Self
fn compat_from(value: GoldenBoolStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenBoolStruct> for GoldenBoolStruct
impl CompatFrom<GoldenBoolStruct> for GoldenBoolStruct
Sourcefn compat_from(value: GoldenBoolStruct) -> Self
fn compat_from(value: GoldenBoolStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenBoolStruct
impl Debug for GoldenBoolStruct
Sourceimpl<'a, ___E> Encode<GoldenBoolStruct, ___E> for &'a GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenBoolStruct, ___E> for &'a GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBoolStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBoolStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenBoolStruct, ___E> for GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenBoolStruct, ___E> for GoldenBoolStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenBoolStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenBoolStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBoolStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBoolStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenBoolStruct>, ___E> for &'a GoldenBoolStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenBoolStruct>, ___E> for &'a GoldenBoolStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenBoolStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenBoolStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenBoolStruct>, ___E> for GoldenBoolStruct
impl<___E> EncodeOption<Box<'static, GoldenBoolStruct>, ___E> for GoldenBoolStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenBoolStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenBoolStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenBoolStruct> for GoldenBoolStruct
impl FromWire<GoldenBoolStruct> for GoldenBoolStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBoolStruct, Self>
Sourcefn from_wire(wire: GoldenBoolStruct) -> Self
fn from_wire(wire: GoldenBoolStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenBoolStruct> for GoldenBoolStruct
impl FromWireRef<GoldenBoolStruct> for GoldenBoolStruct
Sourcefn from_wire_ref(wire: &GoldenBoolStruct) -> Self
fn from_wire_ref(wire: &GoldenBoolStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenBoolStruct
impl Hash for GoldenBoolStruct
Sourceimpl Ord for GoldenBoolStruct
impl Ord for GoldenBoolStruct
Sourcefn cmp(&self, other: &GoldenBoolStruct) -> Ordering
fn cmp(&self, other: &GoldenBoolStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenBoolStruct
impl PartialEq for GoldenBoolStruct
Sourceimpl PartialOrd for GoldenBoolStruct
impl PartialOrd for GoldenBoolStruct
impl Copy for GoldenBoolStruct
impl Eq for GoldenBoolStruct
impl StructuralPartialEq for GoldenBoolStruct