#[repr(C)]pub struct GoldenByteArrayStruct {
pub v: [u8; 4],
}Fields
v: [u8; 4]Trait Implementations
Sourceimpl Clone for GoldenByteArrayStruct
impl Clone for GoldenByteArrayStruct
Sourcefn clone(&self) -> GoldenByteArrayStruct
fn clone(&self) -> GoldenByteArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl CompatFrom<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourcefn compat_from(value: GoldenByteArrayStruct) -> Self
fn compat_from(value: GoldenByteArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl CompatFrom<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourcefn compat_from(value: GoldenByteArrayStruct) -> Self
fn compat_from(value: GoldenByteArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenByteArrayStruct
impl Debug for GoldenByteArrayStruct
Sourceimpl<'a, ___E> Encode<GoldenByteArrayStruct, ___E> for &'a GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenByteArrayStruct, ___E> for &'a GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenByteArrayStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenByteArrayStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenByteArrayStruct>, ___E> for &'a GoldenByteArrayStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenByteArrayStruct>, ___E> for &'a GoldenByteArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenByteArrayStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenByteArrayStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenByteArrayStruct>, ___E> for GoldenByteArrayStruct
impl<___E> EncodeOption<Box<'static, GoldenByteArrayStruct>, ___E> for GoldenByteArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenByteArrayStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenByteArrayStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl FromWire<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenByteArrayStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenByteArrayStruct, Self>
Sourcefn from_wire(wire: GoldenByteArrayStruct) -> Self
fn from_wire(wire: GoldenByteArrayStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl FromWireRef<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourcefn from_wire_ref(wire: &GoldenByteArrayStruct) -> Self
fn from_wire_ref(wire: &GoldenByteArrayStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenByteArrayStruct
impl Hash for GoldenByteArrayStruct
Sourceimpl Ord for GoldenByteArrayStruct
impl Ord for GoldenByteArrayStruct
Sourcefn cmp(&self, other: &GoldenByteArrayStruct) -> Ordering
fn cmp(&self, other: &GoldenByteArrayStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenByteArrayStruct
impl PartialEq for GoldenByteArrayStruct
Sourceimpl PartialOrd for GoldenByteArrayStruct
impl PartialOrd for GoldenByteArrayStruct
impl Copy for GoldenByteArrayStruct
impl Eq for GoldenByteArrayStruct
impl StructuralPartialEq for GoldenByteArrayStruct