pub struct GoldenByteVectorStruct {
pub v: Vec<u8>,
}Fields
v: Vec<u8>Trait Implementations
Sourceimpl Clone for GoldenByteVectorStruct
impl Clone for GoldenByteVectorStruct
Sourcefn clone(&self) -> GoldenByteVectorStruct
fn clone(&self) -> GoldenByteVectorStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenByteVectorStruct> for GoldenByteVectorStruct
impl CompatFrom<GoldenByteVectorStruct> for GoldenByteVectorStruct
Sourcefn compat_from(value: GoldenByteVectorStruct) -> Self
fn compat_from(value: GoldenByteVectorStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenByteVectorStruct> for GoldenByteVectorStruct
impl CompatFrom<GoldenByteVectorStruct> for GoldenByteVectorStruct
Sourcefn compat_from(value: GoldenByteVectorStruct) -> Self
fn compat_from(value: GoldenByteVectorStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenByteVectorStruct
impl Debug for GoldenByteVectorStruct
Sourceimpl<'a, ___E> Encode<GoldenByteVectorStruct<'static>, ___E> for &'a GoldenByteVectorStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<GoldenByteVectorStruct<'static>, ___E> for &'a GoldenByteVectorStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenByteVectorStruct<'static>, ___E> for GoldenByteVectorStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<GoldenByteVectorStruct<'static>, ___E> for GoldenByteVectorStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteVectorStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteVectorStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenByteVectorStruct<'static>>, ___E> for &'a GoldenByteVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenByteVectorStruct: Encode<GoldenByteVectorStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenByteVectorStruct<'static>>, ___E> for &'a GoldenByteVectorStructwhere
___E: Encoder + ?Sized,
&'a GoldenByteVectorStruct: Encode<GoldenByteVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenByteVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenByteVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenByteVectorStruct<'static>>, ___E> for GoldenByteVectorStructwhere
___E: Encoder + ?Sized,
GoldenByteVectorStruct: Encode<GoldenByteVectorStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, GoldenByteVectorStruct<'static>>, ___E> for GoldenByteVectorStructwhere
___E: Encoder + ?Sized,
GoldenByteVectorStruct: Encode<GoldenByteVectorStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenByteVectorStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenByteVectorStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenByteVectorStruct<'de>> for GoldenByteVectorStruct
impl<'de> FromWire<GoldenByteVectorStruct<'de>> for GoldenByteVectorStruct
Sourcefn from_wire(wire: GoldenByteVectorStruct<'de>) -> Self
fn from_wire(wire: GoldenByteVectorStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenByteVectorStruct<'de>> for GoldenByteVectorStruct
impl<'de> FromWireRef<GoldenByteVectorStruct<'de>> for GoldenByteVectorStruct
Sourcefn from_wire_ref(wire: &GoldenByteVectorStruct<'de>) -> Self
fn from_wire_ref(wire: &GoldenByteVectorStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenByteVectorStruct
impl Hash for GoldenByteVectorStruct
Sourceimpl Ord for GoldenByteVectorStruct
impl Ord for GoldenByteVectorStruct
Sourcefn cmp(&self, other: &GoldenByteVectorStruct) -> Ordering
fn cmp(&self, other: &GoldenByteVectorStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenByteVectorStruct
impl PartialEq for GoldenByteVectorStruct
Sourceimpl PartialOrd for GoldenByteVectorStruct
impl PartialOrd for GoldenByteVectorStruct
impl Eq for GoldenByteVectorStruct
impl StructuralPartialEq for GoldenByteVectorStruct