#[repr(C)]pub struct GoldenFloatStruct {
pub v: f32,
}Fields
v: f32Trait Implementations
Sourceimpl Clone for GoldenFloatStruct
impl Clone for GoldenFloatStruct
Sourcefn clone(&self) -> GoldenFloatStruct
fn clone(&self) -> GoldenFloatStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenFloatStruct> for GoldenFloatStruct
impl CompatFrom<GoldenFloatStruct> for GoldenFloatStruct
Sourcefn compat_from(value: GoldenFloatStruct) -> Self
fn compat_from(value: GoldenFloatStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenFloatStruct> for GoldenFloatStruct
impl CompatFrom<GoldenFloatStruct> for GoldenFloatStruct
Sourcefn compat_from(value: GoldenFloatStruct) -> Self
fn compat_from(value: GoldenFloatStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenFloatStruct
impl Debug for GoldenFloatStruct
Sourceimpl<'a, ___E> Encode<GoldenFloatStruct, ___E> for &'a GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenFloatStruct, ___E> for &'a GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenFloatStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenFloatStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenFloatStruct, ___E> for GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenFloatStruct, ___E> for GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenFloatStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenFloatStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenFloatStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenFloatStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenFloatStruct>, ___E> for &'a GoldenFloatStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenFloatStruct>, ___E> for &'a GoldenFloatStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenFloatStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenFloatStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenFloatStruct>, ___E> for GoldenFloatStruct
impl<___E> EncodeOption<Box<'static, GoldenFloatStruct>, ___E> for GoldenFloatStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenFloatStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenFloatStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenFloatStruct> for GoldenFloatStruct
impl FromWire<GoldenFloatStruct> for GoldenFloatStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenFloatStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenFloatStruct, Self>
Sourcefn from_wire(wire: GoldenFloatStruct) -> Self
fn from_wire(wire: GoldenFloatStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenFloatStruct> for GoldenFloatStruct
impl FromWireRef<GoldenFloatStruct> for GoldenFloatStruct
Sourcefn from_wire_ref(wire: &GoldenFloatStruct) -> Self
fn from_wire_ref(wire: &GoldenFloatStruct) -> Self
Converts the given reference to this type.
Sourceimpl PartialEq for GoldenFloatStruct
impl PartialEq for GoldenFloatStruct
Sourceimpl PartialOrd for GoldenFloatStruct
impl PartialOrd for GoldenFloatStruct
impl Copy for GoldenFloatStruct
impl StructuralPartialEq for GoldenFloatStruct