pub struct GoldenNullableUnionStruct {
pub v: Option<Box<GoldenUnion>>,
}Fields
v: Option<Box<GoldenUnion>>Trait Implementations
Sourceimpl Clone for GoldenNullableUnionStruct
impl Clone for GoldenNullableUnionStruct
Sourcefn clone(&self) -> GoldenNullableUnionStruct
fn clone(&self) -> GoldenNullableUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl CompatFrom<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn compat_from(value: GoldenNullableUnionStruct) -> Self
fn compat_from(value: GoldenNullableUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl CompatFrom<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn compat_from(value: GoldenNullableUnionStruct) -> Self
fn compat_from(value: GoldenNullableUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenNullableUnionStruct
impl Debug for GoldenNullableUnionStruct
Sourceimpl<'a, ___E> Encode<GoldenNullableUnionStruct, ___E> for &'a GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenNullableUnionStruct, ___E> for &'a GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenNullableUnionStruct>, ___E> for &'a GoldenNullableUnionStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableUnionStruct: Encode<GoldenNullableUnionStruct, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenNullableUnionStruct>, ___E> for &'a GoldenNullableUnionStructwhere
___E: Encoder + ?Sized,
&'a GoldenNullableUnionStruct: Encode<GoldenNullableUnionStruct, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableUnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableUnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenNullableUnionStruct>, ___E> for GoldenNullableUnionStruct
impl<___E> EncodeOption<Box<'static, GoldenNullableUnionStruct>, ___E> for GoldenNullableUnionStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenNullableUnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenNullableUnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl FromWire<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn from_wire(wire: GoldenNullableUnionStruct) -> Self
fn from_wire(wire: GoldenNullableUnionStruct) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl FromWireRef<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn from_wire_ref(wire: &GoldenNullableUnionStruct) -> Self
fn from_wire_ref(wire: &GoldenNullableUnionStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenNullableUnionStruct
impl Hash for GoldenNullableUnionStruct
Sourceimpl Ord for GoldenNullableUnionStruct
impl Ord for GoldenNullableUnionStruct
Sourcefn cmp(&self, other: &GoldenNullableUnionStruct) -> Ordering
fn cmp(&self, other: &GoldenNullableUnionStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for GoldenNullableUnionStruct
impl PartialOrd for GoldenNullableUnionStruct
impl Eq for GoldenNullableUnionStruct
impl StructuralPartialEq for GoldenNullableUnionStruct