pub struct GoldenStringWithMaxSize2 {
pub s: String,
}Fields
s: StringTrait Implementations
Sourceimpl Clone for GoldenStringWithMaxSize2
impl Clone for GoldenStringWithMaxSize2
Sourcefn clone(&self) -> GoldenStringWithMaxSize2
fn clone(&self) -> GoldenStringWithMaxSize2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenStringWithMaxSize2> for GoldenStringWithMaxSize2
impl CompatFrom<GoldenStringWithMaxSize2> for GoldenStringWithMaxSize2
Sourcefn compat_from(value: GoldenStringWithMaxSize2) -> Self
fn compat_from(value: GoldenStringWithMaxSize2) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenStringWithMaxSize2> for GoldenStringWithMaxSize2
impl CompatFrom<GoldenStringWithMaxSize2> for GoldenStringWithMaxSize2
Sourcefn compat_from(value: GoldenStringWithMaxSize2) -> Self
fn compat_from(value: GoldenStringWithMaxSize2) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenStringWithMaxSize2
impl Debug for GoldenStringWithMaxSize2
Sourceimpl<'a, ___E> Encode<GoldenStringWithMaxSize2<'static>, ___E> for &'a GoldenStringWithMaxSize2where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<GoldenStringWithMaxSize2<'static>, ___E> for &'a GoldenStringWithMaxSize2where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStringWithMaxSize2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStringWithMaxSize2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenStringWithMaxSize2<'static>, ___E> for GoldenStringWithMaxSize2where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<GoldenStringWithMaxSize2<'static>, ___E> for GoldenStringWithMaxSize2where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStringWithMaxSize2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStringWithMaxSize2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenStringWithMaxSize2<'static>>, ___E> for &'a GoldenStringWithMaxSize2where
___E: Encoder + ?Sized,
&'a GoldenStringWithMaxSize2: Encode<GoldenStringWithMaxSize2<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, GoldenStringWithMaxSize2<'static>>, ___E> for &'a GoldenStringWithMaxSize2where
___E: Encoder + ?Sized,
&'a GoldenStringWithMaxSize2: Encode<GoldenStringWithMaxSize2<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStringWithMaxSize2<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStringWithMaxSize2<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenStringWithMaxSize2<'static>>, ___E> for GoldenStringWithMaxSize2where
___E: Encoder + ?Sized,
GoldenStringWithMaxSize2: Encode<GoldenStringWithMaxSize2<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, GoldenStringWithMaxSize2<'static>>, ___E> for GoldenStringWithMaxSize2where
___E: Encoder + ?Sized,
GoldenStringWithMaxSize2: Encode<GoldenStringWithMaxSize2<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStringWithMaxSize2<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStringWithMaxSize2<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<GoldenStringWithMaxSize2<'de>> for GoldenStringWithMaxSize2
impl<'de> FromWire<GoldenStringWithMaxSize2<'de>> for GoldenStringWithMaxSize2
Sourcefn from_wire(wire: GoldenStringWithMaxSize2<'de>) -> Self
fn from_wire(wire: GoldenStringWithMaxSize2<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<GoldenStringWithMaxSize2<'de>> for GoldenStringWithMaxSize2
impl<'de> FromWireRef<GoldenStringWithMaxSize2<'de>> for GoldenStringWithMaxSize2
Sourcefn from_wire_ref(wire: &GoldenStringWithMaxSize2<'de>) -> Self
fn from_wire_ref(wire: &GoldenStringWithMaxSize2<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenStringWithMaxSize2
impl Hash for GoldenStringWithMaxSize2
Sourceimpl Ord for GoldenStringWithMaxSize2
impl Ord for GoldenStringWithMaxSize2
Sourcefn cmp(&self, other: &GoldenStringWithMaxSize2) -> Ordering
fn cmp(&self, other: &GoldenStringWithMaxSize2) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenStringWithMaxSize2
impl PartialEq for GoldenStringWithMaxSize2
Sourceimpl PartialOrd for GoldenStringWithMaxSize2
impl PartialOrd for GoldenStringWithMaxSize2
impl Eq for GoldenStringWithMaxSize2
impl StructuralPartialEq for GoldenStringWithMaxSize2