#[repr(C)]pub struct GoldenStructArrayStruct {
pub v: [GoldenIntStruct; 2],
}Fields
v: [GoldenIntStruct; 2]Trait Implementations
Sourceimpl Clone for GoldenStructArrayStruct
impl Clone for GoldenStructArrayStruct
Sourcefn clone(&self) -> GoldenStructArrayStruct
fn clone(&self) -> GoldenStructArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl CompatFrom<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourcefn compat_from(value: GoldenStructArrayStruct) -> Self
fn compat_from(value: GoldenStructArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl CompatFrom<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourcefn compat_from(value: GoldenStructArrayStruct) -> Self
fn compat_from(value: GoldenStructArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenStructArrayStruct
impl Debug for GoldenStructArrayStruct
Sourceimpl<'a, ___E> Encode<GoldenStructArrayStruct, ___E> for &'a GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenStructArrayStruct, ___E> for &'a GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenStructArrayStruct, ___E> for GoldenStructArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenStructArrayStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenStructArrayStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenStructArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenStructArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenStructArrayStruct>, ___E> for &'a GoldenStructArrayStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenStructArrayStruct>, ___E> for &'a GoldenStructArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStructArrayStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStructArrayStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenStructArrayStruct>, ___E> for GoldenStructArrayStruct
impl<___E> EncodeOption<Box<'static, GoldenStructArrayStruct>, ___E> for GoldenStructArrayStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenStructArrayStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenStructArrayStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl FromWire<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenStructArrayStruct, Self>
Sourcefn from_wire(wire: GoldenStructArrayStruct) -> Self
fn from_wire(wire: GoldenStructArrayStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenStructArrayStruct> for GoldenStructArrayStruct
impl FromWireRef<GoldenStructArrayStruct> for GoldenStructArrayStruct
Sourcefn from_wire_ref(wire: &GoldenStructArrayStruct) -> Self
fn from_wire_ref(wire: &GoldenStructArrayStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenStructArrayStruct
impl Hash for GoldenStructArrayStruct
Sourceimpl Ord for GoldenStructArrayStruct
impl Ord for GoldenStructArrayStruct
Sourcefn cmp(&self, other: &GoldenStructArrayStruct) -> Ordering
fn cmp(&self, other: &GoldenStructArrayStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenStructArrayStruct
impl PartialEq for GoldenStructArrayStruct
Sourceimpl PartialOrd for GoldenStructArrayStruct
impl PartialOrd for GoldenStructArrayStruct
impl Copy for GoldenStructArrayStruct
impl Eq for GoldenStructArrayStruct
impl StructuralPartialEq for GoldenStructArrayStruct