#[repr(C)]pub struct GoldenUintStruct {
pub v: u16,
}Fields
v: u16Trait Implementations
Sourceimpl Clone for GoldenUintStruct
impl Clone for GoldenUintStruct
Sourcefn clone(&self) -> GoldenUintStruct
fn clone(&self) -> GoldenUintStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenUintStruct> for GoldenUintStruct
impl CompatFrom<GoldenUintStruct> for GoldenUintStruct
Sourcefn compat_from(value: GoldenUintStruct) -> Self
fn compat_from(value: GoldenUintStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenUintStruct> for GoldenUintStruct
impl CompatFrom<GoldenUintStruct> for GoldenUintStruct
Sourcefn compat_from(value: GoldenUintStruct) -> Self
fn compat_from(value: GoldenUintStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenUintStruct
impl Debug for GoldenUintStruct
Sourceimpl<'a, ___E> Encode<GoldenUintStruct, ___E> for &'a GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenUintStruct, ___E> for &'a GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUintStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUintStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenUintStruct, ___E> for GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenUintStruct, ___E> for GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenUintStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenUintStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUintStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUintStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenUintStruct>, ___E> for &'a GoldenUintStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenUintStruct>, ___E> for &'a GoldenUintStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenUintStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenUintStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenUintStruct>, ___E> for GoldenUintStruct
impl<___E> EncodeOption<Box<'static, GoldenUintStruct>, ___E> for GoldenUintStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenUintStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenUintStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenUintStruct> for GoldenUintStruct
impl FromWire<GoldenUintStruct> for GoldenUintStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenUintStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenUintStruct, Self>
Sourcefn from_wire(wire: GoldenUintStruct) -> Self
fn from_wire(wire: GoldenUintStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenUintStruct> for GoldenUintStruct
impl FromWireRef<GoldenUintStruct> for GoldenUintStruct
Sourcefn from_wire_ref(wire: &GoldenUintStruct) -> Self
fn from_wire_ref(wire: &GoldenUintStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenUintStruct
impl Hash for GoldenUintStruct
Sourceimpl Ord for GoldenUintStruct
impl Ord for GoldenUintStruct
Sourcefn cmp(&self, other: &GoldenUintStruct) -> Ordering
fn cmp(&self, other: &GoldenUintStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenUintStruct
impl PartialEq for GoldenUintStruct
Sourceimpl PartialOrd for GoldenUintStruct
impl PartialOrd for GoldenUintStruct
impl Copy for GoldenUintStruct
impl Eq for GoldenUintStruct
impl StructuralPartialEq for GoldenUintStruct