pub struct GoldenUnionStruct {
pub v: GoldenUnion,
}Fields
v: GoldenUnionTrait Implementations
Sourceimpl Clone for GoldenUnionStruct
impl Clone for GoldenUnionStruct
Sourcefn clone(&self) -> GoldenUnionStruct
fn clone(&self) -> GoldenUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<GoldenUnionStruct> for GoldenUnionStruct
impl CompatFrom<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn compat_from(value: GoldenUnionStruct) -> Self
fn compat_from(value: GoldenUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<GoldenUnionStruct> for GoldenUnionStruct
impl CompatFrom<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn compat_from(value: GoldenUnionStruct) -> Self
fn compat_from(value: GoldenUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for GoldenUnionStruct
impl Debug for GoldenUnionStruct
Sourceimpl<'a, ___E> Encode<GoldenUnionStruct, ___E> for &'a GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenUnionStruct, ___E> for &'a GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenUnionStruct, ___E> for GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenUnionStruct, ___E> for GoldenUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, GoldenUnionStruct>, ___E> for &'a GoldenUnionStruct
impl<'a, ___E> EncodeOption<Box<'static, GoldenUnionStruct>, ___E> for &'a GoldenUnionStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenUnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenUnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, GoldenUnionStruct>, ___E> for GoldenUnionStruct
impl<___E> EncodeOption<Box<'static, GoldenUnionStruct>, ___E> for GoldenUnionStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, GoldenUnionStruct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, GoldenUnionStruct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<GoldenUnionStruct> for GoldenUnionStruct
impl FromWire<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn from_wire(wire: GoldenUnionStruct) -> Self
fn from_wire(wire: GoldenUnionStruct) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<GoldenUnionStruct> for GoldenUnionStruct
impl FromWireRef<GoldenUnionStruct> for GoldenUnionStruct
Sourcefn from_wire_ref(wire: &GoldenUnionStruct) -> Self
fn from_wire_ref(wire: &GoldenUnionStruct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for GoldenUnionStruct
impl Hash for GoldenUnionStruct
Sourceimpl Ord for GoldenUnionStruct
impl Ord for GoldenUnionStruct
Sourcefn cmp(&self, other: &GoldenUnionStruct) -> Ordering
fn cmp(&self, other: &GoldenUnionStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for GoldenUnionStruct
impl PartialEq for GoldenUnionStruct
Sourceimpl PartialOrd for GoldenUnionStruct
impl PartialOrd for GoldenUnionStruct
impl Copy for GoldenUnionStruct
impl Eq for GoldenUnionStruct
impl StructuralPartialEq for GoldenUnionStruct