#[repr(C)]pub struct Int64Struct {
pub x: i64,
}Fields
x: i64Trait Implementations
Sourceimpl Clone for Int64Struct
impl Clone for Int64Struct
Sourcefn clone(&self) -> Int64Struct
fn clone(&self) -> Int64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Int64Struct> for Int64Struct
impl CompatFrom<Int64Struct> for Int64Struct
Sourcefn compat_from(value: Int64Struct) -> Self
fn compat_from(value: Int64Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Int64Struct> for Int64Struct
impl CompatFrom<Int64Struct> for Int64Struct
Sourcefn compat_from(value: Int64Struct) -> Self
fn compat_from(value: Int64Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Int64Struct
impl Debug for Int64Struct
Sourceimpl<'a, ___E> Encode<Int64Struct, ___E> for &'a Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Int64Struct, ___E> for &'a Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Int64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Int64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Int64Struct, ___E> for Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Int64Struct, ___E> for Int64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Int64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, Int64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Int64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Int64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Int64Struct>, ___E> for &'a Int64Struct
impl<'a, ___E> EncodeOption<Box<'static, Int64Struct>, ___E> for &'a Int64Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Int64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Int64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Int64Struct>, ___E> for Int64Struct
impl<___E> EncodeOption<Box<'static, Int64Struct>, ___E> for Int64Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Int64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Int64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Int64Struct> for Int64Struct
impl FromWire<Int64Struct> for Int64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<Int64Struct, Self>
Sourcefn from_wire(wire: Int64Struct) -> Self
fn from_wire(wire: Int64Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Int64Struct> for Int64Struct
impl FromWireRef<Int64Struct> for Int64Struct
Sourcefn from_wire_ref(wire: &Int64Struct) -> Self
fn from_wire_ref(wire: &Int64Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Int64Struct
impl Hash for Int64Struct
Sourceimpl Ord for Int64Struct
impl Ord for Int64Struct
Sourcefn cmp(&self, other: &Int64Struct) -> Ordering
fn cmp(&self, other: &Int64Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Int64Struct
impl PartialEq for Int64Struct
Sourceimpl PartialOrd for Int64Struct
impl PartialOrd for Int64Struct
impl Copy for Int64Struct
impl Eq for Int64Struct
impl StructuralPartialEq for Int64Struct