pub struct Length2StringWrapper {
pub length_2_string: String,
}Fields
length_2_string: StringTrait Implementations
Sourceimpl Clone for Length2StringWrapper
impl Clone for Length2StringWrapper
Sourcefn clone(&self) -> Length2StringWrapper
fn clone(&self) -> Length2StringWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Length2StringWrapper> for Length2StringWrapper
impl CompatFrom<Length2StringWrapper> for Length2StringWrapper
Sourcefn compat_from(value: Length2StringWrapper) -> Self
fn compat_from(value: Length2StringWrapper) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Length2StringWrapper> for Length2StringWrapper
impl CompatFrom<Length2StringWrapper> for Length2StringWrapper
Sourcefn compat_from(value: Length2StringWrapper) -> Self
fn compat_from(value: Length2StringWrapper) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Length2StringWrapper
impl Debug for Length2StringWrapper
Sourceimpl<'a, ___E> Encode<Length2StringWrapper<'static>, ___E> for &'a Length2StringWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<Length2StringWrapper<'static>, ___E> for &'a Length2StringWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Length2StringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Length2StringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Length2StringWrapper<'static>, ___E> for Length2StringWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<Length2StringWrapper<'static>, ___E> for Length2StringWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Length2StringWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Length2StringWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Length2StringWrapper<'static>>, ___E> for &'a Length2StringWrapperwhere
___E: Encoder + ?Sized,
&'a Length2StringWrapper: Encode<Length2StringWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, Length2StringWrapper<'static>>, ___E> for &'a Length2StringWrapperwhere
___E: Encoder + ?Sized,
&'a Length2StringWrapper: Encode<Length2StringWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Length2StringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Length2StringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Length2StringWrapper<'static>>, ___E> for Length2StringWrapper
impl<___E> EncodeOption<Box<'static, Length2StringWrapper<'static>>, ___E> for Length2StringWrapper
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Length2StringWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Length2StringWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Length2StringWrapper<'de>> for Length2StringWrapper
impl<'de> FromWire<Length2StringWrapper<'de>> for Length2StringWrapper
Sourcefn from_wire(wire: Length2StringWrapper<'de>) -> Self
fn from_wire(wire: Length2StringWrapper<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Length2StringWrapper<'de>> for Length2StringWrapper
impl<'de> FromWireRef<Length2StringWrapper<'de>> for Length2StringWrapper
Sourcefn from_wire_ref(wire: &Length2StringWrapper<'de>) -> Self
fn from_wire_ref(wire: &Length2StringWrapper<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Length2StringWrapper
impl Hash for Length2StringWrapper
Sourceimpl Ord for Length2StringWrapper
impl Ord for Length2StringWrapper
Sourcefn cmp(&self, other: &Length2StringWrapper) -> Ordering
fn cmp(&self, other: &Length2StringWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Length2StringWrapper
impl PartialEq for Length2StringWrapper
Sourceimpl PartialOrd for Length2StringWrapper
impl PartialOrd for Length2StringWrapper
impl Eq for Length2StringWrapper
impl StructuralPartialEq for Length2StringWrapper