pub struct MixedFieldsBody {
pub before: u32,
pub first_union: UnionSize8Align4,
pub middle_start: u16,
pub middle_end: u64,
pub second_union: UnionSize8Align4,
pub after: u32,
}Fields
before: u32first_union: UnionSize8Align4middle_start: u16middle_end: u64second_union: UnionSize8Align4after: u32Trait Implementations
Sourceimpl Clone for MixedFieldsBody
impl Clone for MixedFieldsBody
Sourcefn clone(&self) -> MixedFieldsBody
fn clone(&self) -> MixedFieldsBody
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<MixedFieldsBody> for MixedFieldsBody
impl CompatFrom<MixedFieldsBody> for MixedFieldsBody
Sourcefn compat_from(value: MixedFieldsBody) -> Self
fn compat_from(value: MixedFieldsBody) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MixedFieldsBody> for MixedFieldsBody
impl CompatFrom<MixedFieldsBody> for MixedFieldsBody
Sourcefn compat_from(value: MixedFieldsBody) -> Self
fn compat_from(value: MixedFieldsBody) -> Self
Converts
value into a value of this type.Sourceimpl Debug for MixedFieldsBody
impl Debug for MixedFieldsBody
Sourceimpl<'a, ___E> Encode<MixedFieldsBody, ___E> for &'a MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MixedFieldsBody, ___E> for &'a MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsBody>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsBody>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MixedFieldsBody, ___E> for MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MixedFieldsBody, ___E> for MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsBody>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsBody>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MixedFieldsBody>, ___E> for &'a MixedFieldsBody
impl<'a, ___E> EncodeOption<Box<'static, MixedFieldsBody>, ___E> for &'a MixedFieldsBody
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MixedFieldsBody>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MixedFieldsBody>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MixedFieldsBody>, ___E> for MixedFieldsBody
impl<___E> EncodeOption<Box<'static, MixedFieldsBody>, ___E> for MixedFieldsBody
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MixedFieldsBody>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MixedFieldsBody>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<MixedFieldsBody> for MixedFieldsBody
impl FromWire<MixedFieldsBody> for MixedFieldsBody
Sourcefn from_wire(wire: MixedFieldsBody) -> Self
fn from_wire(wire: MixedFieldsBody) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<MixedFieldsBody> for MixedFieldsBody
impl FromWireRef<MixedFieldsBody> for MixedFieldsBody
Sourcefn from_wire_ref(wire: &MixedFieldsBody) -> Self
fn from_wire_ref(wire: &MixedFieldsBody) -> Self
Converts the given reference to this type.
Sourceimpl Hash for MixedFieldsBody
impl Hash for MixedFieldsBody
Sourceimpl Ord for MixedFieldsBody
impl Ord for MixedFieldsBody
Sourcefn cmp(&self, other: &MixedFieldsBody) -> Ordering
fn cmp(&self, other: &MixedFieldsBody) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MixedFieldsBody
impl PartialEq for MixedFieldsBody
Sourceimpl PartialOrd for MixedFieldsBody
impl PartialOrd for MixedFieldsBody
impl Copy for MixedFieldsBody
impl Eq for MixedFieldsBody
impl StructuralPartialEq for MixedFieldsBody