pub struct MultipleBoundedNullableVectorsOfUint32s {
pub vu0: Option<Vec<u32>>,
pub vu1: Option<Vec<u32>>,
}Fields
vu0: Option<Vec<u32>>vu1: Option<Vec<u32>>Trait Implementations
Sourceimpl Clone for MultipleBoundedNullableVectorsOfUint32s
impl Clone for MultipleBoundedNullableVectorsOfUint32s
Sourcefn clone(&self) -> MultipleBoundedNullableVectorsOfUint32s
fn clone(&self) -> MultipleBoundedNullableVectorsOfUint32s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<MultipleBoundedNullableVectorsOfUint32s> for MultipleBoundedNullableVectorsOfUint32s
impl CompatFrom<MultipleBoundedNullableVectorsOfUint32s> for MultipleBoundedNullableVectorsOfUint32s
Sourcefn compat_from(value: MultipleBoundedNullableVectorsOfUint32s) -> Self
fn compat_from(value: MultipleBoundedNullableVectorsOfUint32s) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MultipleBoundedNullableVectorsOfUint32s> for MultipleBoundedNullableVectorsOfUint32s
impl CompatFrom<MultipleBoundedNullableVectorsOfUint32s> for MultipleBoundedNullableVectorsOfUint32s
Sourcefn compat_from(value: MultipleBoundedNullableVectorsOfUint32s) -> Self
fn compat_from(value: MultipleBoundedNullableVectorsOfUint32s) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E> for &'a MultipleBoundedNullableVectorsOfUint32swhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E> for &'a MultipleBoundedNullableVectorsOfUint32swhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E> for MultipleBoundedNullableVectorsOfUint32swhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E> for MultipleBoundedNullableVectorsOfUint32swhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfUint32s<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MultipleBoundedNullableVectorsOfUint32s<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleBoundedNullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleBoundedNullableVectorsOfUint32s: Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>, ___E> for &'a MultipleBoundedNullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
&'a MultipleBoundedNullableVectorsOfUint32s: Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>, ___E> for MultipleBoundedNullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleBoundedNullableVectorsOfUint32s: Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>, ___E> for MultipleBoundedNullableVectorsOfUint32swhere
___E: Encoder + ?Sized,
MultipleBoundedNullableVectorsOfUint32s: Encode<MultipleBoundedNullableVectorsOfUint32s<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MultipleBoundedNullableVectorsOfUint32s<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MultipleBoundedNullableVectorsOfUint32s<'de>> for MultipleBoundedNullableVectorsOfUint32s
impl<'de> FromWire<MultipleBoundedNullableVectorsOfUint32s<'de>> for MultipleBoundedNullableVectorsOfUint32s
Sourcefn from_wire(wire: MultipleBoundedNullableVectorsOfUint32s<'de>) -> Self
fn from_wire(wire: MultipleBoundedNullableVectorsOfUint32s<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MultipleBoundedNullableVectorsOfUint32s<'de>> for MultipleBoundedNullableVectorsOfUint32s
impl<'de> FromWireRef<MultipleBoundedNullableVectorsOfUint32s<'de>> for MultipleBoundedNullableVectorsOfUint32s
Sourcefn from_wire_ref(wire: &MultipleBoundedNullableVectorsOfUint32s<'de>) -> Self
fn from_wire_ref(wire: &MultipleBoundedNullableVectorsOfUint32s<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MultipleBoundedNullableVectorsOfUint32s
impl Ord for MultipleBoundedNullableVectorsOfUint32s
Sourcefn cmp(&self, other: &MultipleBoundedNullableVectorsOfUint32s) -> Ordering
fn cmp(&self, other: &MultipleBoundedNullableVectorsOfUint32s) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MultipleBoundedNullableVectorsOfUint32s
impl PartialEq for MultipleBoundedNullableVectorsOfUint32s
Sourcefn eq(&self, other: &MultipleBoundedNullableVectorsOfUint32s) -> bool
fn eq(&self, other: &MultipleBoundedNullableVectorsOfUint32s) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MultipleBoundedNullableVectorsOfUint32s
impl PartialOrd for MultipleBoundedNullableVectorsOfUint32s
impl Eq for MultipleBoundedNullableVectorsOfUint32s
impl StructuralPartialEq for MultipleBoundedNullableVectorsOfUint32s