#[repr(C)]pub struct MyInt16 {
pub value: i16,
}Fields
value: i16Trait Implementations
Sourceimpl CompatFrom<MyInt16> for MyInt16
impl CompatFrom<MyInt16> for MyInt16
Sourcefn compat_from(value: MyInt16) -> Self
fn compat_from(value: MyInt16) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyInt16> for MyInt16
impl CompatFrom<MyInt16> for MyInt16
Sourcefn compat_from(value: MyInt16) -> Self
fn compat_from(value: MyInt16) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyInt16, ___E> for &'a MyInt16where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyInt16, ___E> for &'a MyInt16where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyInt16, ___E> for MyInt16where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyInt16, ___E> for MyInt16where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyInt16>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyInt16>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyInt16>, ___E> for &'a MyInt16
impl<'a, ___E> EncodeOption<Box<'static, MyInt16>, ___E> for &'a MyInt16
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyInt16>, ___E> for MyInt16
impl<___E> EncodeOption<Box<'static, MyInt16>, ___E> for MyInt16
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyInt16> for MyInt16
impl FromWireRef<MyInt16> for MyInt16
Sourcefn from_wire_ref(wire: &MyInt16) -> Self
fn from_wire_ref(wire: &MyInt16) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyInt16
impl Ord for MyInt16
Sourceimpl PartialOrd for MyInt16
impl PartialOrd for MyInt16
impl Copy for MyInt16
impl Eq for MyInt16
impl StructuralPartialEq for MyInt16