#[repr(C)]pub struct MyInt64 {
pub value: i64,
}Fields
value: i64Trait Implementations
Sourceimpl CompatFrom<MyInt64> for MyInt64
impl CompatFrom<MyInt64> for MyInt64
Sourcefn compat_from(value: MyInt64) -> Self
fn compat_from(value: MyInt64) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyInt64> for MyInt64
impl CompatFrom<MyInt64> for MyInt64
Sourcefn compat_from(value: MyInt64) -> Self
fn compat_from(value: MyInt64) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyInt64, ___E> for &'a MyInt64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyInt64, ___E> for &'a MyInt64where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyInt64, ___E> for MyInt64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyInt64, ___E> for MyInt64where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyInt64>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyInt64>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyInt64>, ___E> for &'a MyInt64
impl<'a, ___E> EncodeOption<Box<'static, MyInt64>, ___E> for &'a MyInt64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyInt64>, ___E> for MyInt64
impl<___E> EncodeOption<Box<'static, MyInt64>, ___E> for MyInt64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyInt64> for MyInt64
impl FromWireRef<MyInt64> for MyInt64
Sourcefn from_wire_ref(wire: &MyInt64) -> Self
fn from_wire_ref(wire: &MyInt64) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyInt64
impl Ord for MyInt64
Sourceimpl PartialOrd for MyInt64
impl PartialOrd for MyInt64
impl Copy for MyInt64
impl Eq for MyInt64
impl StructuralPartialEq for MyInt64