#[repr(C)]pub struct MyInt8 {
pub value: i8,
}Fields
value: i8Trait Implementations
Sourceimpl CompatFrom<MyInt8> for MyInt8
impl CompatFrom<MyInt8> for MyInt8
Sourcefn compat_from(value: MyInt8) -> Self
fn compat_from(value: MyInt8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyInt8> for MyInt8
impl CompatFrom<MyInt8> for MyInt8
Sourcefn compat_from(value: MyInt8) -> Self
fn compat_from(value: MyInt8) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyInt8, ___E> for &'a MyInt8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyInt8, ___E> for &'a MyInt8where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyInt8, ___E> for MyInt8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyInt8, ___E> for MyInt8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyInt8>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyInt8>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyInt8>, ___E> for &'a MyInt8
impl<'a, ___E> EncodeOption<Box<'static, MyInt8>, ___E> for &'a MyInt8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyInt8>, ___E> for MyInt8
impl<___E> EncodeOption<Box<'static, MyInt8>, ___E> for MyInt8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyInt8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyInt8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyInt8> for MyInt8
impl FromWireRef<MyInt8> for MyInt8
Sourcefn from_wire_ref(wire: &MyInt8) -> Self
fn from_wire_ref(wire: &MyInt8) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyInt8
impl Ord for MyInt8
Sourceimpl PartialOrd for MyInt8
impl PartialOrd for MyInt8
impl Copy for MyInt8
impl Eq for MyInt8
impl StructuralPartialEq for MyInt8