#[repr(C)]pub struct MyUint16 {
pub value: u16,
}Fields
value: u16Trait Implementations
Sourceimpl CompatFrom<MyUint16> for MyUint16
impl CompatFrom<MyUint16> for MyUint16
Sourcefn compat_from(value: MyUint16) -> Self
fn compat_from(value: MyUint16) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyUint16> for MyUint16
impl CompatFrom<MyUint16> for MyUint16
Sourcefn compat_from(value: MyUint16) -> Self
fn compat_from(value: MyUint16) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyUint16, ___E> for &'a MyUint16where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyUint16, ___E> for &'a MyUint16where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyUint16, ___E> for MyUint16where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyUint16, ___E> for MyUint16where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyUint16>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyUint16>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyUint16>, ___E> for &'a MyUint16
impl<'a, ___E> EncodeOption<Box<'static, MyUint16>, ___E> for &'a MyUint16
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyUint16>, ___E> for MyUint16
impl<___E> EncodeOption<Box<'static, MyUint16>, ___E> for MyUint16
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyUint16> for MyUint16
impl FromWireRef<MyUint16> for MyUint16
Sourcefn from_wire_ref(wire: &MyUint16) -> Self
fn from_wire_ref(wire: &MyUint16) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyUint16
impl Ord for MyUint16
Sourceimpl PartialOrd for MyUint16
impl PartialOrd for MyUint16
impl Copy for MyUint16
impl Eq for MyUint16
impl StructuralPartialEq for MyUint16