#[repr(C)]pub struct MyUint64 {
pub value: u64,
}Fields
value: u64Trait Implementations
Sourceimpl CompatFrom<MyUint64> for MyUint64
impl CompatFrom<MyUint64> for MyUint64
Sourcefn compat_from(value: MyUint64) -> Self
fn compat_from(value: MyUint64) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyUint64> for MyUint64
impl CompatFrom<MyUint64> for MyUint64
Sourcefn compat_from(value: MyUint64) -> Self
fn compat_from(value: MyUint64) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyUint64, ___E> for &'a MyUint64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyUint64, ___E> for &'a MyUint64where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyUint64, ___E> for MyUint64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyUint64, ___E> for MyUint64where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyUint64>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyUint64>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyUint64>, ___E> for &'a MyUint64
impl<'a, ___E> EncodeOption<Box<'static, MyUint64>, ___E> for &'a MyUint64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyUint64>, ___E> for MyUint64
impl<___E> EncodeOption<Box<'static, MyUint64>, ___E> for MyUint64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint64>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint64>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyUint64> for MyUint64
impl FromWireRef<MyUint64> for MyUint64
Sourcefn from_wire_ref(wire: &MyUint64) -> Self
fn from_wire_ref(wire: &MyUint64) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyUint64
impl Ord for MyUint64
Sourceimpl PartialOrd for MyUint64
impl PartialOrd for MyUint64
impl Copy for MyUint64
impl Eq for MyUint64
impl StructuralPartialEq for MyUint64