#[repr(C)]pub struct MyUint8 {
pub value: u8,
}Fields
value: u8Trait Implementations
Sourceimpl CompatFrom<MyUint8> for MyUint8
impl CompatFrom<MyUint8> for MyUint8
Sourcefn compat_from(value: MyUint8) -> Self
fn compat_from(value: MyUint8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<MyUint8> for MyUint8
impl CompatFrom<MyUint8> for MyUint8
Sourcefn compat_from(value: MyUint8) -> Self
fn compat_from(value: MyUint8) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<MyUint8, ___E> for &'a MyUint8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MyUint8, ___E> for &'a MyUint8where
___E: InternalHandleEncoder + ?Sized,
Sourceimpl<___E> Encode<MyUint8, ___E> for MyUint8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MyUint8, ___E> for MyUint8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, MyUint8>
const COPY_OPTIMIZATION: CopyOptimization<Self, MyUint8>
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MyUint8>, ___E> for &'a MyUint8
impl<'a, ___E> EncodeOption<Box<'static, MyUint8>, ___E> for &'a MyUint8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MyUint8>, ___E> for MyUint8
impl<___E> EncodeOption<Box<'static, MyUint8>, ___E> for MyUint8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MyUint8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MyUint8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWireRef<MyUint8> for MyUint8
impl FromWireRef<MyUint8> for MyUint8
Sourcefn from_wire_ref(wire: &MyUint8) -> Self
fn from_wire_ref(wire: &MyUint8) -> Self
Converts the given reference to this type.
Sourceimpl Ord for MyUint8
impl Ord for MyUint8
Sourceimpl PartialOrd for MyUint8
impl PartialOrd for MyUint8
impl Copy for MyUint8
impl Eq for MyUint8
impl StructuralPartialEq for MyUint8