#[repr(C)]pub struct OneLayerStructNoPaddingAlign8 {
pub a: u32,
pub b: u16,
pub c: u16,
pub d: u64,
}Fields
a: u32b: u16c: u16d: u64Trait Implementations
Sourceimpl Clone for OneLayerStructNoPaddingAlign8
impl Clone for OneLayerStructNoPaddingAlign8
Sourcefn clone(&self) -> OneLayerStructNoPaddingAlign8
fn clone(&self) -> OneLayerStructNoPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
impl CompatFrom<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
Sourcefn compat_from(value: OneLayerStructNoPaddingAlign8) -> Self
fn compat_from(value: OneLayerStructNoPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
impl CompatFrom<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
Sourcefn compat_from(value: OneLayerStructNoPaddingAlign8) -> Self
fn compat_from(value: OneLayerStructNoPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<OneLayerStructNoPaddingAlign8, ___E> for &'a OneLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructNoPaddingAlign8, ___E> for &'a OneLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructNoPaddingAlign8, ___E> for OneLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructNoPaddingAlign8, ___E> for OneLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, OneLayerStructNoPaddingAlign8>
const COPY_OPTIMIZATION: CopyOptimization<Self, OneLayerStructNoPaddingAlign8>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign8>, ___E> for &'a OneLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
&'a OneLayerStructNoPaddingAlign8: Encode<OneLayerStructNoPaddingAlign8, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign8>, ___E> for &'a OneLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
&'a OneLayerStructNoPaddingAlign8: Encode<OneLayerStructNoPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign8>, ___E> for OneLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
OneLayerStructNoPaddingAlign8: Encode<OneLayerStructNoPaddingAlign8, ___E>,
impl<___E> EncodeOption<Box<'static, OneLayerStructNoPaddingAlign8>, ___E> for OneLayerStructNoPaddingAlign8where
___E: Encoder + ?Sized,
OneLayerStructNoPaddingAlign8: Encode<OneLayerStructNoPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructNoPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
impl FromWire<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
Sourceconst COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign8, Self>
const COPY_OPTIMIZATION: CopyOptimization<OneLayerStructNoPaddingAlign8, Self>
Sourcefn from_wire(wire: OneLayerStructNoPaddingAlign8) -> Self
fn from_wire(wire: OneLayerStructNoPaddingAlign8) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
impl FromWireRef<OneLayerStructNoPaddingAlign8> for OneLayerStructNoPaddingAlign8
Sourcefn from_wire_ref(wire: &OneLayerStructNoPaddingAlign8) -> Self
fn from_wire_ref(wire: &OneLayerStructNoPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl Hash for OneLayerStructNoPaddingAlign8
impl Hash for OneLayerStructNoPaddingAlign8
Sourceimpl Ord for OneLayerStructNoPaddingAlign8
impl Ord for OneLayerStructNoPaddingAlign8
Sourcefn cmp(&self, other: &OneLayerStructNoPaddingAlign8) -> Ordering
fn cmp(&self, other: &OneLayerStructNoPaddingAlign8) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneLayerStructNoPaddingAlign8
impl PartialEq for OneLayerStructNoPaddingAlign8
Sourcefn eq(&self, other: &OneLayerStructNoPaddingAlign8) -> bool
fn eq(&self, other: &OneLayerStructNoPaddingAlign8) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OneLayerStructNoPaddingAlign8
impl PartialOrd for OneLayerStructNoPaddingAlign8
impl Copy for OneLayerStructNoPaddingAlign8
impl Eq for OneLayerStructNoPaddingAlign8
impl StructuralPartialEq for OneLayerStructNoPaddingAlign8