pub struct OneLayerStructWithPaddingAlign4 {
pub a: u16,
pub b: u8,
pub c: u32,
}Fields
a: u16b: u8c: u32Trait Implementations
Sourceimpl Clone for OneLayerStructWithPaddingAlign4
impl Clone for OneLayerStructWithPaddingAlign4
Sourcefn clone(&self) -> OneLayerStructWithPaddingAlign4
fn clone(&self) -> OneLayerStructWithPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl CompatFrom<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn compat_from(value: OneLayerStructWithPaddingAlign4) -> Self
fn compat_from(value: OneLayerStructWithPaddingAlign4) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl CompatFrom<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn compat_from(value: OneLayerStructWithPaddingAlign4) -> Self
fn compat_from(value: OneLayerStructWithPaddingAlign4) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithPaddingAlign4, ___E> for OneLayerStructWithPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign4>, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: Encoder + ?Sized,
&'a OneLayerStructWithPaddingAlign4: Encode<OneLayerStructWithPaddingAlign4, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign4>, ___E> for &'a OneLayerStructWithPaddingAlign4where
___E: Encoder + ?Sized,
&'a OneLayerStructWithPaddingAlign4: Encode<OneLayerStructWithPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign4>, ___E> for OneLayerStructWithPaddingAlign4where
___E: Encoder + ?Sized,
OneLayerStructWithPaddingAlign4: Encode<OneLayerStructWithPaddingAlign4, ___E>,
impl<___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign4>, ___E> for OneLayerStructWithPaddingAlign4where
___E: Encoder + ?Sized,
OneLayerStructWithPaddingAlign4: Encode<OneLayerStructWithPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl FromWire<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn from_wire(wire: OneLayerStructWithPaddingAlign4) -> Self
fn from_wire(wire: OneLayerStructWithPaddingAlign4) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
impl FromWireRef<OneLayerStructWithPaddingAlign4> for OneLayerStructWithPaddingAlign4
Sourcefn from_wire_ref(wire: &OneLayerStructWithPaddingAlign4) -> Self
fn from_wire_ref(wire: &OneLayerStructWithPaddingAlign4) -> Self
Converts the given reference to this type.
Sourceimpl Ord for OneLayerStructWithPaddingAlign4
impl Ord for OneLayerStructWithPaddingAlign4
Sourcefn cmp(&self, other: &OneLayerStructWithPaddingAlign4) -> Ordering
fn cmp(&self, other: &OneLayerStructWithPaddingAlign4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneLayerStructWithPaddingAlign4
impl PartialEq for OneLayerStructWithPaddingAlign4
Sourcefn eq(&self, other: &OneLayerStructWithPaddingAlign4) -> bool
fn eq(&self, other: &OneLayerStructWithPaddingAlign4) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OneLayerStructWithPaddingAlign4
impl PartialOrd for OneLayerStructWithPaddingAlign4
impl Copy for OneLayerStructWithPaddingAlign4
impl Eq for OneLayerStructWithPaddingAlign4
impl StructuralPartialEq for OneLayerStructWithPaddingAlign4