pub struct OneLayerStructWithPaddingAlign8 {
pub a: u32,
pub b: u16,
pub c: u64,
}Fields
a: u32b: u16c: u64Trait Implementations
Sourceimpl Clone for OneLayerStructWithPaddingAlign8
impl Clone for OneLayerStructWithPaddingAlign8
Sourcefn clone(&self) -> OneLayerStructWithPaddingAlign8
fn clone(&self) -> OneLayerStructWithPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl CompatFrom<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn compat_from(value: OneLayerStructWithPaddingAlign8) -> Self
fn compat_from(value: OneLayerStructWithPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl CompatFrom<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn compat_from(value: OneLayerStructWithPaddingAlign8) -> Self
fn compat_from(value: OneLayerStructWithPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign8>, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: Encoder + ?Sized,
&'a OneLayerStructWithPaddingAlign8: Encode<OneLayerStructWithPaddingAlign8, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign8>, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: Encoder + ?Sized,
&'a OneLayerStructWithPaddingAlign8: Encode<OneLayerStructWithPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign8>, ___E> for OneLayerStructWithPaddingAlign8where
___E: Encoder + ?Sized,
OneLayerStructWithPaddingAlign8: Encode<OneLayerStructWithPaddingAlign8, ___E>,
impl<___E> EncodeOption<Box<'static, OneLayerStructWithPaddingAlign8>, ___E> for OneLayerStructWithPaddingAlign8where
___E: Encoder + ?Sized,
OneLayerStructWithPaddingAlign8: Encode<OneLayerStructWithPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OneLayerStructWithPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl FromWire<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn from_wire(wire: OneLayerStructWithPaddingAlign8) -> Self
fn from_wire(wire: OneLayerStructWithPaddingAlign8) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl FromWireRef<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn from_wire_ref(wire: &OneLayerStructWithPaddingAlign8) -> Self
fn from_wire_ref(wire: &OneLayerStructWithPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl Ord for OneLayerStructWithPaddingAlign8
impl Ord for OneLayerStructWithPaddingAlign8
Sourcefn cmp(&self, other: &OneLayerStructWithPaddingAlign8) -> Ordering
fn cmp(&self, other: &OneLayerStructWithPaddingAlign8) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for OneLayerStructWithPaddingAlign8
impl PartialEq for OneLayerStructWithPaddingAlign8
Sourcefn eq(&self, other: &OneLayerStructWithPaddingAlign8) -> bool
fn eq(&self, other: &OneLayerStructWithPaddingAlign8) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for OneLayerStructWithPaddingAlign8
impl PartialOrd for OneLayerStructWithPaddingAlign8
impl Copy for OneLayerStructWithPaddingAlign8
impl Eq for OneLayerStructWithPaddingAlign8
impl StructuralPartialEq for OneLayerStructWithPaddingAlign8