pub struct OptionalEmptyStructWrapper {
pub s: Option<Box<EmptyStruct>>,
}Fields
s: Option<Box<EmptyStruct>>Trait Implementations
Sourceimpl Clone for OptionalEmptyStructWrapper
impl Clone for OptionalEmptyStructWrapper
Sourcefn clone(&self) -> OptionalEmptyStructWrapper
fn clone(&self) -> OptionalEmptyStructWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<OptionalEmptyStructWrapper> for OptionalEmptyStructWrapper
impl CompatFrom<OptionalEmptyStructWrapper> for OptionalEmptyStructWrapper
Sourcefn compat_from(value: OptionalEmptyStructWrapper) -> Self
fn compat_from(value: OptionalEmptyStructWrapper) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<OptionalEmptyStructWrapper> for OptionalEmptyStructWrapper
impl CompatFrom<OptionalEmptyStructWrapper> for OptionalEmptyStructWrapper
Sourcefn compat_from(value: OptionalEmptyStructWrapper) -> Self
fn compat_from(value: OptionalEmptyStructWrapper) -> Self
Converts
value into a value of this type.Sourceimpl Debug for OptionalEmptyStructWrapper
impl Debug for OptionalEmptyStructWrapper
Sourceimpl<'a, ___E> Encode<OptionalEmptyStructWrapper<'static>, ___E> for &'a OptionalEmptyStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<OptionalEmptyStructWrapper<'static>, ___E> for &'a OptionalEmptyStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OptionalEmptyStructWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OptionalEmptyStructWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OptionalEmptyStructWrapper<'static>, ___E> for OptionalEmptyStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<OptionalEmptyStructWrapper<'static>, ___E> for OptionalEmptyStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OptionalEmptyStructWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OptionalEmptyStructWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, OptionalEmptyStructWrapper<'static>>, ___E> for &'a OptionalEmptyStructWrapperwhere
___E: Encoder + ?Sized,
&'a OptionalEmptyStructWrapper: Encode<OptionalEmptyStructWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, OptionalEmptyStructWrapper<'static>>, ___E> for &'a OptionalEmptyStructWrapperwhere
___E: Encoder + ?Sized,
&'a OptionalEmptyStructWrapper: Encode<OptionalEmptyStructWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OptionalEmptyStructWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OptionalEmptyStructWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, OptionalEmptyStructWrapper<'static>>, ___E> for OptionalEmptyStructWrapperwhere
___E: Encoder + ?Sized,
OptionalEmptyStructWrapper: Encode<OptionalEmptyStructWrapper<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, OptionalEmptyStructWrapper<'static>>, ___E> for OptionalEmptyStructWrapperwhere
___E: Encoder + ?Sized,
OptionalEmptyStructWrapper: Encode<OptionalEmptyStructWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, OptionalEmptyStructWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, OptionalEmptyStructWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<OptionalEmptyStructWrapper<'de>> for OptionalEmptyStructWrapper
impl<'de> FromWire<OptionalEmptyStructWrapper<'de>> for OptionalEmptyStructWrapper
Sourcefn from_wire(wire: OptionalEmptyStructWrapper<'de>) -> Self
fn from_wire(wire: OptionalEmptyStructWrapper<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<OptionalEmptyStructWrapper<'de>> for OptionalEmptyStructWrapper
impl<'de> FromWireRef<OptionalEmptyStructWrapper<'de>> for OptionalEmptyStructWrapper
Sourcefn from_wire_ref(wire: &OptionalEmptyStructWrapper<'de>) -> Self
fn from_wire_ref(wire: &OptionalEmptyStructWrapper<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for OptionalEmptyStructWrapper
impl Hash for OptionalEmptyStructWrapper
Sourceimpl Ord for OptionalEmptyStructWrapper
impl Ord for OptionalEmptyStructWrapper
Sourcefn cmp(&self, other: &OptionalEmptyStructWrapper) -> Ordering
fn cmp(&self, other: &OptionalEmptyStructWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for OptionalEmptyStructWrapper
impl PartialOrd for OptionalEmptyStructWrapper
impl Eq for OptionalEmptyStructWrapper
impl StructuralPartialEq for OptionalEmptyStructWrapper