pub struct PaddingAlignment2MaskMayBe4BytesVector {
pub v: Vec<PaddingAlignment2MaskMayBe4Bytes>,
}Fields
v: Vec<PaddingAlignment2MaskMayBe4Bytes>Trait Implementations
Sourceimpl Clone for PaddingAlignment2MaskMayBe4BytesVector
impl Clone for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn clone(&self) -> PaddingAlignment2MaskMayBe4BytesVector
fn clone(&self) -> PaddingAlignment2MaskMayBe4BytesVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingAlignment2MaskMayBe4BytesVector> for PaddingAlignment2MaskMayBe4BytesVector
impl CompatFrom<PaddingAlignment2MaskMayBe4BytesVector> for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn compat_from(value: PaddingAlignment2MaskMayBe4BytesVector) -> Self
fn compat_from(value: PaddingAlignment2MaskMayBe4BytesVector) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingAlignment2MaskMayBe4BytesVector> for PaddingAlignment2MaskMayBe4BytesVector
impl CompatFrom<PaddingAlignment2MaskMayBe4BytesVector> for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn compat_from(value: PaddingAlignment2MaskMayBe4BytesVector) -> Self
fn compat_from(value: PaddingAlignment2MaskMayBe4BytesVector) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E> for &'a PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E> for &'a PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4BytesVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4BytesVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E> for PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E> for PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4BytesVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4BytesVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>, ___E> for &'a PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: Encoder + ?Sized,
&'a PaddingAlignment2MaskMayBe4BytesVector: Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>, ___E> for &'a PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: Encoder + ?Sized,
&'a PaddingAlignment2MaskMayBe4BytesVector: Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>, ___E> for PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: Encoder + ?Sized,
PaddingAlignment2MaskMayBe4BytesVector: Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>, ___E> for PaddingAlignment2MaskMayBe4BytesVectorwhere
___E: Encoder + ?Sized,
PaddingAlignment2MaskMayBe4BytesVector: Encode<PaddingAlignment2MaskMayBe4BytesVector<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingAlignment2MaskMayBe4BytesVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingAlignment2MaskMayBe4BytesVector<'de>> for PaddingAlignment2MaskMayBe4BytesVector
impl<'de> FromWire<PaddingAlignment2MaskMayBe4BytesVector<'de>> for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn from_wire(wire: PaddingAlignment2MaskMayBe4BytesVector<'de>) -> Self
fn from_wire(wire: PaddingAlignment2MaskMayBe4BytesVector<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingAlignment2MaskMayBe4BytesVector<'de>> for PaddingAlignment2MaskMayBe4BytesVector
impl<'de> FromWireRef<PaddingAlignment2MaskMayBe4BytesVector<'de>> for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn from_wire_ref(wire: &PaddingAlignment2MaskMayBe4BytesVector<'de>) -> Self
fn from_wire_ref(wire: &PaddingAlignment2MaskMayBe4BytesVector<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingAlignment2MaskMayBe4BytesVector
impl Ord for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn cmp(&self, other: &PaddingAlignment2MaskMayBe4BytesVector) -> Ordering
fn cmp(&self, other: &PaddingAlignment2MaskMayBe4BytesVector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingAlignment2MaskMayBe4BytesVector
impl PartialEq for PaddingAlignment2MaskMayBe4BytesVector
Sourcefn eq(&self, other: &PaddingAlignment2MaskMayBe4BytesVector) -> bool
fn eq(&self, other: &PaddingAlignment2MaskMayBe4BytesVector) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingAlignment2MaskMayBe4BytesVector
impl PartialOrd for PaddingAlignment2MaskMayBe4BytesVector
impl Eq for PaddingAlignment2MaskMayBe4BytesVector
impl StructuralPartialEq for PaddingAlignment2MaskMayBe4BytesVector