pub struct PaddingBetweenFieldsInt8Int16 {
pub a: i8,
pub b: i16,
}Fields
a: i8b: i16Trait Implementations
Sourceimpl Clone for PaddingBetweenFieldsInt8Int16
impl Clone for PaddingBetweenFieldsInt8Int16
Sourcefn clone(&self) -> PaddingBetweenFieldsInt8Int16
fn clone(&self) -> PaddingBetweenFieldsInt8Int16
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl CompatFrom<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn compat_from(value: PaddingBetweenFieldsInt8Int16) -> Self
fn compat_from(value: PaddingBetweenFieldsInt8Int16) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl CompatFrom<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn compat_from(value: PaddingBetweenFieldsInt8Int16) -> Self
fn compat_from(value: PaddingBetweenFieldsInt8Int16) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt8Int16>, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt8Int16: Encode<PaddingBetweenFieldsInt8Int16, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt8Int16>, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: Encoder + ?Sized,
&'a PaddingBetweenFieldsInt8Int16: Encode<PaddingBetweenFieldsInt8Int16, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt8Int16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt8Int16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt8Int16>, ___E> for PaddingBetweenFieldsInt8Int16where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt8Int16: Encode<PaddingBetweenFieldsInt8Int16, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingBetweenFieldsInt8Int16>, ___E> for PaddingBetweenFieldsInt8Int16where
___E: Encoder + ?Sized,
PaddingBetweenFieldsInt8Int16: Encode<PaddingBetweenFieldsInt8Int16, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt8Int16>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingBetweenFieldsInt8Int16>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl FromWire<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn from_wire(wire: PaddingBetweenFieldsInt8Int16) -> Self
fn from_wire(wire: PaddingBetweenFieldsInt8Int16) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl FromWireRef<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn from_wire_ref(wire: &PaddingBetweenFieldsInt8Int16) -> Self
fn from_wire_ref(wire: &PaddingBetweenFieldsInt8Int16) -> Self
Converts the given reference to this type.
Sourceimpl Hash for PaddingBetweenFieldsInt8Int16
impl Hash for PaddingBetweenFieldsInt8Int16
Sourceimpl Ord for PaddingBetweenFieldsInt8Int16
impl Ord for PaddingBetweenFieldsInt8Int16
Sourcefn cmp(&self, other: &PaddingBetweenFieldsInt8Int16) -> Ordering
fn cmp(&self, other: &PaddingBetweenFieldsInt8Int16) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingBetweenFieldsInt8Int16
impl PartialEq for PaddingBetweenFieldsInt8Int16
Sourcefn eq(&self, other: &PaddingBetweenFieldsInt8Int16) -> bool
fn eq(&self, other: &PaddingBetweenFieldsInt8Int16) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingBetweenFieldsInt8Int16
impl PartialOrd for PaddingBetweenFieldsInt8Int16
impl Copy for PaddingBetweenFieldsInt8Int16
impl Eq for PaddingBetweenFieldsInt8Int16
impl StructuralPartialEq for PaddingBetweenFieldsInt8Int16