pub struct PaddingEndOfOutOfLineObject3Byte {
pub out_of_line: Option<Box<Struct3Byte>>,
}Fields
out_of_line: Option<Box<Struct3Byte>>Trait Implementations
Sourceimpl Clone for PaddingEndOfOutOfLineObject3Byte
impl Clone for PaddingEndOfOutOfLineObject3Byte
Sourcefn clone(&self) -> PaddingEndOfOutOfLineObject3Byte
fn clone(&self) -> PaddingEndOfOutOfLineObject3Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingEndOfOutOfLineObject3Byte> for PaddingEndOfOutOfLineObject3Byte
impl CompatFrom<PaddingEndOfOutOfLineObject3Byte> for PaddingEndOfOutOfLineObject3Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject3Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject3Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingEndOfOutOfLineObject3Byte> for PaddingEndOfOutOfLineObject3Byte
impl CompatFrom<PaddingEndOfOutOfLineObject3Byte> for PaddingEndOfOutOfLineObject3Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject3Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject3Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject3Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject3Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E> for PaddingEndOfOutOfLineObject3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E> for PaddingEndOfOutOfLineObject3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject3Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject3Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject3Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject3Byte: Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject3Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject3Byte: Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject3Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject3Byte: Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject3Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject3Byte: Encode<PaddingEndOfOutOfLineObject3Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject3Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingEndOfOutOfLineObject3Byte<'de>> for PaddingEndOfOutOfLineObject3Byte
impl<'de> FromWire<PaddingEndOfOutOfLineObject3Byte<'de>> for PaddingEndOfOutOfLineObject3Byte
Sourcefn from_wire(wire: PaddingEndOfOutOfLineObject3Byte<'de>) -> Self
fn from_wire(wire: PaddingEndOfOutOfLineObject3Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingEndOfOutOfLineObject3Byte<'de>> for PaddingEndOfOutOfLineObject3Byte
impl<'de> FromWireRef<PaddingEndOfOutOfLineObject3Byte<'de>> for PaddingEndOfOutOfLineObject3Byte
Sourcefn from_wire_ref(wire: &PaddingEndOfOutOfLineObject3Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingEndOfOutOfLineObject3Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingEndOfOutOfLineObject3Byte
impl Ord for PaddingEndOfOutOfLineObject3Byte
Sourcefn cmp(&self, other: &PaddingEndOfOutOfLineObject3Byte) -> Ordering
fn cmp(&self, other: &PaddingEndOfOutOfLineObject3Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingEndOfOutOfLineObject3Byte
impl PartialEq for PaddingEndOfOutOfLineObject3Byte
Sourcefn eq(&self, other: &PaddingEndOfOutOfLineObject3Byte) -> bool
fn eq(&self, other: &PaddingEndOfOutOfLineObject3Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingEndOfOutOfLineObject3Byte
impl PartialOrd for PaddingEndOfOutOfLineObject3Byte
impl Eq for PaddingEndOfOutOfLineObject3Byte
impl StructuralPartialEq for PaddingEndOfOutOfLineObject3Byte