pub struct PaddingEndOfOutOfLineObject5Byte {
pub out_of_line: Option<Box<Struct5Byte>>,
}Fields
out_of_line: Option<Box<Struct5Byte>>Trait Implementations
Sourceimpl Clone for PaddingEndOfOutOfLineObject5Byte
impl Clone for PaddingEndOfOutOfLineObject5Byte
Sourcefn clone(&self) -> PaddingEndOfOutOfLineObject5Byte
fn clone(&self) -> PaddingEndOfOutOfLineObject5Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingEndOfOutOfLineObject5Byte> for PaddingEndOfOutOfLineObject5Byte
impl CompatFrom<PaddingEndOfOutOfLineObject5Byte> for PaddingEndOfOutOfLineObject5Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject5Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject5Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingEndOfOutOfLineObject5Byte> for PaddingEndOfOutOfLineObject5Byte
impl CompatFrom<PaddingEndOfOutOfLineObject5Byte> for PaddingEndOfOutOfLineObject5Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject5Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject5Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject5Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject5Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E> for PaddingEndOfOutOfLineObject5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E> for PaddingEndOfOutOfLineObject5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject5Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject5Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject5Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject5Byte: Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject5Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject5Byte: Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject5Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject5Byte: Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject5Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject5Byte: Encode<PaddingEndOfOutOfLineObject5Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject5Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingEndOfOutOfLineObject5Byte<'de>> for PaddingEndOfOutOfLineObject5Byte
impl<'de> FromWire<PaddingEndOfOutOfLineObject5Byte<'de>> for PaddingEndOfOutOfLineObject5Byte
Sourcefn from_wire(wire: PaddingEndOfOutOfLineObject5Byte<'de>) -> Self
fn from_wire(wire: PaddingEndOfOutOfLineObject5Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingEndOfOutOfLineObject5Byte<'de>> for PaddingEndOfOutOfLineObject5Byte
impl<'de> FromWireRef<PaddingEndOfOutOfLineObject5Byte<'de>> for PaddingEndOfOutOfLineObject5Byte
Sourcefn from_wire_ref(wire: &PaddingEndOfOutOfLineObject5Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingEndOfOutOfLineObject5Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingEndOfOutOfLineObject5Byte
impl Ord for PaddingEndOfOutOfLineObject5Byte
Sourcefn cmp(&self, other: &PaddingEndOfOutOfLineObject5Byte) -> Ordering
fn cmp(&self, other: &PaddingEndOfOutOfLineObject5Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingEndOfOutOfLineObject5Byte
impl PartialEq for PaddingEndOfOutOfLineObject5Byte
Sourcefn eq(&self, other: &PaddingEndOfOutOfLineObject5Byte) -> bool
fn eq(&self, other: &PaddingEndOfOutOfLineObject5Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingEndOfOutOfLineObject5Byte
impl PartialOrd for PaddingEndOfOutOfLineObject5Byte
impl Eq for PaddingEndOfOutOfLineObject5Byte
impl StructuralPartialEq for PaddingEndOfOutOfLineObject5Byte