pub struct PaddingEndOfOutOfLineObject6Byte {
pub out_of_line: Option<Box<Struct6Byte>>,
}Fields
out_of_line: Option<Box<Struct6Byte>>Trait Implementations
Sourceimpl Clone for PaddingEndOfOutOfLineObject6Byte
impl Clone for PaddingEndOfOutOfLineObject6Byte
Sourcefn clone(&self) -> PaddingEndOfOutOfLineObject6Byte
fn clone(&self) -> PaddingEndOfOutOfLineObject6Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingEndOfOutOfLineObject6Byte> for PaddingEndOfOutOfLineObject6Byte
impl CompatFrom<PaddingEndOfOutOfLineObject6Byte> for PaddingEndOfOutOfLineObject6Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject6Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject6Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingEndOfOutOfLineObject6Byte> for PaddingEndOfOutOfLineObject6Byte
impl CompatFrom<PaddingEndOfOutOfLineObject6Byte> for PaddingEndOfOutOfLineObject6Byte
Sourcefn compat_from(value: PaddingEndOfOutOfLineObject6Byte) -> Self
fn compat_from(value: PaddingEndOfOutOfLineObject6Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject6Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E> for &'a PaddingEndOfOutOfLineObject6Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject6Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject6Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E> for PaddingEndOfOutOfLineObject6Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E> for PaddingEndOfOutOfLineObject6Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject6Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingEndOfOutOfLineObject6Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject6Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject6Byte: Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>, ___E> for &'a PaddingEndOfOutOfLineObject6Bytewhere
___E: Encoder + ?Sized,
&'a PaddingEndOfOutOfLineObject6Byte: Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject6Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject6Byte: Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>, ___E> for PaddingEndOfOutOfLineObject6Bytewhere
___E: Encoder + ?Sized,
PaddingEndOfOutOfLineObject6Byte: Encode<PaddingEndOfOutOfLineObject6Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingEndOfOutOfLineObject6Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingEndOfOutOfLineObject6Byte<'de>> for PaddingEndOfOutOfLineObject6Byte
impl<'de> FromWire<PaddingEndOfOutOfLineObject6Byte<'de>> for PaddingEndOfOutOfLineObject6Byte
Sourcefn from_wire(wire: PaddingEndOfOutOfLineObject6Byte<'de>) -> Self
fn from_wire(wire: PaddingEndOfOutOfLineObject6Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingEndOfOutOfLineObject6Byte<'de>> for PaddingEndOfOutOfLineObject6Byte
impl<'de> FromWireRef<PaddingEndOfOutOfLineObject6Byte<'de>> for PaddingEndOfOutOfLineObject6Byte
Sourcefn from_wire_ref(wire: &PaddingEndOfOutOfLineObject6Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingEndOfOutOfLineObject6Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingEndOfOutOfLineObject6Byte
impl Ord for PaddingEndOfOutOfLineObject6Byte
Sourcefn cmp(&self, other: &PaddingEndOfOutOfLineObject6Byte) -> Ordering
fn cmp(&self, other: &PaddingEndOfOutOfLineObject6Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingEndOfOutOfLineObject6Byte
impl PartialEq for PaddingEndOfOutOfLineObject6Byte
Sourcefn eq(&self, other: &PaddingEndOfOutOfLineObject6Byte) -> bool
fn eq(&self, other: &PaddingEndOfOutOfLineObject6Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingEndOfOutOfLineObject6Byte
impl PartialOrd for PaddingEndOfOutOfLineObject6Byte
impl Eq for PaddingEndOfOutOfLineObject6Byte
impl StructuralPartialEq for PaddingEndOfOutOfLineObject6Byte