pub struct PaddingInBetweenOutOfLineObjects3Byte {
pub first: Option<Box<Struct3Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct3Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects3Byte
impl Clone for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects3Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects3Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects3Byte> for PaddingInBetweenOutOfLineObjects3Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects3Byte> for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects3Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects3Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects3Byte> for PaddingInBetweenOutOfLineObjects3Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects3Byte> for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects3Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects3Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects3Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects3Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects3Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects3Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects3Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects3Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects3Byte: Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects3Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects3Byte: Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects3Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects3Byte: Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects3Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects3Byte: Encode<PaddingInBetweenOutOfLineObjects3Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects3Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects3Byte<'de>> for PaddingInBetweenOutOfLineObjects3Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects3Byte<'de>> for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn from_wire(wire: PaddingInBetweenOutOfLineObjects3Byte<'de>) -> Self
fn from_wire(wire: PaddingInBetweenOutOfLineObjects3Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects3Byte<'de>> for PaddingInBetweenOutOfLineObjects3Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects3Byte<'de>> for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects3Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects3Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects3Byte
impl Ord for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects3Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects3Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects3Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects3Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects3Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects3Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects3Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects3Byte
impl Eq for PaddingInBetweenOutOfLineObjects3Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects3Byte