pub struct PaddingInBetweenOutOfLineObjects4Byte {
pub first: Option<Box<Struct4Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct4Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects4Byte
impl Clone for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects4Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects4Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects4Byte> for PaddingInBetweenOutOfLineObjects4Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects4Byte> for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects4Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects4Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects4Byte> for PaddingInBetweenOutOfLineObjects4Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects4Byte> for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects4Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects4Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects4Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects4Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects4Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects4Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects4Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects4Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects4Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects4Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects4Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects4Byte: Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects4Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects4Byte: Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects4Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects4Byte: Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects4Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects4Byte: Encode<PaddingInBetweenOutOfLineObjects4Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects4Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects4Byte<'de>> for PaddingInBetweenOutOfLineObjects4Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects4Byte<'de>> for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn from_wire(wire: PaddingInBetweenOutOfLineObjects4Byte<'de>) -> Self
fn from_wire(wire: PaddingInBetweenOutOfLineObjects4Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects4Byte<'de>> for PaddingInBetweenOutOfLineObjects4Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects4Byte<'de>> for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects4Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects4Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects4Byte
impl Ord for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects4Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects4Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects4Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects4Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects4Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects4Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects4Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects4Byte
impl Eq for PaddingInBetweenOutOfLineObjects4Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects4Byte