pub struct PaddingInBetweenOutOfLineObjects5Byte {
pub first: Option<Box<Struct5Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct5Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects5Byte
impl Clone for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects5Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects5Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects5Byte> for PaddingInBetweenOutOfLineObjects5Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects5Byte> for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects5Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects5Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects5Byte> for PaddingInBetweenOutOfLineObjects5Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects5Byte> for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects5Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects5Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects5Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects5Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects5Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects5Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects5Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects5Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects5Byte: Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects5Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects5Byte: Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects5Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects5Byte: Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects5Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects5Byte: Encode<PaddingInBetweenOutOfLineObjects5Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects5Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects5Byte<'de>> for PaddingInBetweenOutOfLineObjects5Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects5Byte<'de>> for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn from_wire(wire: PaddingInBetweenOutOfLineObjects5Byte<'de>) -> Self
fn from_wire(wire: PaddingInBetweenOutOfLineObjects5Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects5Byte<'de>> for PaddingInBetweenOutOfLineObjects5Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects5Byte<'de>> for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects5Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects5Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects5Byte
impl Ord for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects5Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects5Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects5Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects5Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects5Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects5Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects5Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects5Byte
impl Eq for PaddingInBetweenOutOfLineObjects5Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects5Byte