pub struct PaddingInBetweenOutOfLineObjects7Byte {
pub first: Option<Box<Struct7Byte>>,
pub second: Option<Box<Struct8Byte>>,
}Fields
first: Option<Box<Struct7Byte>>second: Option<Box<Struct8Byte>>Trait Implementations
Sourceimpl Clone for PaddingInBetweenOutOfLineObjects7Byte
impl Clone for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn clone(&self) -> PaddingInBetweenOutOfLineObjects7Byte
fn clone(&self) -> PaddingInBetweenOutOfLineObjects7Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects7Byte> for PaddingInBetweenOutOfLineObjects7Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects7Byte> for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects7Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects7Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<PaddingInBetweenOutOfLineObjects7Byte> for PaddingInBetweenOutOfLineObjects7Byte
impl CompatFrom<PaddingInBetweenOutOfLineObjects7Byte> for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn compat_from(value: PaddingInBetweenOutOfLineObjects7Byte) -> Self
fn compat_from(value: PaddingInBetweenOutOfLineObjects7Byte) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects7Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E> for &'a PaddingInBetweenOutOfLineObjects7Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects7Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects7Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects7Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E> for PaddingInBetweenOutOfLineObjects7Bytewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects7Byte<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingInBetweenOutOfLineObjects7Byte<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects7Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects7Byte: Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>, ___E> for &'a PaddingInBetweenOutOfLineObjects7Bytewhere
___E: Encoder + ?Sized,
&'a PaddingInBetweenOutOfLineObjects7Byte: Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects7Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects7Byte: Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>, ___E> for PaddingInBetweenOutOfLineObjects7Bytewhere
___E: Encoder + ?Sized,
PaddingInBetweenOutOfLineObjects7Byte: Encode<PaddingInBetweenOutOfLineObjects7Byte<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PaddingInBetweenOutOfLineObjects7Byte<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<PaddingInBetweenOutOfLineObjects7Byte<'de>> for PaddingInBetweenOutOfLineObjects7Byte
impl<'de> FromWire<PaddingInBetweenOutOfLineObjects7Byte<'de>> for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn from_wire(wire: PaddingInBetweenOutOfLineObjects7Byte<'de>) -> Self
fn from_wire(wire: PaddingInBetweenOutOfLineObjects7Byte<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects7Byte<'de>> for PaddingInBetweenOutOfLineObjects7Byte
impl<'de> FromWireRef<PaddingInBetweenOutOfLineObjects7Byte<'de>> for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects7Byte<'de>) -> Self
fn from_wire_ref(wire: &PaddingInBetweenOutOfLineObjects7Byte<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PaddingInBetweenOutOfLineObjects7Byte
impl Ord for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn cmp(&self, other: &PaddingInBetweenOutOfLineObjects7Byte) -> Ordering
fn cmp(&self, other: &PaddingInBetweenOutOfLineObjects7Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PaddingInBetweenOutOfLineObjects7Byte
impl PartialEq for PaddingInBetweenOutOfLineObjects7Byte
Sourcefn eq(&self, other: &PaddingInBetweenOutOfLineObjects7Byte) -> bool
fn eq(&self, other: &PaddingInBetweenOutOfLineObjects7Byte) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PaddingInBetweenOutOfLineObjects7Byte
impl PartialOrd for PaddingInBetweenOutOfLineObjects7Byte
impl Eq for PaddingInBetweenOutOfLineObjects7Byte
impl StructuralPartialEq for PaddingInBetweenOutOfLineObjects7Byte