pub struct RecursiveEmptyStruct {
pub inner: Option<Box<RecursiveEmptyStruct>>,
}Fields
inner: Option<Box<RecursiveEmptyStruct>>Trait Implementations
Sourceimpl Clone for RecursiveEmptyStruct
impl Clone for RecursiveEmptyStruct
Sourcefn clone(&self) -> RecursiveEmptyStruct
fn clone(&self) -> RecursiveEmptyStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<RecursiveEmptyStruct> for RecursiveEmptyStruct
impl CompatFrom<RecursiveEmptyStruct> for RecursiveEmptyStruct
Sourcefn compat_from(value: RecursiveEmptyStruct) -> Self
fn compat_from(value: RecursiveEmptyStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<RecursiveEmptyStruct> for RecursiveEmptyStruct
impl CompatFrom<RecursiveEmptyStruct> for RecursiveEmptyStruct
Sourcefn compat_from(value: RecursiveEmptyStruct) -> Self
fn compat_from(value: RecursiveEmptyStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for RecursiveEmptyStruct
impl Debug for RecursiveEmptyStruct
Sourceimpl<'a, ___E> Encode<RecursiveEmptyStruct<'static>, ___E> for &'a RecursiveEmptyStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<RecursiveEmptyStruct<'static>, ___E> for &'a RecursiveEmptyStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveEmptyStruct<'static>, ___E> for RecursiveEmptyStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<RecursiveEmptyStruct<'static>, ___E> for RecursiveEmptyStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStruct<'static>>, ___E> for &'a RecursiveEmptyStructwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStruct: Encode<RecursiveEmptyStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStruct<'static>>, ___E> for &'a RecursiveEmptyStructwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStruct: Encode<RecursiveEmptyStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RecursiveEmptyStruct<'static>>, ___E> for RecursiveEmptyStruct
impl<___E> EncodeOption<Box<'static, RecursiveEmptyStruct<'static>>, ___E> for RecursiveEmptyStruct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RecursiveEmptyStruct<'de>> for RecursiveEmptyStruct
impl<'de> FromWire<RecursiveEmptyStruct<'de>> for RecursiveEmptyStruct
Sourcefn from_wire(wire: RecursiveEmptyStruct<'de>) -> Self
fn from_wire(wire: RecursiveEmptyStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveEmptyStruct<'de>> for RecursiveEmptyStruct
impl<'de> FromWireRef<RecursiveEmptyStruct<'de>> for RecursiveEmptyStruct
Sourcefn from_wire_ref(wire: &RecursiveEmptyStruct<'de>) -> Self
fn from_wire_ref(wire: &RecursiveEmptyStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for RecursiveEmptyStruct
impl Hash for RecursiveEmptyStruct
Sourceimpl Ord for RecursiveEmptyStruct
impl Ord for RecursiveEmptyStruct
Sourcefn cmp(&self, other: &RecursiveEmptyStruct) -> Ordering
fn cmp(&self, other: &RecursiveEmptyStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecursiveEmptyStruct
impl PartialEq for RecursiveEmptyStruct
Sourceimpl PartialOrd for RecursiveEmptyStruct
impl PartialOrd for RecursiveEmptyStruct
impl Eq for RecursiveEmptyStruct
impl StructuralPartialEq for RecursiveEmptyStruct