pub struct RecursiveEmptyStructArrayWrapper {
pub arr: [RecursiveEmptyStruct; 1],
}Fields
arr: [RecursiveEmptyStruct; 1]Trait Implementations
Sourceimpl Clone for RecursiveEmptyStructArrayWrapper
impl Clone for RecursiveEmptyStructArrayWrapper
Sourcefn clone(&self) -> RecursiveEmptyStructArrayWrapper
fn clone(&self) -> RecursiveEmptyStructArrayWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<RecursiveEmptyStructArrayWrapper> for RecursiveEmptyStructArrayWrapper
impl CompatFrom<RecursiveEmptyStructArrayWrapper> for RecursiveEmptyStructArrayWrapper
Sourcefn compat_from(value: RecursiveEmptyStructArrayWrapper) -> Self
fn compat_from(value: RecursiveEmptyStructArrayWrapper) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<RecursiveEmptyStructArrayWrapper> for RecursiveEmptyStructArrayWrapper
impl CompatFrom<RecursiveEmptyStructArrayWrapper> for RecursiveEmptyStructArrayWrapper
Sourcefn compat_from(value: RecursiveEmptyStructArrayWrapper) -> Self
fn compat_from(value: RecursiveEmptyStructArrayWrapper) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E> for &'a RecursiveEmptyStructArrayWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E> for &'a RecursiveEmptyStructArrayWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStructArrayWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStructArrayWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E> for RecursiveEmptyStructArrayWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E> for RecursiveEmptyStructArrayWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStructArrayWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStructArrayWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>, ___E> for &'a RecursiveEmptyStructArrayWrapperwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStructArrayWrapper: Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>, ___E> for &'a RecursiveEmptyStructArrayWrapperwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStructArrayWrapper: Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>, ___E> for RecursiveEmptyStructArrayWrapperwhere
___E: Encoder + ?Sized,
RecursiveEmptyStructArrayWrapper: Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>, ___E> for RecursiveEmptyStructArrayWrapperwhere
___E: Encoder + ?Sized,
RecursiveEmptyStructArrayWrapper: Encode<RecursiveEmptyStructArrayWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructArrayWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RecursiveEmptyStructArrayWrapper<'de>> for RecursiveEmptyStructArrayWrapper
impl<'de> FromWire<RecursiveEmptyStructArrayWrapper<'de>> for RecursiveEmptyStructArrayWrapper
Sourcefn from_wire(wire: RecursiveEmptyStructArrayWrapper<'de>) -> Self
fn from_wire(wire: RecursiveEmptyStructArrayWrapper<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveEmptyStructArrayWrapper<'de>> for RecursiveEmptyStructArrayWrapper
impl<'de> FromWireRef<RecursiveEmptyStructArrayWrapper<'de>> for RecursiveEmptyStructArrayWrapper
Sourcefn from_wire_ref(wire: &RecursiveEmptyStructArrayWrapper<'de>) -> Self
fn from_wire_ref(wire: &RecursiveEmptyStructArrayWrapper<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for RecursiveEmptyStructArrayWrapper
impl Ord for RecursiveEmptyStructArrayWrapper
Sourcefn cmp(&self, other: &RecursiveEmptyStructArrayWrapper) -> Ordering
fn cmp(&self, other: &RecursiveEmptyStructArrayWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecursiveEmptyStructArrayWrapper
impl PartialEq for RecursiveEmptyStructArrayWrapper
Sourcefn eq(&self, other: &RecursiveEmptyStructArrayWrapper) -> bool
fn eq(&self, other: &RecursiveEmptyStructArrayWrapper) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecursiveEmptyStructArrayWrapper
impl PartialOrd for RecursiveEmptyStructArrayWrapper
impl Eq for RecursiveEmptyStructArrayWrapper
impl StructuralPartialEq for RecursiveEmptyStructArrayWrapper