pub struct RecursiveEmptyStructVectorWrapper {
pub vec: Vec<RecursiveEmptyStruct>,
}Fields
vec: Vec<RecursiveEmptyStruct>Trait Implementations
Sourceimpl Clone for RecursiveEmptyStructVectorWrapper
impl Clone for RecursiveEmptyStructVectorWrapper
Sourcefn clone(&self) -> RecursiveEmptyStructVectorWrapper
fn clone(&self) -> RecursiveEmptyStructVectorWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<RecursiveEmptyStructVectorWrapper> for RecursiveEmptyStructVectorWrapper
impl CompatFrom<RecursiveEmptyStructVectorWrapper> for RecursiveEmptyStructVectorWrapper
Sourcefn compat_from(value: RecursiveEmptyStructVectorWrapper) -> Self
fn compat_from(value: RecursiveEmptyStructVectorWrapper) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<RecursiveEmptyStructVectorWrapper> for RecursiveEmptyStructVectorWrapper
impl CompatFrom<RecursiveEmptyStructVectorWrapper> for RecursiveEmptyStructVectorWrapper
Sourcefn compat_from(value: RecursiveEmptyStructVectorWrapper) -> Self
fn compat_from(value: RecursiveEmptyStructVectorWrapper) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E> for &'a RecursiveEmptyStructVectorWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E> for &'a RecursiveEmptyStructVectorWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStructVectorWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStructVectorWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E> for RecursiveEmptyStructVectorWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E> for RecursiveEmptyStructVectorWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveEmptyStructVectorWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveEmptyStructVectorWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>, ___E> for &'a RecursiveEmptyStructVectorWrapperwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStructVectorWrapper: Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>, ___E> for &'a RecursiveEmptyStructVectorWrapperwhere
___E: Encoder + ?Sized,
&'a RecursiveEmptyStructVectorWrapper: Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>, ___E> for RecursiveEmptyStructVectorWrapperwhere
___E: Encoder + ?Sized,
RecursiveEmptyStructVectorWrapper: Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>, ___E> for RecursiveEmptyStructVectorWrapperwhere
___E: Encoder + ?Sized,
RecursiveEmptyStructVectorWrapper: Encode<RecursiveEmptyStructVectorWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveEmptyStructVectorWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RecursiveEmptyStructVectorWrapper<'de>> for RecursiveEmptyStructVectorWrapper
impl<'de> FromWire<RecursiveEmptyStructVectorWrapper<'de>> for RecursiveEmptyStructVectorWrapper
Sourcefn from_wire(wire: RecursiveEmptyStructVectorWrapper<'de>) -> Self
fn from_wire(wire: RecursiveEmptyStructVectorWrapper<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveEmptyStructVectorWrapper<'de>> for RecursiveEmptyStructVectorWrapper
impl<'de> FromWireRef<RecursiveEmptyStructVectorWrapper<'de>> for RecursiveEmptyStructVectorWrapper
Sourcefn from_wire_ref(wire: &RecursiveEmptyStructVectorWrapper<'de>) -> Self
fn from_wire_ref(wire: &RecursiveEmptyStructVectorWrapper<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for RecursiveEmptyStructVectorWrapper
impl Ord for RecursiveEmptyStructVectorWrapper
Sourcefn cmp(&self, other: &RecursiveEmptyStructVectorWrapper) -> Ordering
fn cmp(&self, other: &RecursiveEmptyStructVectorWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecursiveEmptyStructVectorWrapper
impl PartialEq for RecursiveEmptyStructVectorWrapper
Sourcefn eq(&self, other: &RecursiveEmptyStructVectorWrapper) -> bool
fn eq(&self, other: &RecursiveEmptyStructVectorWrapper) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecursiveEmptyStructVectorWrapper
impl PartialOrd for RecursiveEmptyStructVectorWrapper
impl Eq for RecursiveEmptyStructVectorWrapper
impl StructuralPartialEq for RecursiveEmptyStructVectorWrapper