pub struct RecursiveOptionalStructWithString {
pub inner: Option<Box<RecursiveOptionalStructWithString>>,
pub str: Option<String>,
}Fields
inner: Option<Box<RecursiveOptionalStructWithString>>str: Option<String>Trait Implementations
Sourceimpl Clone for RecursiveOptionalStructWithString
impl Clone for RecursiveOptionalStructWithString
Sourcefn clone(&self) -> RecursiveOptionalStructWithString
fn clone(&self) -> RecursiveOptionalStructWithString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<RecursiveOptionalStructWithString> for RecursiveOptionalStructWithString
impl CompatFrom<RecursiveOptionalStructWithString> for RecursiveOptionalStructWithString
Sourcefn compat_from(value: RecursiveOptionalStructWithString) -> Self
fn compat_from(value: RecursiveOptionalStructWithString) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<RecursiveOptionalStructWithString> for RecursiveOptionalStructWithString
impl CompatFrom<RecursiveOptionalStructWithString> for RecursiveOptionalStructWithString
Sourcefn compat_from(value: RecursiveOptionalStructWithString) -> Self
fn compat_from(value: RecursiveOptionalStructWithString) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<RecursiveOptionalStructWithString<'static>, ___E> for RecursiveOptionalStructWithStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RecursiveOptionalStructWithString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: Encoder + ?Sized,
&'a RecursiveOptionalStructWithString: Encode<RecursiveOptionalStructWithString<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E> for &'a RecursiveOptionalStructWithStringwhere
___E: Encoder + ?Sized,
&'a RecursiveOptionalStructWithString: Encode<RecursiveOptionalStructWithString<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveOptionalStructWithString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveOptionalStructWithString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E> for RecursiveOptionalStructWithStringwhere
___E: Encoder + ?Sized,
RecursiveOptionalStructWithString: Encode<RecursiveOptionalStructWithString<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RecursiveOptionalStructWithString<'static>>, ___E> for RecursiveOptionalStructWithStringwhere
___E: Encoder + ?Sized,
RecursiveOptionalStructWithString: Encode<RecursiveOptionalStructWithString<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RecursiveOptionalStructWithString<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RecursiveOptionalStructWithString<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
impl<'de> FromWire<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
Sourcefn from_wire(wire: RecursiveOptionalStructWithString<'de>) -> Self
fn from_wire(wire: RecursiveOptionalStructWithString<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
impl<'de> FromWireRef<RecursiveOptionalStructWithString<'de>> for RecursiveOptionalStructWithString
Sourcefn from_wire_ref(wire: &RecursiveOptionalStructWithString<'de>) -> Self
fn from_wire_ref(wire: &RecursiveOptionalStructWithString<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for RecursiveOptionalStructWithString
impl Ord for RecursiveOptionalStructWithString
Sourcefn cmp(&self, other: &RecursiveOptionalStructWithString) -> Ordering
fn cmp(&self, other: &RecursiveOptionalStructWithString) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RecursiveOptionalStructWithString
impl PartialEq for RecursiveOptionalStructWithString
Sourcefn eq(&self, other: &RecursiveOptionalStructWithString) -> bool
fn eq(&self, other: &RecursiveOptionalStructWithString) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RecursiveOptionalStructWithString
impl PartialOrd for RecursiveOptionalStructWithString
impl Eq for RecursiveOptionalStructWithString
impl StructuralPartialEq for RecursiveOptionalStructWithString