pub struct Regression10V2 {
pub table: Regression10TableV2,
}Fields
table: Regression10TableV2Trait Implementations
Sourceimpl Clone for Regression10V2
impl Clone for Regression10V2
Sourcefn clone(&self) -> Regression10V2
fn clone(&self) -> Regression10V2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression10V2> for Regression10V2
impl CompatFrom<Regression10V2> for Regression10V2
Sourcefn compat_from(value: Regression10V2) -> Self
fn compat_from(value: Regression10V2) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Regression10V2> for Regression10V2
impl CompatFrom<Regression10V2> for Regression10V2
Sourcefn compat_from(value: Regression10V2) -> Self
fn compat_from(value: Regression10V2) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Regression10V2
impl Debug for Regression10V2
Sourceimpl<'a, ___E> Encode<Regression10V2<'static>, ___E> for &'a Regression10V2where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<Regression10V2<'static>, ___E> for &'a Regression10V2where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression10V2<'static>, ___E> for Regression10V2where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<Regression10V2<'static>, ___E> for Regression10V2where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression10V2<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression10V2<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression10V2<'static>>, ___E> for &'a Regression10V2
impl<'a, ___E> EncodeOption<Box<'static, Regression10V2<'static>>, ___E> for &'a Regression10V2
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V2<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V2<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression10V2<'static>>, ___E> for Regression10V2
impl<___E> EncodeOption<Box<'static, Regression10V2<'static>>, ___E> for Regression10V2
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression10V2<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression10V2<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression10V2<'de>> for Regression10V2
impl<'de> FromWire<Regression10V2<'de>> for Regression10V2
Sourcefn from_wire(wire: Regression10V2<'de>) -> Self
fn from_wire(wire: Regression10V2<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression10V2<'de>> for Regression10V2
impl<'de> FromWireRef<Regression10V2<'de>> for Regression10V2
Sourcefn from_wire_ref(wire: &Regression10V2<'de>) -> Self
fn from_wire_ref(wire: &Regression10V2<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Regression10V2
impl Hash for Regression10V2
Sourceimpl Ord for Regression10V2
impl Ord for Regression10V2
Sourcefn cmp(&self, other: &Regression10V2) -> Ordering
fn cmp(&self, other: &Regression10V2) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression10V2
impl PartialEq for Regression10V2
Sourceimpl PartialOrd for Regression10V2
impl PartialOrd for Regression10V2
impl Copy for Regression10V2
impl Eq for Regression10V2
impl StructuralPartialEq for Regression10V2