pub struct Regression2 {
pub head: Regression1,
pub f7: u8,
}Fields
head: Regression1f7: u8Trait Implementations
Sourceimpl Clone for Regression2
impl Clone for Regression2
Sourcefn clone(&self) -> Regression2
fn clone(&self) -> Regression2
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression2> for Regression2
impl CompatFrom<Regression2> for Regression2
Sourcefn compat_from(value: Regression2) -> Self
fn compat_from(value: Regression2) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Regression2> for Regression2
impl CompatFrom<Regression2> for Regression2
Sourcefn compat_from(value: Regression2) -> Self
fn compat_from(value: Regression2) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Regression2
impl Debug for Regression2
Sourceimpl<'a, ___E> Encode<Regression2, ___E> for &'a Regression2where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Regression2, ___E> for &'a Regression2where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression2>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression2>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression2, ___E> for Regression2where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Regression2, ___E> for Regression2where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression2>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression2>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression2>, ___E> for &'a Regression2
impl<'a, ___E> EncodeOption<Box<'static, Regression2>, ___E> for &'a Regression2
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression2>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression2>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression2>, ___E> for Regression2
impl<___E> EncodeOption<Box<'static, Regression2>, ___E> for Regression2
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression2>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression2>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Regression2> for Regression2
impl FromWire<Regression2> for Regression2
Sourcefn from_wire(wire: Regression2) -> Self
fn from_wire(wire: Regression2) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Regression2> for Regression2
impl FromWireRef<Regression2> for Regression2
Sourcefn from_wire_ref(wire: &Regression2) -> Self
fn from_wire_ref(wire: &Regression2) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Regression2
impl Hash for Regression2
Sourceimpl Ord for Regression2
impl Ord for Regression2
Sourcefn cmp(&self, other: &Regression2) -> Ordering
fn cmp(&self, other: &Regression2) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression2
impl PartialEq for Regression2
Sourceimpl PartialOrd for Regression2
impl PartialOrd for Regression2
impl Copy for Regression2
impl Eq for Regression2
impl StructuralPartialEq for Regression2