pub struct Regression6 {
pub f1: u8,
pub f2: BitsUint32,
pub f3: BitsUint8,
pub f4: u16,
pub f5: u64,
pub f6: u8,
}Fields
f1: u8f2: BitsUint32f3: BitsUint8f4: u16f5: u64f6: u8Trait Implementations
Sourceimpl Clone for Regression6
impl Clone for Regression6
Sourcefn clone(&self) -> Regression6
fn clone(&self) -> Regression6
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression6> for Regression6
impl CompatFrom<Regression6> for Regression6
Sourcefn compat_from(value: Regression6) -> Self
fn compat_from(value: Regression6) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Regression6> for Regression6
impl CompatFrom<Regression6> for Regression6
Sourcefn compat_from(value: Regression6) -> Self
fn compat_from(value: Regression6) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Regression6
impl Debug for Regression6
Sourceimpl<'a, ___E> Encode<Regression6, ___E> for &'a Regression6where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Regression6, ___E> for &'a Regression6where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression6>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression6>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression6, ___E> for Regression6where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Regression6, ___E> for Regression6where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression6>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression6>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression6>, ___E> for &'a Regression6
impl<'a, ___E> EncodeOption<Box<'static, Regression6>, ___E> for &'a Regression6
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression6>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression6>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression6>, ___E> for Regression6
impl<___E> EncodeOption<Box<'static, Regression6>, ___E> for Regression6
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression6>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression6>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Regression6> for Regression6
impl FromWire<Regression6> for Regression6
Sourcefn from_wire(wire: Regression6) -> Self
fn from_wire(wire: Regression6) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Regression6> for Regression6
impl FromWireRef<Regression6> for Regression6
Sourcefn from_wire_ref(wire: &Regression6) -> Self
fn from_wire_ref(wire: &Regression6) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Regression6
impl Hash for Regression6
Sourceimpl Ord for Regression6
impl Ord for Regression6
Sourcefn cmp(&self, other: &Regression6) -> Ordering
fn cmp(&self, other: &Regression6) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression6
impl PartialEq for Regression6
Sourceimpl PartialOrd for Regression6
impl PartialOrd for Regression6
impl Copy for Regression6
impl Eq for Regression6
impl StructuralPartialEq for Regression6