pub struct Regression9Value {
pub u: StringBoolUnion,
pub nullable_u: Option<Box<StringBoolUnion>>,
}Fields
u: StringBoolUnionnullable_u: Option<Box<StringBoolUnion>>Trait Implementations
Sourceimpl Clone for Regression9Value
impl Clone for Regression9Value
Sourcefn clone(&self) -> Regression9Value
fn clone(&self) -> Regression9Value
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Regression9Value> for Regression9Value
impl CompatFrom<Regression9Value> for Regression9Value
Sourcefn compat_from(value: Regression9Value) -> Self
fn compat_from(value: Regression9Value) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Regression9Value> for Regression9Value
impl CompatFrom<Regression9Value> for Regression9Value
Sourcefn compat_from(value: Regression9Value) -> Self
fn compat_from(value: Regression9Value) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Regression9Value
impl Debug for Regression9Value
Sourceimpl<'a, ___E> Encode<Regression9Value<'static>, ___E> for &'a Regression9Valuewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<Regression9Value<'static>, ___E> for &'a Regression9Valuewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression9Value<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression9Value<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Regression9Value<'static>, ___E> for Regression9Valuewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<Regression9Value<'static>, ___E> for Regression9Valuewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Regression9Value<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Regression9Value<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Regression9Value<'static>>, ___E> for &'a Regression9Value
impl<'a, ___E> EncodeOption<Box<'static, Regression9Value<'static>>, ___E> for &'a Regression9Value
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression9Value<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression9Value<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Regression9Value<'static>>, ___E> for Regression9Value
impl<___E> EncodeOption<Box<'static, Regression9Value<'static>>, ___E> for Regression9Value
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Regression9Value<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Regression9Value<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<Regression9Value<'de>> for Regression9Value
impl<'de> FromWire<Regression9Value<'de>> for Regression9Value
Sourcefn from_wire(wire: Regression9Value<'de>) -> Self
fn from_wire(wire: Regression9Value<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Regression9Value<'de>> for Regression9Value
impl<'de> FromWireRef<Regression9Value<'de>> for Regression9Value
Sourcefn from_wire_ref(wire: &Regression9Value<'de>) -> Self
fn from_wire_ref(wire: &Regression9Value<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Regression9Value
impl Hash for Regression9Value
Sourceimpl Ord for Regression9Value
impl Ord for Regression9Value
Sourcefn cmp(&self, other: &Regression9Value) -> Ordering
fn cmp(&self, other: &Regression9Value) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Regression9Value
impl PartialEq for Regression9Value
Sourceimpl PartialOrd for Regression9Value
impl PartialOrd for Regression9Value
impl Eq for Regression9Value
impl StructuralPartialEq for Regression9Value