pub struct Sandwich1Message {
pub header: TransactionHeader,
pub body: Sandwich1,
}Fields
header: TransactionHeaderbody: Sandwich1Trait Implementations
Sourceimpl Clone for Sandwich1Message
impl Clone for Sandwich1Message
Sourcefn clone(&self) -> Sandwich1Message
fn clone(&self) -> Sandwich1Message
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Sandwich1Message> for Sandwich1Message
impl CompatFrom<Sandwich1Message> for Sandwich1Message
Sourcefn compat_from(value: Sandwich1Message) -> Self
fn compat_from(value: Sandwich1Message) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Sandwich1Message> for Sandwich1Message
impl CompatFrom<Sandwich1Message> for Sandwich1Message
Sourcefn compat_from(value: Sandwich1Message) -> Self
fn compat_from(value: Sandwich1Message) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Sandwich1Message
impl Debug for Sandwich1Message
Sourceimpl<'a, ___E> Encode<Sandwich1Message, ___E> for &'a Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Sandwich1Message, ___E> for &'a Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1Message>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1Message>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich1Message, ___E> for Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Sandwich1Message, ___E> for Sandwich1Messagewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1Message>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1Message>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Sandwich1Message>, ___E> for &'a Sandwich1Message
impl<'a, ___E> EncodeOption<Box<'static, Sandwich1Message>, ___E> for &'a Sandwich1Message
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich1Message>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich1Message>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Sandwich1Message>, ___E> for Sandwich1Message
impl<___E> EncodeOption<Box<'static, Sandwich1Message>, ___E> for Sandwich1Message
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Sandwich1Message>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Sandwich1Message>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Sandwich1Message> for Sandwich1Message
impl FromWire<Sandwich1Message> for Sandwich1Message
Sourcefn from_wire(wire: Sandwich1Message) -> Self
fn from_wire(wire: Sandwich1Message) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Sandwich1Message> for Sandwich1Message
impl FromWireRef<Sandwich1Message> for Sandwich1Message
Sourcefn from_wire_ref(wire: &Sandwich1Message) -> Self
fn from_wire_ref(wire: &Sandwich1Message) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Sandwich1Message
impl Hash for Sandwich1Message
Sourceimpl Ord for Sandwich1Message
impl Ord for Sandwich1Message
Sourcefn cmp(&self, other: &Sandwich1Message) -> Ordering
fn cmp(&self, other: &Sandwich1Message) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Sandwich1Message
impl PartialEq for Sandwich1Message
Sourceimpl PartialOrd for Sandwich1Message
impl PartialOrd for Sandwich1Message
impl Copy for Sandwich1Message
impl Eq for Sandwich1Message
impl StructuralPartialEq for Sandwich1Message