pub struct SimpleTableArrayStruct {
pub the_array: [TransformerSimpleTable; 2],
}Fields
the_array: [TransformerSimpleTable; 2]Trait Implementations
Sourceimpl Clone for SimpleTableArrayStruct
impl Clone for SimpleTableArrayStruct
Sourcefn clone(&self) -> SimpleTableArrayStruct
fn clone(&self) -> SimpleTableArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<SimpleTableArrayStruct> for SimpleTableArrayStruct
impl CompatFrom<SimpleTableArrayStruct> for SimpleTableArrayStruct
Sourcefn compat_from(value: SimpleTableArrayStruct) -> Self
fn compat_from(value: SimpleTableArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<SimpleTableArrayStruct> for SimpleTableArrayStruct
impl CompatFrom<SimpleTableArrayStruct> for SimpleTableArrayStruct
Sourcefn compat_from(value: SimpleTableArrayStruct) -> Self
fn compat_from(value: SimpleTableArrayStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for SimpleTableArrayStruct
impl Debug for SimpleTableArrayStruct
Sourceimpl<'a, ___E> Encode<SimpleTableArrayStruct<'static>, ___E> for &'a SimpleTableArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<SimpleTableArrayStruct<'static>, ___E> for &'a SimpleTableArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SimpleTableArrayStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SimpleTableArrayStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SimpleTableArrayStruct<'static>, ___E> for SimpleTableArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<SimpleTableArrayStruct<'static>, ___E> for SimpleTableArrayStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SimpleTableArrayStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SimpleTableArrayStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SimpleTableArrayStruct<'static>>, ___E> for &'a SimpleTableArrayStructwhere
___E: Encoder + ?Sized,
&'a SimpleTableArrayStruct: Encode<SimpleTableArrayStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SimpleTableArrayStruct<'static>>, ___E> for &'a SimpleTableArrayStructwhere
___E: Encoder + ?Sized,
&'a SimpleTableArrayStruct: Encode<SimpleTableArrayStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SimpleTableArrayStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SimpleTableArrayStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SimpleTableArrayStruct<'static>>, ___E> for SimpleTableArrayStructwhere
___E: Encoder + ?Sized,
SimpleTableArrayStruct: Encode<SimpleTableArrayStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, SimpleTableArrayStruct<'static>>, ___E> for SimpleTableArrayStructwhere
___E: Encoder + ?Sized,
SimpleTableArrayStruct: Encode<SimpleTableArrayStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SimpleTableArrayStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SimpleTableArrayStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<SimpleTableArrayStruct<'de>> for SimpleTableArrayStruct
impl<'de> FromWire<SimpleTableArrayStruct<'de>> for SimpleTableArrayStruct
Sourcefn from_wire(wire: SimpleTableArrayStruct<'de>) -> Self
fn from_wire(wire: SimpleTableArrayStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SimpleTableArrayStruct<'de>> for SimpleTableArrayStruct
impl<'de> FromWireRef<SimpleTableArrayStruct<'de>> for SimpleTableArrayStruct
Sourcefn from_wire_ref(wire: &SimpleTableArrayStruct<'de>) -> Self
fn from_wire_ref(wire: &SimpleTableArrayStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SimpleTableArrayStruct
impl Hash for SimpleTableArrayStruct
Sourceimpl Ord for SimpleTableArrayStruct
impl Ord for SimpleTableArrayStruct
Sourcefn cmp(&self, other: &SimpleTableArrayStruct) -> Ordering
fn cmp(&self, other: &SimpleTableArrayStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SimpleTableArrayStruct
impl PartialEq for SimpleTableArrayStruct
Sourceimpl PartialOrd for SimpleTableArrayStruct
impl PartialOrd for SimpleTableArrayStruct
impl Copy for SimpleTableArrayStruct
impl Eq for SimpleTableArrayStruct
impl StructuralPartialEq for SimpleTableArrayStruct