pub struct SimpleTableThenUint64 {
pub table: SimpleTable,
pub number: u64,
}Fields
table: SimpleTablenumber: u64Trait Implementations
Sourceimpl Clone for SimpleTableThenUint64
impl Clone for SimpleTableThenUint64
Sourcefn clone(&self) -> SimpleTableThenUint64
fn clone(&self) -> SimpleTableThenUint64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<SimpleTableThenUint64> for SimpleTableThenUint64
impl CompatFrom<SimpleTableThenUint64> for SimpleTableThenUint64
Sourcefn compat_from(value: SimpleTableThenUint64) -> Self
fn compat_from(value: SimpleTableThenUint64) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<SimpleTableThenUint64> for SimpleTableThenUint64
impl CompatFrom<SimpleTableThenUint64> for SimpleTableThenUint64
Sourcefn compat_from(value: SimpleTableThenUint64) -> Self
fn compat_from(value: SimpleTableThenUint64) -> Self
Converts
value into a value of this type.Sourceimpl Debug for SimpleTableThenUint64
impl Debug for SimpleTableThenUint64
Sourceimpl<'a, ___E> Encode<SimpleTableThenUint64<'static>, ___E> for &'a SimpleTableThenUint64where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<SimpleTableThenUint64<'static>, ___E> for &'a SimpleTableThenUint64where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SimpleTableThenUint64<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SimpleTableThenUint64<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<SimpleTableThenUint64<'static>, ___E> for SimpleTableThenUint64where
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<SimpleTableThenUint64<'static>, ___E> for SimpleTableThenUint64where
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SimpleTableThenUint64<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SimpleTableThenUint64<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SimpleTableThenUint64<'static>>, ___E> for &'a SimpleTableThenUint64where
___E: Encoder + ?Sized,
&'a SimpleTableThenUint64: Encode<SimpleTableThenUint64<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SimpleTableThenUint64<'static>>, ___E> for &'a SimpleTableThenUint64where
___E: Encoder + ?Sized,
&'a SimpleTableThenUint64: Encode<SimpleTableThenUint64<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SimpleTableThenUint64<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SimpleTableThenUint64<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, SimpleTableThenUint64<'static>>, ___E> for SimpleTableThenUint64
impl<___E> EncodeOption<Box<'static, SimpleTableThenUint64<'static>>, ___E> for SimpleTableThenUint64
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SimpleTableThenUint64<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SimpleTableThenUint64<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<SimpleTableThenUint64<'de>> for SimpleTableThenUint64
impl<'de> FromWire<SimpleTableThenUint64<'de>> for SimpleTableThenUint64
Sourcefn from_wire(wire: SimpleTableThenUint64<'de>) -> Self
fn from_wire(wire: SimpleTableThenUint64<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<SimpleTableThenUint64<'de>> for SimpleTableThenUint64
impl<'de> FromWireRef<SimpleTableThenUint64<'de>> for SimpleTableThenUint64
Sourcefn from_wire_ref(wire: &SimpleTableThenUint64<'de>) -> Self
fn from_wire_ref(wire: &SimpleTableThenUint64<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SimpleTableThenUint64
impl Hash for SimpleTableThenUint64
Sourceimpl Ord for SimpleTableThenUint64
impl Ord for SimpleTableThenUint64
Sourcefn cmp(&self, other: &SimpleTableThenUint64) -> Ordering
fn cmp(&self, other: &SimpleTableThenUint64) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SimpleTableThenUint64
impl PartialEq for SimpleTableThenUint64
Sourceimpl PartialOrd for SimpleTableThenUint64
impl PartialOrd for SimpleTableThenUint64
impl Copy for SimpleTableThenUint64
impl Eq for SimpleTableThenUint64
impl StructuralPartialEq for SimpleTableThenUint64