#[repr(C)]pub struct Size5Alignment1Array {
pub a: [Size5Alignment1; 3],
}Fields
a: [Size5Alignment1; 3]Trait Implementations
Sourceimpl Clone for Size5Alignment1Array
impl Clone for Size5Alignment1Array
Sourcefn clone(&self) -> Size5Alignment1Array
fn clone(&self) -> Size5Alignment1Array
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Size5Alignment1Array> for Size5Alignment1Array
impl CompatFrom<Size5Alignment1Array> for Size5Alignment1Array
Sourcefn compat_from(value: Size5Alignment1Array) -> Self
fn compat_from(value: Size5Alignment1Array) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Size5Alignment1Array> for Size5Alignment1Array
impl CompatFrom<Size5Alignment1Array> for Size5Alignment1Array
Sourcefn compat_from(value: Size5Alignment1Array) -> Self
fn compat_from(value: Size5Alignment1Array) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Size5Alignment1Array
impl Debug for Size5Alignment1Array
Sourceimpl<'a, ___E> Encode<Size5Alignment1Array, ___E> for &'a Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment1Array, ___E> for &'a Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1Array>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1Array>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment1Array, ___E> for Size5Alignment1Arraywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Size5Alignment1Array>
const COPY_OPTIMIZATION: CopyOptimization<Self, Size5Alignment1Array>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment1Array>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment1Array>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Size5Alignment1Array>, ___E> for &'a Size5Alignment1Array
impl<'a, ___E> EncodeOption<Box<'static, Size5Alignment1Array>, ___E> for &'a Size5Alignment1Array
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment1Array>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment1Array>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Size5Alignment1Array>, ___E> for Size5Alignment1Array
impl<___E> EncodeOption<Box<'static, Size5Alignment1Array>, ___E> for Size5Alignment1Array
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment1Array>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment1Array>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Size5Alignment1Array> for Size5Alignment1Array
impl FromWire<Size5Alignment1Array> for Size5Alignment1Array
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Self>
const COPY_OPTIMIZATION: CopyOptimization<Size5Alignment1Array, Self>
Sourcefn from_wire(wire: Size5Alignment1Array) -> Self
fn from_wire(wire: Size5Alignment1Array) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Size5Alignment1Array> for Size5Alignment1Array
impl FromWireRef<Size5Alignment1Array> for Size5Alignment1Array
Sourcefn from_wire_ref(wire: &Size5Alignment1Array) -> Self
fn from_wire_ref(wire: &Size5Alignment1Array) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Size5Alignment1Array
impl Hash for Size5Alignment1Array
Sourceimpl Ord for Size5Alignment1Array
impl Ord for Size5Alignment1Array
Sourcefn cmp(&self, other: &Size5Alignment1Array) -> Ordering
fn cmp(&self, other: &Size5Alignment1Array) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Size5Alignment1Array
impl PartialEq for Size5Alignment1Array
Sourceimpl PartialOrd for Size5Alignment1Array
impl PartialOrd for Size5Alignment1Array
impl Copy for Size5Alignment1Array
impl Eq for Size5Alignment1Array
impl StructuralPartialEq for Size5Alignment1Array