pub struct Size5Alignment4 {
pub four: u32,
pub one: u8,
}Fields
four: u32one: u8Trait Implementations
Sourceimpl Clone for Size5Alignment4
impl Clone for Size5Alignment4
Sourcefn clone(&self) -> Size5Alignment4
fn clone(&self) -> Size5Alignment4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Size5Alignment4> for Size5Alignment4
impl CompatFrom<Size5Alignment4> for Size5Alignment4
Sourcefn compat_from(value: Size5Alignment4) -> Self
fn compat_from(value: Size5Alignment4) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Size5Alignment4> for Size5Alignment4
impl CompatFrom<Size5Alignment4> for Size5Alignment4
Sourcefn compat_from(value: Size5Alignment4) -> Self
fn compat_from(value: Size5Alignment4) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Size5Alignment4
impl Debug for Size5Alignment4
Sourceimpl<'a, ___E> Encode<Size5Alignment4, ___E> for &'a Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size5Alignment4, ___E> for &'a Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size5Alignment4, ___E> for Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size5Alignment4, ___E> for Size5Alignment4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size5Alignment4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size5Alignment4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Size5Alignment4>, ___E> for &'a Size5Alignment4
impl<'a, ___E> EncodeOption<Box<'static, Size5Alignment4>, ___E> for &'a Size5Alignment4
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Size5Alignment4>, ___E> for Size5Alignment4
impl<___E> EncodeOption<Box<'static, Size5Alignment4>, ___E> for Size5Alignment4
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Size5Alignment4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Size5Alignment4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Size5Alignment4> for Size5Alignment4
impl FromWire<Size5Alignment4> for Size5Alignment4
Sourcefn from_wire(wire: Size5Alignment4) -> Self
fn from_wire(wire: Size5Alignment4) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Size5Alignment4> for Size5Alignment4
impl FromWireRef<Size5Alignment4> for Size5Alignment4
Sourcefn from_wire_ref(wire: &Size5Alignment4) -> Self
fn from_wire_ref(wire: &Size5Alignment4) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Size5Alignment4
impl Hash for Size5Alignment4
Sourceimpl Ord for Size5Alignment4
impl Ord for Size5Alignment4
Sourcefn cmp(&self, other: &Size5Alignment4) -> Ordering
fn cmp(&self, other: &Size5Alignment4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Size5Alignment4
impl PartialEq for Size5Alignment4
Sourceimpl PartialOrd for Size5Alignment4
impl PartialOrd for Size5Alignment4
impl Copy for Size5Alignment4
impl Eq for Size5Alignment4
impl StructuralPartialEq for Size5Alignment4