#[repr(C)]pub struct StrictBitsUint16Struct {
pub b: StrictBitsUint16,
}Fields
b: StrictBitsUint16Trait Implementations
Sourceimpl Clone for StrictBitsUint16Struct
impl Clone for StrictBitsUint16Struct
Sourcefn clone(&self) -> StrictBitsUint16Struct
fn clone(&self) -> StrictBitsUint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl CompatFrom<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourcefn compat_from(value: StrictBitsUint16Struct) -> Self
fn compat_from(value: StrictBitsUint16Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl CompatFrom<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourcefn compat_from(value: StrictBitsUint16Struct) -> Self
fn compat_from(value: StrictBitsUint16Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StrictBitsUint16Struct
impl Debug for StrictBitsUint16Struct
Sourceimpl<'a, ___E> Encode<StrictBitsUint16Struct, ___E> for &'a StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint16Struct, ___E> for &'a StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint16Struct>, ___E> for &'a StrictBitsUint16Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint16Struct>, ___E> for &'a StrictBitsUint16Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictBitsUint16Struct>, ___E> for StrictBitsUint16Struct
impl<___E> EncodeOption<Box<'static, StrictBitsUint16Struct>, ___E> for StrictBitsUint16Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl FromWire<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint16Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint16Struct, Self>
Sourcefn from_wire(wire: StrictBitsUint16Struct) -> Self
fn from_wire(wire: StrictBitsUint16Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl FromWireRef<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint16Struct) -> Self
fn from_wire_ref(wire: &StrictBitsUint16Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StrictBitsUint16Struct
impl Hash for StrictBitsUint16Struct
Sourceimpl Ord for StrictBitsUint16Struct
impl Ord for StrictBitsUint16Struct
Sourcefn cmp(&self, other: &StrictBitsUint16Struct) -> Ordering
fn cmp(&self, other: &StrictBitsUint16Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictBitsUint16Struct
impl PartialEq for StrictBitsUint16Struct
Sourceimpl PartialOrd for StrictBitsUint16Struct
impl PartialOrd for StrictBitsUint16Struct
impl Copy for StrictBitsUint16Struct
impl Eq for StrictBitsUint16Struct
impl StructuralPartialEq for StrictBitsUint16Struct