#[repr(C)]pub struct StrictBitsUint32Struct {
pub b: StrictBitsUint32,
}Fields
b: StrictBitsUint32Trait Implementations
Sourceimpl Clone for StrictBitsUint32Struct
impl Clone for StrictBitsUint32Struct
Sourcefn clone(&self) -> StrictBitsUint32Struct
fn clone(&self) -> StrictBitsUint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl CompatFrom<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourcefn compat_from(value: StrictBitsUint32Struct) -> Self
fn compat_from(value: StrictBitsUint32Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl CompatFrom<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourcefn compat_from(value: StrictBitsUint32Struct) -> Self
fn compat_from(value: StrictBitsUint32Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StrictBitsUint32Struct
impl Debug for StrictBitsUint32Struct
Sourceimpl<'a, ___E> Encode<StrictBitsUint32Struct, ___E> for &'a StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint32Struct, ___E> for &'a StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint32Struct>, ___E> for &'a StrictBitsUint32Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictBitsUint32Struct>, ___E> for &'a StrictBitsUint32Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictBitsUint32Struct>, ___E> for StrictBitsUint32Struct
impl<___E> EncodeOption<Box<'static, StrictBitsUint32Struct>, ___E> for StrictBitsUint32Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictBitsUint32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictBitsUint32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl FromWire<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint32Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint32Struct, Self>
Sourcefn from_wire(wire: StrictBitsUint32Struct) -> Self
fn from_wire(wire: StrictBitsUint32Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl FromWireRef<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint32Struct) -> Self
fn from_wire_ref(wire: &StrictBitsUint32Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StrictBitsUint32Struct
impl Hash for StrictBitsUint32Struct
Sourceimpl Ord for StrictBitsUint32Struct
impl Ord for StrictBitsUint32Struct
Sourcefn cmp(&self, other: &StrictBitsUint32Struct) -> Ordering
fn cmp(&self, other: &StrictBitsUint32Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictBitsUint32Struct
impl PartialEq for StrictBitsUint32Struct
Sourceimpl PartialOrd for StrictBitsUint32Struct
impl PartialOrd for StrictBitsUint32Struct
impl Copy for StrictBitsUint32Struct
impl Eq for StrictBitsUint32Struct
impl StructuralPartialEq for StrictBitsUint32Struct