#[repr(C)]pub struct StrictEnumInt32Struct {
pub e: StrictEnumInt32,
}Fields
e: StrictEnumInt32Trait Implementations
Sourceimpl Clone for StrictEnumInt32Struct
impl Clone for StrictEnumInt32Struct
Sourcefn clone(&self) -> StrictEnumInt32Struct
fn clone(&self) -> StrictEnumInt32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl CompatFrom<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourcefn compat_from(value: StrictEnumInt32Struct) -> Self
fn compat_from(value: StrictEnumInt32Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl CompatFrom<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourcefn compat_from(value: StrictEnumInt32Struct) -> Self
fn compat_from(value: StrictEnumInt32Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumInt32Struct
impl Debug for StrictEnumInt32Struct
Sourceimpl<'a, ___E> Encode<StrictEnumInt32Struct, ___E> for &'a StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt32Struct, ___E> for &'a StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt32Struct>, ___E> for &'a StrictEnumInt32Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt32Struct>, ___E> for &'a StrictEnumInt32Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumInt32Struct>, ___E> for StrictEnumInt32Struct
impl<___E> EncodeOption<Box<'static, StrictEnumInt32Struct>, ___E> for StrictEnumInt32Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt32Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt32Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl FromWire<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt32Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt32Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt32Struct) -> Self
fn from_wire(wire: StrictEnumInt32Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl FromWireRef<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt32Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt32Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumInt32Struct
impl Hash for StrictEnumInt32Struct
Sourceimpl Ord for StrictEnumInt32Struct
impl Ord for StrictEnumInt32Struct
Sourcefn cmp(&self, other: &StrictEnumInt32Struct) -> Ordering
fn cmp(&self, other: &StrictEnumInt32Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumInt32Struct
impl PartialEq for StrictEnumInt32Struct
Sourceimpl PartialOrd for StrictEnumInt32Struct
impl PartialOrd for StrictEnumInt32Struct
impl Copy for StrictEnumInt32Struct
impl Eq for StrictEnumInt32Struct
impl StructuralPartialEq for StrictEnumInt32Struct