#[repr(C)]pub struct StrictEnumInt64Struct {
pub e: StrictEnumInt64,
}Fields
e: StrictEnumInt64Trait Implementations
Sourceimpl Clone for StrictEnumInt64Struct
impl Clone for StrictEnumInt64Struct
Sourcefn clone(&self) -> StrictEnumInt64Struct
fn clone(&self) -> StrictEnumInt64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl CompatFrom<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourcefn compat_from(value: StrictEnumInt64Struct) -> Self
fn compat_from(value: StrictEnumInt64Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl CompatFrom<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourcefn compat_from(value: StrictEnumInt64Struct) -> Self
fn compat_from(value: StrictEnumInt64Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumInt64Struct
impl Debug for StrictEnumInt64Struct
Sourceimpl<'a, ___E> Encode<StrictEnumInt64Struct, ___E> for &'a StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt64Struct, ___E> for &'a StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt64Struct>, ___E> for &'a StrictEnumInt64Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt64Struct>, ___E> for &'a StrictEnumInt64Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumInt64Struct>, ___E> for StrictEnumInt64Struct
impl<___E> EncodeOption<Box<'static, StrictEnumInt64Struct>, ___E> for StrictEnumInt64Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt64Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt64Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl FromWire<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt64Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt64Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt64Struct) -> Self
fn from_wire(wire: StrictEnumInt64Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl FromWireRef<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt64Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt64Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumInt64Struct
impl Hash for StrictEnumInt64Struct
Sourceimpl Ord for StrictEnumInt64Struct
impl Ord for StrictEnumInt64Struct
Sourcefn cmp(&self, other: &StrictEnumInt64Struct) -> Ordering
fn cmp(&self, other: &StrictEnumInt64Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumInt64Struct
impl PartialEq for StrictEnumInt64Struct
Sourceimpl PartialOrd for StrictEnumInt64Struct
impl PartialOrd for StrictEnumInt64Struct
impl Copy for StrictEnumInt64Struct
impl Eq for StrictEnumInt64Struct
impl StructuralPartialEq for StrictEnumInt64Struct