#[repr(C)]pub struct StrictEnumInt8Struct {
pub e: StrictEnumInt8,
}Fields
e: StrictEnumInt8Trait Implementations
Sourceimpl Clone for StrictEnumInt8Struct
impl Clone for StrictEnumInt8Struct
Sourcefn clone(&self) -> StrictEnumInt8Struct
fn clone(&self) -> StrictEnumInt8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl CompatFrom<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourcefn compat_from(value: StrictEnumInt8Struct) -> Self
fn compat_from(value: StrictEnumInt8Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl CompatFrom<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourcefn compat_from(value: StrictEnumInt8Struct) -> Self
fn compat_from(value: StrictEnumInt8Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StrictEnumInt8Struct
impl Debug for StrictEnumInt8Struct
Sourceimpl<'a, ___E> Encode<StrictEnumInt8Struct, ___E> for &'a StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt8Struct, ___E> for &'a StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt8Struct, ___E> for StrictEnumInt8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt8Struct>, ___E> for &'a StrictEnumInt8Struct
impl<'a, ___E> EncodeOption<Box<'static, StrictEnumInt8Struct>, ___E> for &'a StrictEnumInt8Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StrictEnumInt8Struct>, ___E> for StrictEnumInt8Struct
impl<___E> EncodeOption<Box<'static, StrictEnumInt8Struct>, ___E> for StrictEnumInt8Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StrictEnumInt8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StrictEnumInt8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl FromWire<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt8Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt8Struct) -> Self
fn from_wire(wire: StrictEnumInt8Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt8Struct> for StrictEnumInt8Struct
impl FromWireRef<StrictEnumInt8Struct> for StrictEnumInt8Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt8Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt8Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StrictEnumInt8Struct
impl Hash for StrictEnumInt8Struct
Sourceimpl Ord for StrictEnumInt8Struct
impl Ord for StrictEnumInt8Struct
Sourcefn cmp(&self, other: &StrictEnumInt8Struct) -> Ordering
fn cmp(&self, other: &StrictEnumInt8Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StrictEnumInt8Struct
impl PartialEq for StrictEnumInt8Struct
Sourceimpl PartialOrd for StrictEnumInt8Struct
impl PartialOrd for StrictEnumInt8Struct
impl Copy for StrictEnumInt8Struct
impl Eq for StrictEnumInt8Struct
impl StructuralPartialEq for StrictEnumInt8Struct