pub struct StringUnionStructWrapper {
pub sus: StringUnionStruct,
}Fields
sus: StringUnionStructTrait Implementations
Sourceimpl Clone for StringUnionStructWrapper
impl Clone for StringUnionStructWrapper
Sourcefn clone(&self) -> StringUnionStructWrapper
fn clone(&self) -> StringUnionStructWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StringUnionStructWrapper> for StringUnionStructWrapper
impl CompatFrom<StringUnionStructWrapper> for StringUnionStructWrapper
Sourcefn compat_from(value: StringUnionStructWrapper) -> Self
fn compat_from(value: StringUnionStructWrapper) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StringUnionStructWrapper> for StringUnionStructWrapper
impl CompatFrom<StringUnionStructWrapper> for StringUnionStructWrapper
Sourcefn compat_from(value: StringUnionStructWrapper) -> Self
fn compat_from(value: StringUnionStructWrapper) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StringUnionStructWrapper
impl Debug for StringUnionStructWrapper
Sourceimpl<'a, ___E> Encode<StringUnionStructWrapper<'static>, ___E> for &'a StringUnionStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StringUnionStructWrapper<'static>, ___E> for &'a StringUnionStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringUnionStructWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringUnionStructWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StringUnionStructWrapper<'static>, ___E> for StringUnionStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StringUnionStructWrapper<'static>, ___E> for StringUnionStructWrapperwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringUnionStructWrapper<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringUnionStructWrapper<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StringUnionStructWrapper<'static>>, ___E> for &'a StringUnionStructWrapperwhere
___E: Encoder + ?Sized,
&'a StringUnionStructWrapper: Encode<StringUnionStructWrapper<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StringUnionStructWrapper<'static>>, ___E> for &'a StringUnionStructWrapperwhere
___E: Encoder + ?Sized,
&'a StringUnionStructWrapper: Encode<StringUnionStructWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringUnionStructWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringUnionStructWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StringUnionStructWrapper<'static>>, ___E> for StringUnionStructWrapperwhere
___E: Encoder + ?Sized,
StringUnionStructWrapper: Encode<StringUnionStructWrapper<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StringUnionStructWrapper<'static>>, ___E> for StringUnionStructWrapperwhere
___E: Encoder + ?Sized,
StringUnionStructWrapper: Encode<StringUnionStructWrapper<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringUnionStructWrapper<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringUnionStructWrapper<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StringUnionStructWrapper<'de>> for StringUnionStructWrapper
impl<'de> FromWire<StringUnionStructWrapper<'de>> for StringUnionStructWrapper
Sourcefn from_wire(wire: StringUnionStructWrapper<'de>) -> Self
fn from_wire(wire: StringUnionStructWrapper<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StringUnionStructWrapper<'de>> for StringUnionStructWrapper
impl<'de> FromWireRef<StringUnionStructWrapper<'de>> for StringUnionStructWrapper
Sourcefn from_wire_ref(wire: &StringUnionStructWrapper<'de>) -> Self
fn from_wire_ref(wire: &StringUnionStructWrapper<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StringUnionStructWrapper
impl Hash for StringUnionStructWrapper
Sourceimpl Ord for StringUnionStructWrapper
impl Ord for StringUnionStructWrapper
Sourcefn cmp(&self, other: &StringUnionStructWrapper) -> Ordering
fn cmp(&self, other: &StringUnionStructWrapper) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringUnionStructWrapper
impl PartialEq for StringUnionStructWrapper
Sourceimpl PartialOrd for StringUnionStructWrapper
impl PartialOrd for StringUnionStructWrapper
impl Eq for StringUnionStructWrapper
impl StructuralPartialEq for StringUnionStructWrapper