pub struct StringWithLimitInTable {
pub t: TableWithStringWithLimit,
}Fields
t: TableWithStringWithLimitTrait Implementations
Sourceimpl Clone for StringWithLimitInTable
impl Clone for StringWithLimitInTable
Sourcefn clone(&self) -> StringWithLimitInTable
fn clone(&self) -> StringWithLimitInTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StringWithLimitInTable> for StringWithLimitInTable
impl CompatFrom<StringWithLimitInTable> for StringWithLimitInTable
Sourcefn compat_from(value: StringWithLimitInTable) -> Self
fn compat_from(value: StringWithLimitInTable) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StringWithLimitInTable> for StringWithLimitInTable
impl CompatFrom<StringWithLimitInTable> for StringWithLimitInTable
Sourcefn compat_from(value: StringWithLimitInTable) -> Self
fn compat_from(value: StringWithLimitInTable) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StringWithLimitInTable
impl Debug for StringWithLimitInTable
Sourceimpl<'a, ___E> Encode<StringWithLimitInTable<'static>, ___E> for &'a StringWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StringWithLimitInTable<'static>, ___E> for &'a StringWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StringWithLimitInTable<'static>, ___E> for StringWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StringWithLimitInTable<'static>, ___E> for StringWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StringWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StringWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInTable<'static>>, ___E> for &'a StringWithLimitInTablewhere
___E: Encoder + ?Sized,
&'a StringWithLimitInTable: Encode<StringWithLimitInTable<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StringWithLimitInTable<'static>>, ___E> for &'a StringWithLimitInTablewhere
___E: Encoder + ?Sized,
&'a StringWithLimitInTable: Encode<StringWithLimitInTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StringWithLimitInTable<'static>>, ___E> for StringWithLimitInTablewhere
___E: Encoder + ?Sized,
StringWithLimitInTable: Encode<StringWithLimitInTable<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, StringWithLimitInTable<'static>>, ___E> for StringWithLimitInTablewhere
___E: Encoder + ?Sized,
StringWithLimitInTable: Encode<StringWithLimitInTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StringWithLimitInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StringWithLimitInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StringWithLimitInTable<'de>> for StringWithLimitInTable
impl<'de> FromWire<StringWithLimitInTable<'de>> for StringWithLimitInTable
Sourcefn from_wire(wire: StringWithLimitInTable<'de>) -> Self
fn from_wire(wire: StringWithLimitInTable<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StringWithLimitInTable<'de>> for StringWithLimitInTable
impl<'de> FromWireRef<StringWithLimitInTable<'de>> for StringWithLimitInTable
Sourcefn from_wire_ref(wire: &StringWithLimitInTable<'de>) -> Self
fn from_wire_ref(wire: &StringWithLimitInTable<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StringWithLimitInTable
impl Hash for StringWithLimitInTable
Sourceimpl Ord for StringWithLimitInTable
impl Ord for StringWithLimitInTable
Sourcefn cmp(&self, other: &StringWithLimitInTable) -> Ordering
fn cmp(&self, other: &StringWithLimitInTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StringWithLimitInTable
impl PartialEq for StringWithLimitInTable
Sourceimpl PartialOrd for StringWithLimitInTable
impl PartialOrd for StringWithLimitInTable
impl Eq for StringWithLimitInTable
impl StructuralPartialEq for StringWithLimitInTable