#[repr(C)]pub struct Struct2Byte {
pub a: i16,
}Fields
a: i16Trait Implementations
Sourceimpl Clone for Struct2Byte
impl Clone for Struct2Byte
Sourcefn clone(&self) -> Struct2Byte
fn clone(&self) -> Struct2Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Struct2Byte> for Struct2Byte
impl CompatFrom<Struct2Byte> for Struct2Byte
Sourcefn compat_from(value: Struct2Byte) -> Self
fn compat_from(value: Struct2Byte) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Struct2Byte> for Struct2Byte
impl CompatFrom<Struct2Byte> for Struct2Byte
Sourcefn compat_from(value: Struct2Byte) -> Self
fn compat_from(value: Struct2Byte) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Struct2Byte
impl Debug for Struct2Byte
Sourceimpl<'a, ___E> Encode<Struct2Byte, ___E> for &'a Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct2Byte, ___E> for &'a Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct2Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct2Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct2Byte, ___E> for Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct2Byte, ___E> for Struct2Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Struct2Byte>
const COPY_OPTIMIZATION: CopyOptimization<Self, Struct2Byte>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct2Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct2Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Struct2Byte>, ___E> for &'a Struct2Byte
impl<'a, ___E> EncodeOption<Box<'static, Struct2Byte>, ___E> for &'a Struct2Byte
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct2Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct2Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Struct2Byte>, ___E> for Struct2Byte
impl<___E> EncodeOption<Box<'static, Struct2Byte>, ___E> for Struct2Byte
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Struct2Byte>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Struct2Byte>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Struct2Byte> for Struct2Byte
impl FromWire<Struct2Byte> for Struct2Byte
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Self>
const COPY_OPTIMIZATION: CopyOptimization<Struct2Byte, Self>
Sourcefn from_wire(wire: Struct2Byte) -> Self
fn from_wire(wire: Struct2Byte) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Struct2Byte> for Struct2Byte
impl FromWireRef<Struct2Byte> for Struct2Byte
Sourcefn from_wire_ref(wire: &Struct2Byte) -> Self
fn from_wire_ref(wire: &Struct2Byte) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Struct2Byte
impl Hash for Struct2Byte
Sourceimpl Ord for Struct2Byte
impl Ord for Struct2Byte
Sourcefn cmp(&self, other: &Struct2Byte) -> Ordering
fn cmp(&self, other: &Struct2Byte) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Struct2Byte
impl PartialEq for Struct2Byte
Sourceimpl PartialOrd for Struct2Byte
impl PartialOrd for Struct2Byte
impl Copy for Struct2Byte
impl Eq for Struct2Byte
impl StructuralPartialEq for Struct2Byte