pub struct StructOfEmptyTable {
pub table: EmptyTable,
}Fields
table: EmptyTableTrait Implementations
Sourceimpl Clone for StructOfEmptyTable
impl Clone for StructOfEmptyTable
Sourcefn clone(&self) -> StructOfEmptyTable
fn clone(&self) -> StructOfEmptyTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfEmptyTable> for StructOfEmptyTable
impl CompatFrom<StructOfEmptyTable> for StructOfEmptyTable
Sourcefn compat_from(value: StructOfEmptyTable) -> Self
fn compat_from(value: StructOfEmptyTable) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StructOfEmptyTable> for StructOfEmptyTable
impl CompatFrom<StructOfEmptyTable> for StructOfEmptyTable
Sourcefn compat_from(value: StructOfEmptyTable) -> Self
fn compat_from(value: StructOfEmptyTable) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StructOfEmptyTable
impl Debug for StructOfEmptyTable
Sourceimpl<'a, ___E> Encode<StructOfEmptyTable<'static>, ___E> for &'a StructOfEmptyTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructOfEmptyTable<'static>, ___E> for &'a StructOfEmptyTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfEmptyTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfEmptyTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfEmptyTable<'static>, ___E> for StructOfEmptyTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructOfEmptyTable<'static>, ___E> for StructOfEmptyTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfEmptyTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfEmptyTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfEmptyTable<'static>>, ___E> for &'a StructOfEmptyTable
impl<'a, ___E> EncodeOption<Box<'static, StructOfEmptyTable<'static>>, ___E> for &'a StructOfEmptyTable
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfEmptyTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfEmptyTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfEmptyTable<'static>>, ___E> for StructOfEmptyTable
impl<___E> EncodeOption<Box<'static, StructOfEmptyTable<'static>>, ___E> for StructOfEmptyTable
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfEmptyTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfEmptyTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfEmptyTable<'de>> for StructOfEmptyTable
impl<'de> FromWire<StructOfEmptyTable<'de>> for StructOfEmptyTable
Sourcefn from_wire(wire: StructOfEmptyTable<'de>) -> Self
fn from_wire(wire: StructOfEmptyTable<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfEmptyTable<'de>> for StructOfEmptyTable
impl<'de> FromWireRef<StructOfEmptyTable<'de>> for StructOfEmptyTable
Sourcefn from_wire_ref(wire: &StructOfEmptyTable<'de>) -> Self
fn from_wire_ref(wire: &StructOfEmptyTable<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StructOfEmptyTable
impl Hash for StructOfEmptyTable
Sourceimpl Ord for StructOfEmptyTable
impl Ord for StructOfEmptyTable
Sourcefn cmp(&self, other: &StructOfEmptyTable) -> Ordering
fn cmp(&self, other: &StructOfEmptyTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfEmptyTable
impl PartialEq for StructOfEmptyTable
Sourceimpl PartialOrd for StructOfEmptyTable
impl PartialOrd for StructOfEmptyTable
impl Copy for StructOfEmptyTable
impl Eq for StructOfEmptyTable
impl StructuralPartialEq for StructOfEmptyTable