pub struct StructOfTableWithGaps {
pub table: TableWithGaps,
}Fields
table: TableWithGapsTrait Implementations
Sourceimpl Clone for StructOfTableWithGaps
impl Clone for StructOfTableWithGaps
Sourcefn clone(&self) -> StructOfTableWithGaps
fn clone(&self) -> StructOfTableWithGaps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfTableWithGaps> for StructOfTableWithGaps
impl CompatFrom<StructOfTableWithGaps> for StructOfTableWithGaps
Sourcefn compat_from(value: StructOfTableWithGaps) -> Self
fn compat_from(value: StructOfTableWithGaps) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StructOfTableWithGaps> for StructOfTableWithGaps
impl CompatFrom<StructOfTableWithGaps> for StructOfTableWithGaps
Sourcefn compat_from(value: StructOfTableWithGaps) -> Self
fn compat_from(value: StructOfTableWithGaps) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StructOfTableWithGaps
impl Debug for StructOfTableWithGaps
Sourceimpl<'a, ___E> Encode<StructOfTableWithGaps<'static>, ___E> for &'a StructOfTableWithGapswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructOfTableWithGaps<'static>, ___E> for &'a StructOfTableWithGapswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithGaps<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithGaps<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfTableWithGaps<'static>, ___E> for StructOfTableWithGapswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructOfTableWithGaps<'static>, ___E> for StructOfTableWithGapswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfTableWithGaps<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfTableWithGaps<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithGaps<'static>>, ___E> for &'a StructOfTableWithGapswhere
___E: Encoder + ?Sized,
&'a StructOfTableWithGaps: Encode<StructOfTableWithGaps<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StructOfTableWithGaps<'static>>, ___E> for &'a StructOfTableWithGapswhere
___E: Encoder + ?Sized,
&'a StructOfTableWithGaps: Encode<StructOfTableWithGaps<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithGaps<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithGaps<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfTableWithGaps<'static>>, ___E> for StructOfTableWithGaps
impl<___E> EncodeOption<Box<'static, StructOfTableWithGaps<'static>>, ___E> for StructOfTableWithGaps
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfTableWithGaps<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfTableWithGaps<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfTableWithGaps<'de>> for StructOfTableWithGaps
impl<'de> FromWire<StructOfTableWithGaps<'de>> for StructOfTableWithGaps
Sourcefn from_wire(wire: StructOfTableWithGaps<'de>) -> Self
fn from_wire(wire: StructOfTableWithGaps<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfTableWithGaps<'de>> for StructOfTableWithGaps
impl<'de> FromWireRef<StructOfTableWithGaps<'de>> for StructOfTableWithGaps
Sourcefn from_wire_ref(wire: &StructOfTableWithGaps<'de>) -> Self
fn from_wire_ref(wire: &StructOfTableWithGaps<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StructOfTableWithGaps
impl Hash for StructOfTableWithGaps
Sourceimpl Ord for StructOfTableWithGaps
impl Ord for StructOfTableWithGaps
Sourcefn cmp(&self, other: &StructOfTableWithGaps) -> Ordering
fn cmp(&self, other: &StructOfTableWithGaps) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfTableWithGaps
impl PartialEq for StructOfTableWithGaps
Sourceimpl PartialOrd for StructOfTableWithGaps
impl PartialOrd for StructOfTableWithGaps
impl Copy for StructOfTableWithGaps
impl Eq for StructOfTableWithGaps
impl StructuralPartialEq for StructOfTableWithGaps