pub struct StructOfUnionOfTable {
pub u: UnionOfTable,
}Fields
u: UnionOfTableTrait Implementations
Sourceimpl Clone for StructOfUnionOfTable
impl Clone for StructOfUnionOfTable
Sourcefn clone(&self) -> StructOfUnionOfTable
fn clone(&self) -> StructOfUnionOfTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructOfUnionOfTable> for StructOfUnionOfTable
impl CompatFrom<StructOfUnionOfTable> for StructOfUnionOfTable
Sourcefn compat_from(value: StructOfUnionOfTable) -> Self
fn compat_from(value: StructOfUnionOfTable) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StructOfUnionOfTable> for StructOfUnionOfTable
impl CompatFrom<StructOfUnionOfTable> for StructOfUnionOfTable
Sourcefn compat_from(value: StructOfUnionOfTable) -> Self
fn compat_from(value: StructOfUnionOfTable) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StructOfUnionOfTable
impl Debug for StructOfUnionOfTable
Sourceimpl<'a, ___E> Encode<StructOfUnionOfTable<'static>, ___E> for &'a StructOfUnionOfTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructOfUnionOfTable<'static>, ___E> for &'a StructOfUnionOfTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfUnionOfTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfUnionOfTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructOfUnionOfTable<'static>, ___E> for StructOfUnionOfTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructOfUnionOfTable<'static>, ___E> for StructOfUnionOfTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructOfUnionOfTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructOfUnionOfTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructOfUnionOfTable<'static>>, ___E> for &'a StructOfUnionOfTablewhere
___E: Encoder + ?Sized,
&'a StructOfUnionOfTable: Encode<StructOfUnionOfTable<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, StructOfUnionOfTable<'static>>, ___E> for &'a StructOfUnionOfTablewhere
___E: Encoder + ?Sized,
&'a StructOfUnionOfTable: Encode<StructOfUnionOfTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfUnionOfTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfUnionOfTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructOfUnionOfTable<'static>>, ___E> for StructOfUnionOfTable
impl<___E> EncodeOption<Box<'static, StructOfUnionOfTable<'static>>, ___E> for StructOfUnionOfTable
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructOfUnionOfTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructOfUnionOfTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructOfUnionOfTable<'de>> for StructOfUnionOfTable
impl<'de> FromWire<StructOfUnionOfTable<'de>> for StructOfUnionOfTable
Sourcefn from_wire(wire: StructOfUnionOfTable<'de>) -> Self
fn from_wire(wire: StructOfUnionOfTable<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructOfUnionOfTable<'de>> for StructOfUnionOfTable
impl<'de> FromWireRef<StructOfUnionOfTable<'de>> for StructOfUnionOfTable
Sourcefn from_wire_ref(wire: &StructOfUnionOfTable<'de>) -> Self
fn from_wire_ref(wire: &StructOfUnionOfTable<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StructOfUnionOfTable
impl Hash for StructOfUnionOfTable
Sourceimpl Ord for StructOfUnionOfTable
impl Ord for StructOfUnionOfTable
Sourcefn cmp(&self, other: &StructOfUnionOfTable) -> Ordering
fn cmp(&self, other: &StructOfUnionOfTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructOfUnionOfTable
impl PartialEq for StructOfUnionOfTable
Sourceimpl PartialOrd for StructOfUnionOfTable
impl PartialOrd for StructOfUnionOfTable
impl Copy for StructOfUnionOfTable
impl Eq for StructOfUnionOfTable
impl StructuralPartialEq for StructOfUnionOfTable