pub struct StructWithOptionals {
pub s: EmptyStruct,
pub s2: Option<Box<EmptyStruct>>,
pub t: TableWithEmptyStruct,
pub xu: XUnionWithEmptyStruct,
pub xu2: Option<Box<XUnionWithEmptyStruct>>,
pub u: UnionWithEmptyStruct,
pub u2: Option<Box<UnionWithEmptyStruct>>,
}Fields
s: EmptyStructs2: Option<Box<EmptyStruct>>t: TableWithEmptyStructxu: XUnionWithEmptyStructxu2: Option<Box<XUnionWithEmptyStruct>>u: UnionWithEmptyStructu2: Option<Box<UnionWithEmptyStruct>>Trait Implementations
Sourceimpl Clone for StructWithOptionals
impl Clone for StructWithOptionals
Sourcefn clone(&self) -> StructWithOptionals
fn clone(&self) -> StructWithOptionals
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructWithOptionals> for StructWithOptionals
impl CompatFrom<StructWithOptionals> for StructWithOptionals
Sourcefn compat_from(value: StructWithOptionals) -> Self
fn compat_from(value: StructWithOptionals) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StructWithOptionals> for StructWithOptionals
impl CompatFrom<StructWithOptionals> for StructWithOptionals
Sourcefn compat_from(value: StructWithOptionals) -> Self
fn compat_from(value: StructWithOptionals) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StructWithOptionals
impl Debug for StructWithOptionals
Sourceimpl<'a, ___E> Encode<StructWithOptionals<'static>, ___E> for &'a StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructWithOptionals<'static>, ___E> for &'a StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithOptionals<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithOptionals<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithOptionals<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithOptionals<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructWithOptionals<'static>>, ___E> for &'a StructWithOptionals
impl<'a, ___E> EncodeOption<Box<'static, StructWithOptionals<'static>>, ___E> for &'a StructWithOptionals
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithOptionals<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithOptionals<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructWithOptionals<'static>>, ___E> for StructWithOptionals
impl<___E> EncodeOption<Box<'static, StructWithOptionals<'static>>, ___E> for StructWithOptionals
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithOptionals<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithOptionals<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructWithOptionals<'de>> for StructWithOptionals
impl<'de> FromWire<StructWithOptionals<'de>> for StructWithOptionals
Sourcefn from_wire(wire: StructWithOptionals<'de>) -> Self
fn from_wire(wire: StructWithOptionals<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructWithOptionals<'de>> for StructWithOptionals
impl<'de> FromWireRef<StructWithOptionals<'de>> for StructWithOptionals
Sourcefn from_wire_ref(wire: &StructWithOptionals<'de>) -> Self
fn from_wire_ref(wire: &StructWithOptionals<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StructWithOptionals
impl Hash for StructWithOptionals
Sourceimpl Ord for StructWithOptionals
impl Ord for StructWithOptionals
Sourcefn cmp(&self, other: &StructWithOptionals) -> Ordering
fn cmp(&self, other: &StructWithOptionals) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructWithOptionals
impl PartialEq for StructWithOptionals
Sourceimpl PartialOrd for StructWithOptionals
impl PartialOrd for StructWithOptionals
impl Eq for StructWithOptionals
impl StructuralPartialEq for StructWithOptionals