pub struct StructWithVectors {
pub vec_empty: Vec<i32>,
pub vec_int: Vec<i32>,
pub vec_string: Vec<String>,
pub vec_nullable_string: Vec<Option<String>>,
pub vec_struct: Vec<StructWithInt>,
pub vec_nullable_struct: Vec<Option<Box<StructWithInt>>>,
pub vec_vec_int: Vec<Vec<i32>>,
}Fields
vec_empty: Vec<i32>vec_int: Vec<i32>vec_string: Vec<String>vec_nullable_string: Vec<Option<String>>vec_struct: Vec<StructWithInt>vec_nullable_struct: Vec<Option<Box<StructWithInt>>>vec_vec_int: Vec<Vec<i32>>Trait Implementations
Sourceimpl Clone for StructWithVectors
impl Clone for StructWithVectors
Sourcefn clone(&self) -> StructWithVectors
fn clone(&self) -> StructWithVectors
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<StructWithVectors> for StructWithVectors
impl CompatFrom<StructWithVectors> for StructWithVectors
Sourcefn compat_from(value: StructWithVectors) -> Self
fn compat_from(value: StructWithVectors) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<StructWithVectors> for StructWithVectors
impl CompatFrom<StructWithVectors> for StructWithVectors
Sourcefn compat_from(value: StructWithVectors) -> Self
fn compat_from(value: StructWithVectors) -> Self
Converts
value into a value of this type.Sourceimpl Debug for StructWithVectors
impl Debug for StructWithVectors
Sourceimpl<'a, ___E> Encode<StructWithVectors<'static>, ___E> for &'a StructWithVectorswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructWithVectors<'static>, ___E> for &'a StructWithVectorswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithVectors<'static>, ___E> for StructWithVectorswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructWithVectors<'static>, ___E> for StructWithVectorswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithVectors<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithVectors<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, StructWithVectors<'static>>, ___E> for &'a StructWithVectors
impl<'a, ___E> EncodeOption<Box<'static, StructWithVectors<'static>>, ___E> for &'a StructWithVectors
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithVectors<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithVectors<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, StructWithVectors<'static>>, ___E> for StructWithVectors
impl<___E> EncodeOption<Box<'static, StructWithVectors<'static>>, ___E> for StructWithVectors
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, StructWithVectors<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, StructWithVectors<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<StructWithVectors<'de>> for StructWithVectors
impl<'de> FromWire<StructWithVectors<'de>> for StructWithVectors
Sourcefn from_wire(wire: StructWithVectors<'de>) -> Self
fn from_wire(wire: StructWithVectors<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructWithVectors<'de>> for StructWithVectors
impl<'de> FromWireRef<StructWithVectors<'de>> for StructWithVectors
Sourcefn from_wire_ref(wire: &StructWithVectors<'de>) -> Self
fn from_wire_ref(wire: &StructWithVectors<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for StructWithVectors
impl Hash for StructWithVectors
Sourceimpl Ord for StructWithVectors
impl Ord for StructWithVectors
Sourcefn cmp(&self, other: &StructWithVectors) -> Ordering
fn cmp(&self, other: &StructWithVectors) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for StructWithVectors
impl PartialEq for StructWithVectors
Sourceimpl PartialOrd for StructWithVectors
impl PartialOrd for StructWithVectors
impl Eq for StructWithVectors
impl StructuralPartialEq for StructWithVectors