pub struct TableWithReservedFieldThenUnionStruct {
pub t: TableWithReservedFieldThenUnion,
}Fields
t: TableWithReservedFieldThenUnionTrait Implementations
Sourceimpl Clone for TableWithReservedFieldThenUnionStruct
impl Clone for TableWithReservedFieldThenUnionStruct
Sourcefn clone(&self) -> TableWithReservedFieldThenUnionStruct
fn clone(&self) -> TableWithReservedFieldThenUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TableWithReservedFieldThenUnionStruct> for TableWithReservedFieldThenUnionStruct
impl CompatFrom<TableWithReservedFieldThenUnionStruct> for TableWithReservedFieldThenUnionStruct
Sourcefn compat_from(value: TableWithReservedFieldThenUnionStruct) -> Self
fn compat_from(value: TableWithReservedFieldThenUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TableWithReservedFieldThenUnionStruct> for TableWithReservedFieldThenUnionStruct
impl CompatFrom<TableWithReservedFieldThenUnionStruct> for TableWithReservedFieldThenUnionStruct
Sourcefn compat_from(value: TableWithReservedFieldThenUnionStruct) -> Self
fn compat_from(value: TableWithReservedFieldThenUnionStruct) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TableWithReservedFieldThenUnionStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: Encoder + ?Sized,
&'a TableWithReservedFieldThenUnionStruct: Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>, ___E> for &'a TableWithReservedFieldThenUnionStructwhere
___E: Encoder + ?Sized,
&'a TableWithReservedFieldThenUnionStruct: Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: Encoder + ?Sized,
TableWithReservedFieldThenUnionStruct: Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>, ___E> for TableWithReservedFieldThenUnionStructwhere
___E: Encoder + ?Sized,
TableWithReservedFieldThenUnionStruct: Encode<TableWithReservedFieldThenUnionStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TableWithReservedFieldThenUnionStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
impl<'de> FromWire<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
Sourcefn from_wire(wire: TableWithReservedFieldThenUnionStruct<'de>) -> Self
fn from_wire(wire: TableWithReservedFieldThenUnionStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
impl<'de> FromWireRef<TableWithReservedFieldThenUnionStruct<'de>> for TableWithReservedFieldThenUnionStruct
Sourcefn from_wire_ref(wire: &TableWithReservedFieldThenUnionStruct<'de>) -> Self
fn from_wire_ref(wire: &TableWithReservedFieldThenUnionStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for TableWithReservedFieldThenUnionStruct
impl Ord for TableWithReservedFieldThenUnionStruct
Sourcefn cmp(&self, other: &TableWithReservedFieldThenUnionStruct) -> Ordering
fn cmp(&self, other: &TableWithReservedFieldThenUnionStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TableWithReservedFieldThenUnionStruct
impl PartialEq for TableWithReservedFieldThenUnionStruct
Sourcefn eq(&self, other: &TableWithReservedFieldThenUnionStruct) -> bool
fn eq(&self, other: &TableWithReservedFieldThenUnionStruct) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TableWithReservedFieldThenUnionStruct
impl PartialOrd for TableWithReservedFieldThenUnionStruct
impl Copy for TableWithReservedFieldThenUnionStruct
impl Eq for TableWithReservedFieldThenUnionStruct
impl StructuralPartialEq for TableWithReservedFieldThenUnionStruct