pub struct TestOptionalXUnionInStruct {
pub before: String,
pub xu: Option<Box<SampleXUnion>>,
pub after: String,
}Fields
before: Stringxu: Option<Box<SampleXUnion>>after: StringTrait Implementations
Sourceimpl Clone for TestOptionalXUnionInStruct
impl Clone for TestOptionalXUnionInStruct
Sourcefn clone(&self) -> TestOptionalXUnionInStruct
fn clone(&self) -> TestOptionalXUnionInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TestOptionalXUnionInStruct> for TestOptionalXUnionInStruct
impl CompatFrom<TestOptionalXUnionInStruct> for TestOptionalXUnionInStruct
Sourcefn compat_from(value: TestOptionalXUnionInStruct) -> Self
fn compat_from(value: TestOptionalXUnionInStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TestOptionalXUnionInStruct> for TestOptionalXUnionInStruct
impl CompatFrom<TestOptionalXUnionInStruct> for TestOptionalXUnionInStruct
Sourcefn compat_from(value: TestOptionalXUnionInStruct) -> Self
fn compat_from(value: TestOptionalXUnionInStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for TestOptionalXUnionInStruct
impl Debug for TestOptionalXUnionInStruct
Sourceimpl<'a, ___E> Encode<TestOptionalXUnionInStruct<'static>, ___E> for &'a TestOptionalXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<TestOptionalXUnionInStruct<'static>, ___E> for &'a TestOptionalXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestOptionalXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestOptionalXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TestOptionalXUnionInStruct<'static>, ___E> for TestOptionalXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<TestOptionalXUnionInStruct<'static>, ___E> for TestOptionalXUnionInStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TestOptionalXUnionInStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TestOptionalXUnionInStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TestOptionalXUnionInStruct<'static>>, ___E> for &'a TestOptionalXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestOptionalXUnionInStruct: Encode<TestOptionalXUnionInStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TestOptionalXUnionInStruct<'static>>, ___E> for &'a TestOptionalXUnionInStructwhere
___E: Encoder + ?Sized,
&'a TestOptionalXUnionInStruct: Encode<TestOptionalXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestOptionalXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestOptionalXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TestOptionalXUnionInStruct<'static>>, ___E> for TestOptionalXUnionInStructwhere
___E: Encoder + ?Sized,
TestOptionalXUnionInStruct: Encode<TestOptionalXUnionInStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, TestOptionalXUnionInStruct<'static>>, ___E> for TestOptionalXUnionInStructwhere
___E: Encoder + ?Sized,
TestOptionalXUnionInStruct: Encode<TestOptionalXUnionInStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TestOptionalXUnionInStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TestOptionalXUnionInStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<TestOptionalXUnionInStruct<'de>> for TestOptionalXUnionInStruct
impl<'de> FromWire<TestOptionalXUnionInStruct<'de>> for TestOptionalXUnionInStruct
Sourcefn from_wire(wire: TestOptionalXUnionInStruct<'de>) -> Self
fn from_wire(wire: TestOptionalXUnionInStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TestOptionalXUnionInStruct<'de>> for TestOptionalXUnionInStruct
impl<'de> FromWireRef<TestOptionalXUnionInStruct<'de>> for TestOptionalXUnionInStruct
Sourcefn from_wire_ref(wire: &TestOptionalXUnionInStruct<'de>) -> Self
fn from_wire_ref(wire: &TestOptionalXUnionInStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for TestOptionalXUnionInStruct
impl Hash for TestOptionalXUnionInStruct
Sourceimpl Ord for TestOptionalXUnionInStruct
impl Ord for TestOptionalXUnionInStruct
Sourcefn cmp(&self, other: &TestOptionalXUnionInStruct) -> Ordering
fn cmp(&self, other: &TestOptionalXUnionInStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for TestOptionalXUnionInStruct
impl PartialOrd for TestOptionalXUnionInStruct
impl Eq for TestOptionalXUnionInStruct
impl StructuralPartialEq for TestOptionalXUnionInStruct