pub struct ThreeByteInVector {
pub elems: Vec<ThreeByte>,
}Fields
elems: Vec<ThreeByte>Trait Implementations
Sourceimpl Clone for ThreeByteInVector
impl Clone for ThreeByteInVector
Sourcefn clone(&self) -> ThreeByteInVector
fn clone(&self) -> ThreeByteInVector
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<ThreeByteInVector> for ThreeByteInVector
impl CompatFrom<ThreeByteInVector> for ThreeByteInVector
Sourcefn compat_from(value: ThreeByteInVector) -> Self
fn compat_from(value: ThreeByteInVector) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<ThreeByteInVector> for ThreeByteInVector
impl CompatFrom<ThreeByteInVector> for ThreeByteInVector
Sourcefn compat_from(value: ThreeByteInVector) -> Self
fn compat_from(value: ThreeByteInVector) -> Self
Converts
value into a value of this type.Sourceimpl Debug for ThreeByteInVector
impl Debug for ThreeByteInVector
Sourceimpl<'a, ___E> Encode<ThreeByteInVector<'static>, ___E> for &'a ThreeByteInVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ThreeByteInVector<'static>, ___E> for &'a ThreeByteInVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ThreeByteInVector<'static>, ___E> for ThreeByteInVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ThreeByteInVector<'static>, ___E> for ThreeByteInVectorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInVector<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInVector<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ThreeByteInVector<'static>>, ___E> for &'a ThreeByteInVector
impl<'a, ___E> EncodeOption<Box<'static, ThreeByteInVector<'static>>, ___E> for &'a ThreeByteInVector
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ThreeByteInVector<'static>>, ___E> for ThreeByteInVector
impl<___E> EncodeOption<Box<'static, ThreeByteInVector<'static>>, ___E> for ThreeByteInVector
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ThreeByteInVector<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ThreeByteInVector<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ThreeByteInVector<'de>> for ThreeByteInVector
impl<'de> FromWire<ThreeByteInVector<'de>> for ThreeByteInVector
Sourcefn from_wire(wire: ThreeByteInVector<'de>) -> Self
fn from_wire(wire: ThreeByteInVector<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ThreeByteInVector<'de>> for ThreeByteInVector
impl<'de> FromWireRef<ThreeByteInVector<'de>> for ThreeByteInVector
Sourcefn from_wire_ref(wire: &ThreeByteInVector<'de>) -> Self
fn from_wire_ref(wire: &ThreeByteInVector<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ThreeByteInVector
impl Hash for ThreeByteInVector
Sourceimpl Ord for ThreeByteInVector
impl Ord for ThreeByteInVector
Sourcefn cmp(&self, other: &ThreeByteInVector) -> Ordering
fn cmp(&self, other: &ThreeByteInVector) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ThreeByteInVector
impl PartialEq for ThreeByteInVector
Sourceimpl PartialOrd for ThreeByteInVector
impl PartialOrd for ThreeByteInVector
impl Eq for ThreeByteInVector
impl StructuralPartialEq for ThreeByteInVector