pub struct TwoLayerStructInnerPaddingAlign4 {
pub s: OneLayerStructWithPaddingAlign4,
pub a: u32,
}Fields
s: OneLayerStructWithPaddingAlign4a: u32Trait Implementations
Sourceimpl Clone for TwoLayerStructInnerPaddingAlign4
impl Clone for TwoLayerStructInnerPaddingAlign4
Sourcefn clone(&self) -> TwoLayerStructInnerPaddingAlign4
fn clone(&self) -> TwoLayerStructInnerPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl CompatFrom<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn compat_from(value: TwoLayerStructInnerPaddingAlign4) -> Self
fn compat_from(value: TwoLayerStructInnerPaddingAlign4) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl CompatFrom<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn compat_from(value: TwoLayerStructInnerPaddingAlign4) -> Self
fn compat_from(value: TwoLayerStructInnerPaddingAlign4) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign4>, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: Encoder + ?Sized,
&'a TwoLayerStructInnerPaddingAlign4: Encode<TwoLayerStructInnerPaddingAlign4, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign4>, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: Encoder + ?Sized,
&'a TwoLayerStructInnerPaddingAlign4: Encode<TwoLayerStructInnerPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign4>, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: Encoder + ?Sized,
TwoLayerStructInnerPaddingAlign4: Encode<TwoLayerStructInnerPaddingAlign4, ___E>,
impl<___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign4>, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: Encoder + ?Sized,
TwoLayerStructInnerPaddingAlign4: Encode<TwoLayerStructInnerPaddingAlign4, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign4>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign4>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl FromWire<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn from_wire(wire: TwoLayerStructInnerPaddingAlign4) -> Self
fn from_wire(wire: TwoLayerStructInnerPaddingAlign4) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl FromWireRef<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign4) -> Self
fn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign4) -> Self
Converts the given reference to this type.
Sourceimpl Ord for TwoLayerStructInnerPaddingAlign4
impl Ord for TwoLayerStructInnerPaddingAlign4
Sourcefn cmp(&self, other: &TwoLayerStructInnerPaddingAlign4) -> Ordering
fn cmp(&self, other: &TwoLayerStructInnerPaddingAlign4) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TwoLayerStructInnerPaddingAlign4
impl PartialEq for TwoLayerStructInnerPaddingAlign4
Sourcefn eq(&self, other: &TwoLayerStructInnerPaddingAlign4) -> bool
fn eq(&self, other: &TwoLayerStructInnerPaddingAlign4) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TwoLayerStructInnerPaddingAlign4
impl PartialOrd for TwoLayerStructInnerPaddingAlign4
impl Copy for TwoLayerStructInnerPaddingAlign4
impl Eq for TwoLayerStructInnerPaddingAlign4
impl StructuralPartialEq for TwoLayerStructInnerPaddingAlign4