pub struct TwoLayerStructInnerPaddingAlign8 {
pub s: OneLayerStructWithPaddingAlign8,
pub a: u64,
}Fields
s: OneLayerStructWithPaddingAlign8a: u64Trait Implementations
Sourceimpl Clone for TwoLayerStructInnerPaddingAlign8
impl Clone for TwoLayerStructInnerPaddingAlign8
Sourcefn clone(&self) -> TwoLayerStructInnerPaddingAlign8
fn clone(&self) -> TwoLayerStructInnerPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl CompatFrom<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn compat_from(value: TwoLayerStructInnerPaddingAlign8) -> Self
fn compat_from(value: TwoLayerStructInnerPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl CompatFrom<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn compat_from(value: TwoLayerStructInnerPaddingAlign8) -> Self
fn compat_from(value: TwoLayerStructInnerPaddingAlign8) -> Self
Converts
value into a value of this type.Sourceimpl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign8>, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: Encoder + ?Sized,
&'a TwoLayerStructInnerPaddingAlign8: Encode<TwoLayerStructInnerPaddingAlign8, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign8>, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: Encoder + ?Sized,
&'a TwoLayerStructInnerPaddingAlign8: Encode<TwoLayerStructInnerPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign8>, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: Encoder + ?Sized,
TwoLayerStructInnerPaddingAlign8: Encode<TwoLayerStructInnerPaddingAlign8, ___E>,
impl<___E> EncodeOption<Box<'static, TwoLayerStructInnerPaddingAlign8>, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: Encoder + ?Sized,
TwoLayerStructInnerPaddingAlign8: Encode<TwoLayerStructInnerPaddingAlign8, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TwoLayerStructInnerPaddingAlign8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl FromWire<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn from_wire(wire: TwoLayerStructInnerPaddingAlign8) -> Self
fn from_wire(wire: TwoLayerStructInnerPaddingAlign8) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl FromWireRef<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign8) -> Self
fn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl Ord for TwoLayerStructInnerPaddingAlign8
impl Ord for TwoLayerStructInnerPaddingAlign8
Sourcefn cmp(&self, other: &TwoLayerStructInnerPaddingAlign8) -> Ordering
fn cmp(&self, other: &TwoLayerStructInnerPaddingAlign8) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TwoLayerStructInnerPaddingAlign8
impl PartialEq for TwoLayerStructInnerPaddingAlign8
Sourcefn eq(&self, other: &TwoLayerStructInnerPaddingAlign8) -> bool
fn eq(&self, other: &TwoLayerStructInnerPaddingAlign8) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TwoLayerStructInnerPaddingAlign8
impl PartialOrd for TwoLayerStructInnerPaddingAlign8
impl Copy for TwoLayerStructInnerPaddingAlign8
impl Eq for TwoLayerStructInnerPaddingAlign8
impl StructuralPartialEq for TwoLayerStructInnerPaddingAlign8