#[repr(C)]pub struct Uint16Struct {
pub val: u16,
}Fields
val: u16Trait Implementations
Sourceimpl Clone for Uint16Struct
impl Clone for Uint16Struct
Sourcefn clone(&self) -> Uint16Struct
fn clone(&self) -> Uint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint16Struct> for Uint16Struct
impl CompatFrom<Uint16Struct> for Uint16Struct
Sourcefn compat_from(value: Uint16Struct) -> Self
fn compat_from(value: Uint16Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Uint16Struct> for Uint16Struct
impl CompatFrom<Uint16Struct> for Uint16Struct
Sourcefn compat_from(value: Uint16Struct) -> Self
fn compat_from(value: Uint16Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Uint16Struct
impl Debug for Uint16Struct
Sourceimpl<'a, ___E> Encode<Uint16Struct, ___E> for &'a Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint16Struct, ___E> for &'a Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint16Struct, ___E> for Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint16Struct, ___E> for Uint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Uint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, Uint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint16Struct>, ___E> for &'a Uint16Struct
impl<'a, ___E> EncodeOption<Box<'static, Uint16Struct>, ___E> for &'a Uint16Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint16Struct>, ___E> for Uint16Struct
impl<___E> EncodeOption<Box<'static, Uint16Struct>, ___E> for Uint16Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint16Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint16Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint16Struct> for Uint16Struct
impl FromWire<Uint16Struct> for Uint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<Uint16Struct, Self>
Sourcefn from_wire(wire: Uint16Struct) -> Self
fn from_wire(wire: Uint16Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint16Struct> for Uint16Struct
impl FromWireRef<Uint16Struct> for Uint16Struct
Sourcefn from_wire_ref(wire: &Uint16Struct) -> Self
fn from_wire_ref(wire: &Uint16Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Uint16Struct
impl Hash for Uint16Struct
Sourceimpl Ord for Uint16Struct
impl Ord for Uint16Struct
Sourcefn cmp(&self, other: &Uint16Struct) -> Ordering
fn cmp(&self, other: &Uint16Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint16Struct
impl PartialEq for Uint16Struct
Sourceimpl PartialOrd for Uint16Struct
impl PartialOrd for Uint16Struct
impl Copy for Uint16Struct
impl Eq for Uint16Struct
impl StructuralPartialEq for Uint16Struct