pub struct Uint64Uint32Uint16Uint8 {
pub f1: u64,
pub f2: u32,
pub f3: u16,
pub f4: u8,
}Fields
f1: u64f2: u32f3: u16f4: u8Trait Implementations
Sourceimpl Clone for Uint64Uint32Uint16Uint8
impl Clone for Uint64Uint32Uint16Uint8
Sourcefn clone(&self) -> Uint64Uint32Uint16Uint8
fn clone(&self) -> Uint64Uint32Uint16Uint8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl CompatFrom<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn compat_from(value: Uint64Uint32Uint16Uint8) -> Self
fn compat_from(value: Uint64Uint32Uint16Uint8) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl CompatFrom<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn compat_from(value: Uint64Uint32Uint16Uint8) -> Self
fn compat_from(value: Uint64Uint32Uint16Uint8) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Uint64Uint32Uint16Uint8
impl Debug for Uint64Uint32Uint16Uint8
Sourceimpl<'a, ___E> Encode<Uint64Uint32Uint16Uint8, ___E> for &'a Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint64Uint32Uint16Uint8, ___E> for &'a Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint64Uint32Uint16Uint8, ___E> for Uint64Uint32Uint16Uint8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint64Uint32Uint16Uint8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint64Uint32Uint16Uint8>, ___E> for &'a Uint64Uint32Uint16Uint8
impl<'a, ___E> EncodeOption<Box<'static, Uint64Uint32Uint16Uint8>, ___E> for &'a Uint64Uint32Uint16Uint8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint64Uint32Uint16Uint8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint64Uint32Uint16Uint8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint64Uint32Uint16Uint8>, ___E> for Uint64Uint32Uint16Uint8
impl<___E> EncodeOption<Box<'static, Uint64Uint32Uint16Uint8>, ___E> for Uint64Uint32Uint16Uint8
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint64Uint32Uint16Uint8>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint64Uint32Uint16Uint8>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl FromWire<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn from_wire(wire: Uint64Uint32Uint16Uint8) -> Self
fn from_wire(wire: Uint64Uint32Uint16Uint8) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
impl FromWireRef<Uint64Uint32Uint16Uint8> for Uint64Uint32Uint16Uint8
Sourcefn from_wire_ref(wire: &Uint64Uint32Uint16Uint8) -> Self
fn from_wire_ref(wire: &Uint64Uint32Uint16Uint8) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Uint64Uint32Uint16Uint8
impl Hash for Uint64Uint32Uint16Uint8
Sourceimpl Ord for Uint64Uint32Uint16Uint8
impl Ord for Uint64Uint32Uint16Uint8
Sourcefn cmp(&self, other: &Uint64Uint32Uint16Uint8) -> Ordering
fn cmp(&self, other: &Uint64Uint32Uint16Uint8) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint64Uint32Uint16Uint8
impl PartialEq for Uint64Uint32Uint16Uint8
Sourceimpl PartialOrd for Uint64Uint32Uint16Uint8
impl PartialOrd for Uint64Uint32Uint16Uint8
impl Copy for Uint64Uint32Uint16Uint8
impl Eq for Uint64Uint32Uint16Uint8
impl StructuralPartialEq for Uint64Uint32Uint16Uint8