#[repr(C)]pub struct Uint8Struct {
pub val: u8,
}Fields
val: u8Trait Implementations
Sourceimpl Clone for Uint8Struct
impl Clone for Uint8Struct
Sourcefn clone(&self) -> Uint8Struct
fn clone(&self) -> Uint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<Uint8Struct> for Uint8Struct
impl CompatFrom<Uint8Struct> for Uint8Struct
Sourcefn compat_from(value: Uint8Struct) -> Self
fn compat_from(value: Uint8Struct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<Uint8Struct> for Uint8Struct
impl CompatFrom<Uint8Struct> for Uint8Struct
Sourcefn compat_from(value: Uint8Struct) -> Self
fn compat_from(value: Uint8Struct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for Uint8Struct
impl Debug for Uint8Struct
Sourceimpl<'a, ___E> Encode<Uint8Struct, ___E> for &'a Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8Struct, ___E> for &'a Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8Struct, ___E> for Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8Struct, ___E> for Uint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Uint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, Uint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, Uint8Struct>, ___E> for &'a Uint8Struct
impl<'a, ___E> EncodeOption<Box<'static, Uint8Struct>, ___E> for &'a Uint8Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, Uint8Struct>, ___E> for Uint8Struct
impl<___E> EncodeOption<Box<'static, Uint8Struct>, ___E> for Uint8Struct
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Uint8Struct>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Uint8Struct>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<Uint8Struct> for Uint8Struct
impl FromWire<Uint8Struct> for Uint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<Uint8Struct, Self>
Sourcefn from_wire(wire: Uint8Struct) -> Self
fn from_wire(wire: Uint8Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Uint8Struct> for Uint8Struct
impl FromWireRef<Uint8Struct> for Uint8Struct
Sourcefn from_wire_ref(wire: &Uint8Struct) -> Self
fn from_wire_ref(wire: &Uint8Struct) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Uint8Struct
impl Hash for Uint8Struct
Sourceimpl Ord for Uint8Struct
impl Ord for Uint8Struct
Sourcefn cmp(&self, other: &Uint8Struct) -> Ordering
fn cmp(&self, other: &Uint8Struct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Uint8Struct
impl PartialEq for Uint8Struct
Sourceimpl PartialOrd for Uint8Struct
impl PartialOrd for Uint8Struct
impl Copy for Uint8Struct
impl Eq for Uint8Struct
impl StructuralPartialEq for Uint8Struct