pub struct UnionWithBoundStringStruct {
pub v: UnionWithBoundString,
}Fields
v: UnionWithBoundStringTrait Implementations
Sourceimpl Clone for UnionWithBoundStringStruct
impl Clone for UnionWithBoundStringStruct
Sourcefn clone(&self) -> UnionWithBoundStringStruct
fn clone(&self) -> UnionWithBoundStringStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<UnionWithBoundStringStruct> for UnionWithBoundStringStruct
impl CompatFrom<UnionWithBoundStringStruct> for UnionWithBoundStringStruct
Sourcefn compat_from(value: UnionWithBoundStringStruct) -> Self
fn compat_from(value: UnionWithBoundStringStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<UnionWithBoundStringStruct> for UnionWithBoundStringStruct
impl CompatFrom<UnionWithBoundStringStruct> for UnionWithBoundStringStruct
Sourcefn compat_from(value: UnionWithBoundStringStruct) -> Self
fn compat_from(value: UnionWithBoundStringStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for UnionWithBoundStringStruct
impl Debug for UnionWithBoundStringStruct
Sourceimpl<'a, ___E> Encode<UnionWithBoundStringStruct<'static>, ___E> for &'a UnionWithBoundStringStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<UnionWithBoundStringStruct<'static>, ___E> for &'a UnionWithBoundStringStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnionWithBoundStringStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnionWithBoundStringStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<UnionWithBoundStringStruct<'static>, ___E> for UnionWithBoundStringStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<UnionWithBoundStringStruct<'static>, ___E> for UnionWithBoundStringStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UnionWithBoundStringStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UnionWithBoundStringStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UnionWithBoundStringStruct<'static>>, ___E> for &'a UnionWithBoundStringStructwhere
___E: Encoder + ?Sized,
&'a UnionWithBoundStringStruct: Encode<UnionWithBoundStringStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, UnionWithBoundStringStruct<'static>>, ___E> for &'a UnionWithBoundStringStructwhere
___E: Encoder + ?Sized,
&'a UnionWithBoundStringStruct: Encode<UnionWithBoundStringStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnionWithBoundStringStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnionWithBoundStringStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, UnionWithBoundStringStruct<'static>>, ___E> for UnionWithBoundStringStructwhere
___E: Encoder + ?Sized,
UnionWithBoundStringStruct: Encode<UnionWithBoundStringStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, UnionWithBoundStringStruct<'static>>, ___E> for UnionWithBoundStringStructwhere
___E: Encoder + ?Sized,
UnionWithBoundStringStruct: Encode<UnionWithBoundStringStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UnionWithBoundStringStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UnionWithBoundStringStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<UnionWithBoundStringStruct<'de>> for UnionWithBoundStringStruct
impl<'de> FromWire<UnionWithBoundStringStruct<'de>> for UnionWithBoundStringStruct
Sourcefn from_wire(wire: UnionWithBoundStringStruct<'de>) -> Self
fn from_wire(wire: UnionWithBoundStringStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<UnionWithBoundStringStruct<'de>> for UnionWithBoundStringStruct
impl<'de> FromWireRef<UnionWithBoundStringStruct<'de>> for UnionWithBoundStringStruct
Sourcefn from_wire_ref(wire: &UnionWithBoundStringStruct<'de>) -> Self
fn from_wire_ref(wire: &UnionWithBoundStringStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for UnionWithBoundStringStruct
impl Hash for UnionWithBoundStringStruct
Sourceimpl Ord for UnionWithBoundStringStruct
impl Ord for UnionWithBoundStringStruct
Sourcefn cmp(&self, other: &UnionWithBoundStringStruct) -> Ordering
fn cmp(&self, other: &UnionWithBoundStringStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for UnionWithBoundStringStruct
impl PartialOrd for UnionWithBoundStringStruct
impl Eq for UnionWithBoundStringStruct
impl StructuralPartialEq for UnionWithBoundStringStruct