pub struct VectorWithLimitInTable {
pub t: TableWithVectorWithLimit,
}Fields
t: TableWithVectorWithLimitTrait Implementations
Sourceimpl Clone for VectorWithLimitInTable
impl Clone for VectorWithLimitInTable
Sourcefn clone(&self) -> VectorWithLimitInTable
fn clone(&self) -> VectorWithLimitInTable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<VectorWithLimitInTable> for VectorWithLimitInTable
impl CompatFrom<VectorWithLimitInTable> for VectorWithLimitInTable
Sourcefn compat_from(value: VectorWithLimitInTable) -> Self
fn compat_from(value: VectorWithLimitInTable) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<VectorWithLimitInTable> for VectorWithLimitInTable
impl CompatFrom<VectorWithLimitInTable> for VectorWithLimitInTable
Sourcefn compat_from(value: VectorWithLimitInTable) -> Self
fn compat_from(value: VectorWithLimitInTable) -> Self
Converts
value into a value of this type.Sourceimpl Debug for VectorWithLimitInTable
impl Debug for VectorWithLimitInTable
Sourceimpl<'a, ___E> Encode<VectorWithLimitInTable<'static>, ___E> for &'a VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<VectorWithLimitInTable<'static>, ___E> for &'a VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, VectorWithLimitInTable<'static>>, ___E> for &'a VectorWithLimitInTablewhere
___E: Encoder + ?Sized,
&'a VectorWithLimitInTable: Encode<VectorWithLimitInTable<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, VectorWithLimitInTable<'static>>, ___E> for &'a VectorWithLimitInTablewhere
___E: Encoder + ?Sized,
&'a VectorWithLimitInTable: Encode<VectorWithLimitInTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorWithLimitInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorWithLimitInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, VectorWithLimitInTable<'static>>, ___E> for VectorWithLimitInTablewhere
___E: Encoder + ?Sized,
VectorWithLimitInTable: Encode<VectorWithLimitInTable<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, VectorWithLimitInTable<'static>>, ___E> for VectorWithLimitInTablewhere
___E: Encoder + ?Sized,
VectorWithLimitInTable: Encode<VectorWithLimitInTable<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, VectorWithLimitInTable<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, VectorWithLimitInTable<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
impl<'de> FromWire<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
Sourcefn from_wire(wire: VectorWithLimitInTable<'de>) -> Self
fn from_wire(wire: VectorWithLimitInTable<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
impl<'de> FromWireRef<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
Sourcefn from_wire_ref(wire: &VectorWithLimitInTable<'de>) -> Self
fn from_wire_ref(wire: &VectorWithLimitInTable<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for VectorWithLimitInTable
impl Hash for VectorWithLimitInTable
Sourceimpl Ord for VectorWithLimitInTable
impl Ord for VectorWithLimitInTable
Sourcefn cmp(&self, other: &VectorWithLimitInTable) -> Ordering
fn cmp(&self, other: &VectorWithLimitInTable) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for VectorWithLimitInTable
impl PartialEq for VectorWithLimitInTable
Sourceimpl PartialOrd for VectorWithLimitInTable
impl PartialOrd for VectorWithLimitInTable
impl Eq for VectorWithLimitInTable
impl StructuralPartialEq for VectorWithLimitInTable