pub struct XUnionWithStructStruct {
pub xu: XUnionWithStruct,
}Fields
xu: XUnionWithStructTrait Implementations
Sourceimpl Clone for XUnionWithStructStruct
impl Clone for XUnionWithStructStruct
Sourcefn clone(&self) -> XUnionWithStructStruct
fn clone(&self) -> XUnionWithStructStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompatFrom<XUnionWithStructStruct> for XUnionWithStructStruct
impl CompatFrom<XUnionWithStructStruct> for XUnionWithStructStruct
Sourcefn compat_from(value: XUnionWithStructStruct) -> Self
fn compat_from(value: XUnionWithStructStruct) -> Self
Converts
value into a value of this type.Sourceimpl CompatFrom<XUnionWithStructStruct> for XUnionWithStructStruct
impl CompatFrom<XUnionWithStructStruct> for XUnionWithStructStruct
Sourcefn compat_from(value: XUnionWithStructStruct) -> Self
fn compat_from(value: XUnionWithStructStruct) -> Self
Converts
value into a value of this type.Sourceimpl Debug for XUnionWithStructStruct
impl Debug for XUnionWithStructStruct
Sourceimpl<'a, ___E> Encode<XUnionWithStructStruct<'static>, ___E> for &'a XUnionWithStructStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<XUnionWithStructStruct<'static>, ___E> for &'a XUnionWithStructStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<XUnionWithStructStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<XUnionWithStructStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<XUnionWithStructStruct<'static>, ___E> for XUnionWithStructStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<XUnionWithStructStruct<'static>, ___E> for XUnionWithStructStructwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<XUnionWithStructStruct<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<XUnionWithStructStruct<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, XUnionWithStructStruct<'static>>, ___E> for &'a XUnionWithStructStructwhere
___E: Encoder + ?Sized,
&'a XUnionWithStructStruct: Encode<XUnionWithStructStruct<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, XUnionWithStructStruct<'static>>, ___E> for &'a XUnionWithStructStructwhere
___E: Encoder + ?Sized,
&'a XUnionWithStructStruct: Encode<XUnionWithStructStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, XUnionWithStructStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, XUnionWithStructStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, XUnionWithStructStruct<'static>>, ___E> for XUnionWithStructStructwhere
___E: Encoder + ?Sized,
XUnionWithStructStruct: Encode<XUnionWithStructStruct<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, XUnionWithStructStruct<'static>>, ___E> for XUnionWithStructStructwhere
___E: Encoder + ?Sized,
XUnionWithStructStruct: Encode<XUnionWithStructStruct<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, XUnionWithStructStruct<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, XUnionWithStructStruct<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<XUnionWithStructStruct<'de>> for XUnionWithStructStruct
impl<'de> FromWire<XUnionWithStructStruct<'de>> for XUnionWithStructStruct
Sourcefn from_wire(wire: XUnionWithStructStruct<'de>) -> Self
fn from_wire(wire: XUnionWithStructStruct<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<XUnionWithStructStruct<'de>> for XUnionWithStructStruct
impl<'de> FromWireRef<XUnionWithStructStruct<'de>> for XUnionWithStructStruct
Sourcefn from_wire_ref(wire: &XUnionWithStructStruct<'de>) -> Self
fn from_wire_ref(wire: &XUnionWithStructStruct<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for XUnionWithStructStruct
impl Hash for XUnionWithStructStruct
Sourceimpl Ord for XUnionWithStructStruct
impl Ord for XUnionWithStructStruct
Sourcefn cmp(&self, other: &XUnionWithStructStruct) -> Ordering
fn cmp(&self, other: &XUnionWithStructStruct) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for XUnionWithStructStruct
impl PartialEq for XUnionWithStructStruct
Sourceimpl PartialOrd for XUnionWithStructStruct
impl PartialOrd for XUnionWithStructStruct
impl Copy for XUnionWithStructStruct
impl Eq for XUnionWithStructStruct
impl StructuralPartialEq for XUnionWithStructStruct