#[repr(C)]pub struct AnEmptyStructInStruct {
pub v: EmptyStruct,
}Expand description
The wire type corresponding to AnEmptyStructInStruct.
Fields
v: EmptyStructTrait Implementations
Sourceimpl Clone for AnEmptyStructInStruct
impl Clone for AnEmptyStructInStruct
Sourcefn clone(&self) -> AnEmptyStructInStruct
fn clone(&self) -> AnEmptyStructInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for AnEmptyStructInStruct
impl Constrained for AnEmptyStructInStruct
Sourceimpl Debug for AnEmptyStructInStruct
impl Debug for AnEmptyStructInStruct
Sourceimpl<___D> Decode<___D> for AnEmptyStructInStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for AnEmptyStructInStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<AnEmptyStructInStruct, ___E> for &'a AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<AnEmptyStructInStruct, ___E> for &'a AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnEmptyStructInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnEmptyStructInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, AnEmptyStructInStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, AnEmptyStructInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnEmptyStructInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnEmptyStructInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmptyStruct, ___E>,
impl<___E, T0> Encode<AnEmptyStructInStruct, ___E> for AnEmptyStructInStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmptyStruct, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<AnEmptyStructInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<AnEmptyStructInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<AnEmptyStructInStruct> for AnEmptyStructInStruct
impl FromWire<AnEmptyStructInStruct> for AnEmptyStructInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<AnEmptyStructInStruct, Self>
Sourcefn from_wire(wire: AnEmptyStructInStruct) -> Self
fn from_wire(wire: AnEmptyStructInStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<AnEmptyStructInStruct> for AnEmptyStructInStruct
impl FromWireRef<AnEmptyStructInStruct> for AnEmptyStructInStruct
Sourcefn from_wire_ref(wire: &AnEmptyStructInStruct) -> Self
fn from_wire_ref(wire: &AnEmptyStructInStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for AnEmptyStructInStruct
impl IntoNatural for AnEmptyStructInStruct
Sourcetype Natural = AnEmptyStructInStruct
type Natural = AnEmptyStructInStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for AnEmptyStructInStruct
impl Wire for AnEmptyStructInStruct
Sourcetype Narrowed<'de> = AnEmptyStructInStruct
type Narrowed<'de> = AnEmptyStructInStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.