#[repr(C)]pub struct Bounded32NullableString<'de> {
pub s0: OptionalString<'de>,
}Expand description
The wire type corresponding to Bounded32NullableString.
Fields
s0: OptionalString<'de>Trait Implementations
Sourceimpl Constrained for Bounded32NullableString<'_>
impl Constrained for Bounded32NullableString<'_>
Sourceimpl<'de> Debug for Bounded32NullableString<'de>
impl<'de> Debug for Bounded32NullableString<'de>
Sourceimpl<'de, ___D> Decode<___D> for Bounded32NullableString<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
impl<'de, ___D> Decode<___D> for Bounded32NullableString<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
Sourceimpl<'a, ___E> Encode<Bounded32NullableString<'static>, ___E> for &'a Bounded32NullableStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<Bounded32NullableString<'static>, ___E> for &'a Bounded32NullableStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableStringwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableString<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<OptionalString<'static>, ___E>,
impl<___E, T0> Encode<Bounded32NullableString<'static>, ___E> for Bounded32NullableString<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<OptionalString<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Bounded32NullableString<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Bounded32NullableString<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<Bounded32NullableString<'de>> for Bounded32NullableString
impl<'de> FromWire<Bounded32NullableString<'de>> for Bounded32NullableString
Sourcefn from_wire(wire: Bounded32NullableString<'de>) -> Self
fn from_wire(wire: Bounded32NullableString<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Bounded32NullableString<'de>> for Bounded32NullableString
impl<'de> FromWireRef<Bounded32NullableString<'de>> for Bounded32NullableString
Sourcefn from_wire_ref(wire: &Bounded32NullableString<'de>) -> Self
fn from_wire_ref(wire: &Bounded32NullableString<'de>) -> Self
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for Bounded32NullableString<'de>
impl<'de> IntoNatural for Bounded32NullableString<'de>
Sourcetype Natural = Bounded32NullableString
type Natural = Bounded32NullableString
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Bounded32NullableString<'static>
impl Wire for Bounded32NullableString<'static>
Sourcetype Narrowed<'de> = Bounded32NullableString<'de>
type Narrowed<'de> = Bounded32NullableString<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.