#[repr(C)]pub struct EmptyStructUnionStruct {
pub u: EmptyStructUnion,
}Expand description
The wire type corresponding to EmptyStructUnionStruct.
Fields
u: EmptyStructUnionTrait Implementations
Sourceimpl Clone for EmptyStructUnionStruct
impl Clone for EmptyStructUnionStruct
Sourcefn clone(&self) -> EmptyStructUnionStruct
fn clone(&self) -> EmptyStructUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EmptyStructUnionStruct
impl Constrained for EmptyStructUnionStruct
Sourceimpl Debug for EmptyStructUnionStruct
impl Debug for EmptyStructUnionStruct
Sourceimpl<___D> Decode<___D> for EmptyStructUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EmptyStructUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EmptyStructUnionStruct, ___E> for &'a EmptyStructUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmptyStructUnionStruct, ___E> for &'a EmptyStructUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmptyStructUnionStruct, ___E> for EmptyStructUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmptyStructUnionStruct, ___E> for EmptyStructUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<EmptyStructUnionStruct, ___E> for EmptyStructUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmptyStructUnion, ___E>,
impl<___E, T0> Encode<EmptyStructUnionStruct, ___E> for EmptyStructUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<EmptyStructUnion, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmptyStructUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmptyStructUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EmptyStructUnionStruct> for EmptyStructUnionStruct
impl FromWire<EmptyStructUnionStruct> for EmptyStructUnionStruct
Sourcefn from_wire(wire: EmptyStructUnionStruct) -> Self
fn from_wire(wire: EmptyStructUnionStruct) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<EmptyStructUnionStruct> for EmptyStructUnionStruct
impl FromWireRef<EmptyStructUnionStruct> for EmptyStructUnionStruct
Sourcefn from_wire_ref(wire: &EmptyStructUnionStruct) -> Self
fn from_wire_ref(wire: &EmptyStructUnionStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for EmptyStructUnionStruct
impl IntoNatural for EmptyStructUnionStruct
Sourcetype Natural = EmptyStructUnionStruct
type Natural = EmptyStructUnionStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EmptyStructUnionStruct
impl Wire for EmptyStructUnionStruct
Sourcetype Narrowed<'de> = EmptyStructUnionStruct
type Narrowed<'de> = EmptyStructUnionStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.