#[repr(C)]pub struct FiveByteInStruct {
pub elem1: FiveByte,
pub elem2: FiveByte,
pub elem3: FiveByte,
}Expand description
The wire type corresponding to FiveByteInStruct.
Fields
elem1: FiveByteelem2: FiveByteelem3: FiveByteTrait Implementations
Sourceimpl Clone for FiveByteInStruct
impl Clone for FiveByteInStruct
Sourcefn clone(&self) -> FiveByteInStruct
fn clone(&self) -> FiveByteInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FiveByteInStruct
impl Constrained for FiveByteInStruct
Sourceimpl Debug for FiveByteInStruct
impl Debug for FiveByteInStruct
Sourceimpl<___D> Decode<___D> for FiveByteInStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FiveByteInStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<FiveByteInStruct, ___E> for &'a FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FiveByteInStruct, ___E> for &'a FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FiveByteInStruct, ___E> for FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FiveByteInStruct, ___E> for FiveByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<FiveByteInStruct, ___E> for FiveByteInStruct<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<FiveByteInStruct, ___E> for FiveByteInStruct<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FiveByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FiveByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FiveByteInStruct> for FiveByteInStruct
impl FromWire<FiveByteInStruct> for FiveByteInStruct
Sourcefn from_wire(wire: FiveByteInStruct) -> Self
fn from_wire(wire: FiveByteInStruct) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<FiveByteInStruct> for FiveByteInStruct
impl FromWireRef<FiveByteInStruct> for FiveByteInStruct
Sourcefn from_wire_ref(wire: &FiveByteInStruct) -> Self
fn from_wire_ref(wire: &FiveByteInStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for FiveByteInStruct
impl IntoNatural for FiveByteInStruct
Sourcetype Natural = FiveByteInStruct
type Natural = FiveByteInStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FiveByteInStruct
impl Wire for FiveByteInStruct
Sourcetype Narrowed<'de> = FiveByteInStruct
type Narrowed<'de> = FiveByteInStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.