#[repr(C)]pub struct FlexibleBitsUint64Struct {
pub b: FlexibleBitsUint64,
}Expand description
The wire type corresponding to FlexibleBitsUint64Struct.
Fields
b: FlexibleBitsUint64Trait Implementations
Sourceimpl Clone for FlexibleBitsUint64Struct
impl Clone for FlexibleBitsUint64Struct
Sourcefn clone(&self) -> FlexibleBitsUint64Struct
fn clone(&self) -> FlexibleBitsUint64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FlexibleBitsUint64Struct
impl Constrained for FlexibleBitsUint64Struct
Sourceimpl Debug for FlexibleBitsUint64Struct
impl Debug for FlexibleBitsUint64Struct
Sourceimpl<___D> Decode<___D> for FlexibleBitsUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FlexibleBitsUint64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<FlexibleBitsUint64Struct, ___E> for &'a FlexibleBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FlexibleBitsUint64Struct, ___E> for &'a FlexibleBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FlexibleBitsUint64Struct, ___E> for FlexibleBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FlexibleBitsUint64Struct, ___E> for FlexibleBitsUint64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, FlexibleBitsUint64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, FlexibleBitsUint64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<FlexibleBitsUint64Struct, ___E> for FlexibleBitsUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<FlexibleBitsUint64, ___E>,
impl<___E, T0> Encode<FlexibleBitsUint64Struct, ___E> for FlexibleBitsUint64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<FlexibleBitsUint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FlexibleBitsUint64Struct> for FlexibleBitsUint64Struct
impl FromWire<FlexibleBitsUint64Struct> for FlexibleBitsUint64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<FlexibleBitsUint64Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<FlexibleBitsUint64Struct, Self>
Sourcefn from_wire(wire: FlexibleBitsUint64Struct) -> Self
fn from_wire(wire: FlexibleBitsUint64Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<FlexibleBitsUint64Struct> for FlexibleBitsUint64Struct
impl FromWireRef<FlexibleBitsUint64Struct> for FlexibleBitsUint64Struct
Sourcefn from_wire_ref(wire: &FlexibleBitsUint64Struct) -> Self
fn from_wire_ref(wire: &FlexibleBitsUint64Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for FlexibleBitsUint64Struct
impl IntoNatural for FlexibleBitsUint64Struct
Sourcetype Natural = FlexibleBitsUint64Struct
type Natural = FlexibleBitsUint64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FlexibleBitsUint64Struct
impl Wire for FlexibleBitsUint64Struct
Sourcetype Narrowed<'de> = FlexibleBitsUint64Struct
type Narrowed<'de> = FlexibleBitsUint64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.