#[repr(C)]pub struct FlexibleBitsUint8Struct {
pub b: FlexibleBitsUint8,
}Expand description
The wire type corresponding to FlexibleBitsUint8Struct.
Fields
b: FlexibleBitsUint8Trait Implementations
Sourceimpl Clone for FlexibleBitsUint8Struct
impl Clone for FlexibleBitsUint8Struct
Sourcefn clone(&self) -> FlexibleBitsUint8Struct
fn clone(&self) -> FlexibleBitsUint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for FlexibleBitsUint8Struct
impl Constrained for FlexibleBitsUint8Struct
Sourceimpl Debug for FlexibleBitsUint8Struct
impl Debug for FlexibleBitsUint8Struct
Sourceimpl<___D> Decode<___D> for FlexibleBitsUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for FlexibleBitsUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<FlexibleBitsUint8Struct, ___E> for &'a FlexibleBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<FlexibleBitsUint8Struct, ___E> for &'a FlexibleBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<FlexibleBitsUint8Struct, ___E> for FlexibleBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<FlexibleBitsUint8Struct, ___E> for FlexibleBitsUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, FlexibleBitsUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, FlexibleBitsUint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<FlexibleBitsUint8Struct, ___E> for FlexibleBitsUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<FlexibleBitsUint8, ___E>,
impl<___E, T0> Encode<FlexibleBitsUint8Struct, ___E> for FlexibleBitsUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<FlexibleBitsUint8, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<FlexibleBitsUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<FlexibleBitsUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<FlexibleBitsUint8Struct> for FlexibleBitsUint8Struct
impl FromWire<FlexibleBitsUint8Struct> for FlexibleBitsUint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<FlexibleBitsUint8Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<FlexibleBitsUint8Struct, Self>
Sourcefn from_wire(wire: FlexibleBitsUint8Struct) -> Self
fn from_wire(wire: FlexibleBitsUint8Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<FlexibleBitsUint8Struct> for FlexibleBitsUint8Struct
impl FromWireRef<FlexibleBitsUint8Struct> for FlexibleBitsUint8Struct
Sourcefn from_wire_ref(wire: &FlexibleBitsUint8Struct) -> Self
fn from_wire_ref(wire: &FlexibleBitsUint8Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for FlexibleBitsUint8Struct
impl IntoNatural for FlexibleBitsUint8Struct
Sourcetype Natural = FlexibleBitsUint8Struct
type Natural = FlexibleBitsUint8Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for FlexibleBitsUint8Struct
impl Wire for FlexibleBitsUint8Struct
Sourcetype Narrowed<'de> = FlexibleBitsUint8Struct
type Narrowed<'de> = FlexibleBitsUint8Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.