#[repr(C)]pub struct GoldenBitsStruct {
pub v: GoldenBits,
}Expand description
The wire type corresponding to GoldenBitsStruct.
Fields
v: GoldenBitsTrait Implementations
Sourceimpl Clone for GoldenBitsStruct
impl Clone for GoldenBitsStruct
Sourcefn clone(&self) -> GoldenBitsStruct
fn clone(&self) -> GoldenBitsStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenBitsStruct
impl Constrained for GoldenBitsStruct
Sourceimpl Debug for GoldenBitsStruct
impl Debug for GoldenBitsStruct
Sourceimpl<___D> Decode<___D> for GoldenBitsStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenBitsStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenBitsStruct, ___E> for &'a GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenBitsStruct, ___E> for &'a GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenBitsStruct, ___E> for GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenBitsStruct, ___E> for GoldenBitsStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenBitsStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenBitsStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenBitsStruct, ___E> for GoldenBitsStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenBits, ___E>,
impl<___E, T0> Encode<GoldenBitsStruct, ___E> for GoldenBitsStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenBits, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenBitsStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenBitsStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenBitsStruct> for GoldenBitsStruct
impl FromWire<GoldenBitsStruct> for GoldenBitsStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenBitsStruct, Self>
Sourcefn from_wire(wire: GoldenBitsStruct) -> Self
fn from_wire(wire: GoldenBitsStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenBitsStruct> for GoldenBitsStruct
impl FromWireRef<GoldenBitsStruct> for GoldenBitsStruct
Sourcefn from_wire_ref(wire: &GoldenBitsStruct) -> Self
fn from_wire_ref(wire: &GoldenBitsStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenBitsStruct
impl IntoNatural for GoldenBitsStruct
Sourcetype Natural = GoldenBitsStruct
type Natural = GoldenBitsStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenBitsStruct
impl Wire for GoldenBitsStruct
Sourcetype Narrowed<'de> = GoldenBitsStruct
type Narrowed<'de> = GoldenBitsStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.