#[repr(C)]pub struct GoldenByteArrayStruct {
pub v: [u8; 4],
}Expand description
The wire type corresponding to GoldenByteArrayStruct.
Fields
v: [u8; 4]Trait Implementations
Sourceimpl Clone for GoldenByteArrayStruct
impl Clone for GoldenByteArrayStruct
Sourcefn clone(&self) -> GoldenByteArrayStruct
fn clone(&self) -> GoldenByteArrayStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenByteArrayStruct
impl Constrained for GoldenByteArrayStruct
Sourceimpl Debug for GoldenByteArrayStruct
impl Debug for GoldenByteArrayStruct
Sourceimpl<___D> Decode<___D> for GoldenByteArrayStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenByteArrayStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenByteArrayStruct, ___E> for &'a GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenByteArrayStruct, ___E> for &'a GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenByteArrayStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenByteArrayStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStruct<T0>
impl<___E, T0> Encode<GoldenByteArrayStruct, ___E> for GoldenByteArrayStruct<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenByteArrayStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenByteArrayStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl FromWire<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenByteArrayStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenByteArrayStruct, Self>
Sourcefn from_wire(wire: GoldenByteArrayStruct) -> Self
fn from_wire(wire: GoldenByteArrayStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenByteArrayStruct> for GoldenByteArrayStruct
impl FromWireRef<GoldenByteArrayStruct> for GoldenByteArrayStruct
Sourcefn from_wire_ref(wire: &GoldenByteArrayStruct) -> Self
fn from_wire_ref(wire: &GoldenByteArrayStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenByteArrayStruct
impl IntoNatural for GoldenByteArrayStruct
Sourcetype Natural = GoldenByteArrayStruct
type Natural = GoldenByteArrayStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenByteArrayStruct
impl Wire for GoldenByteArrayStruct
Sourcetype Narrowed<'de> = GoldenByteArrayStruct
type Narrowed<'de> = GoldenByteArrayStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.