#[repr(C)]pub struct GoldenDoubleStruct {
pub v: Float64,
}Expand description
The wire type corresponding to GoldenDoubleStruct.
Fields
v: Float64Trait Implementations
Sourceimpl Clone for GoldenDoubleStruct
impl Clone for GoldenDoubleStruct
Sourcefn clone(&self) -> GoldenDoubleStruct
fn clone(&self) -> GoldenDoubleStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenDoubleStruct
impl Constrained for GoldenDoubleStruct
Sourceimpl Debug for GoldenDoubleStruct
impl Debug for GoldenDoubleStruct
Sourceimpl<___D> Decode<___D> for GoldenDoubleStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenDoubleStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenDoubleStruct, ___E> for &'a GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenDoubleStruct, ___E> for &'a GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenDoubleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenDoubleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenDoubleStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenDoubleStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenDoubleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenDoubleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
impl<___E, T0> Encode<GoldenDoubleStruct, ___E> for GoldenDoubleStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenDoubleStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenDoubleStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenDoubleStruct> for GoldenDoubleStruct
impl FromWire<GoldenDoubleStruct> for GoldenDoubleStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenDoubleStruct, Self>
Sourcefn from_wire(wire: GoldenDoubleStruct) -> Self
fn from_wire(wire: GoldenDoubleStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenDoubleStruct> for GoldenDoubleStruct
impl FromWireRef<GoldenDoubleStruct> for GoldenDoubleStruct
Sourcefn from_wire_ref(wire: &GoldenDoubleStruct) -> Self
fn from_wire_ref(wire: &GoldenDoubleStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenDoubleStruct
impl IntoNatural for GoldenDoubleStruct
Sourcetype Natural = GoldenDoubleStruct
type Natural = GoldenDoubleStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenDoubleStruct
impl Wire for GoldenDoubleStruct
Sourcetype Narrowed<'de> = GoldenDoubleStruct
type Narrowed<'de> = GoldenDoubleStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.