#[repr(C)]pub struct GoldenFloatStruct {
pub v: Float32,
}Expand description
The wire type corresponding to GoldenFloatStruct.
Fields
v: Float32Trait Implementations
Sourceimpl Clone for GoldenFloatStruct
impl Clone for GoldenFloatStruct
Sourcefn clone(&self) -> GoldenFloatStruct
fn clone(&self) -> GoldenFloatStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenFloatStruct
impl Constrained for GoldenFloatStruct
Sourceimpl Debug for GoldenFloatStruct
impl Debug for GoldenFloatStruct
Sourceimpl<___D> Decode<___D> for GoldenFloatStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenFloatStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenFloatStruct, ___E> for &'a GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenFloatStruct, ___E> for &'a GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenFloatStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenFloatStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenFloatStruct, ___E> for GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenFloatStruct, ___E> for GoldenFloatStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenFloatStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenFloatStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenFloatStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenFloatStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenFloatStruct, ___E> for GoldenFloatStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float32, ___E>,
impl<___E, T0> Encode<GoldenFloatStruct, ___E> for GoldenFloatStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Float32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenFloatStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenFloatStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenFloatStruct> for GoldenFloatStruct
impl FromWire<GoldenFloatStruct> for GoldenFloatStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenFloatStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenFloatStruct, Self>
Sourcefn from_wire(wire: GoldenFloatStruct) -> Self
fn from_wire(wire: GoldenFloatStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenFloatStruct> for GoldenFloatStruct
impl FromWireRef<GoldenFloatStruct> for GoldenFloatStruct
Sourcefn from_wire_ref(wire: &GoldenFloatStruct) -> Self
fn from_wire_ref(wire: &GoldenFloatStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenFloatStruct
impl IntoNatural for GoldenFloatStruct
Sourcetype Natural = GoldenFloatStruct
type Natural = GoldenFloatStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenFloatStruct
impl Wire for GoldenFloatStruct
Sourcetype Narrowed<'de> = GoldenFloatStruct
type Narrowed<'de> = GoldenFloatStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.