#[repr(C)]pub struct GoldenIntStruct {
pub v: Int16,
}Expand description
The wire type corresponding to GoldenIntStruct.
Fields
v: Int16Trait Implementations
Sourceimpl Clone for GoldenIntStruct
impl Clone for GoldenIntStruct
Sourcefn clone(&self) -> GoldenIntStruct
fn clone(&self) -> GoldenIntStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenIntStruct
impl Constrained for GoldenIntStruct
Sourceimpl Debug for GoldenIntStruct
impl Debug for GoldenIntStruct
Sourceimpl<___D> Decode<___D> for GoldenIntStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenIntStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenIntStruct, ___E> for &'a GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenIntStruct, ___E> for &'a GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenIntStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenIntStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenIntStruct, ___E> for GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenIntStruct, ___E> for GoldenIntStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenIntStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenIntStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenIntStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenIntStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenIntStruct, ___E> for GoldenIntStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int16, ___E>,
impl<___E, T0> Encode<GoldenIntStruct, ___E> for GoldenIntStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenIntStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenIntStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenIntStruct> for GoldenIntStruct
impl FromWire<GoldenIntStruct> for GoldenIntStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenIntStruct, Self>
Sourcefn from_wire(wire: GoldenIntStruct) -> Self
fn from_wire(wire: GoldenIntStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenIntStruct> for GoldenIntStruct
impl FromWireRef<GoldenIntStruct> for GoldenIntStruct
Sourcefn from_wire_ref(wire: &GoldenIntStruct) -> Self
fn from_wire_ref(wire: &GoldenIntStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenIntStruct
impl IntoNatural for GoldenIntStruct
Sourcetype Natural = GoldenIntStruct
type Natural = GoldenIntStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenIntStruct
impl Wire for GoldenIntStruct
Sourcetype Narrowed<'de> = GoldenIntStruct
type Narrowed<'de> = GoldenIntStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.