#[repr(C)]pub struct GoldenNullableUnionStruct {
pub v: GoldenUnion,
}Expand description
The wire type corresponding to GoldenNullableUnionStruct.
Fields
v: GoldenUnionTrait Implementations
Sourceimpl Clone for GoldenNullableUnionStruct
impl Clone for GoldenNullableUnionStruct
Sourcefn clone(&self) -> GoldenNullableUnionStruct
fn clone(&self) -> GoldenNullableUnionStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenNullableUnionStruct
impl Constrained for GoldenNullableUnionStruct
Sourceimpl Debug for GoldenNullableUnionStruct
impl Debug for GoldenNullableUnionStruct
Sourceimpl<___D> Decode<___D> for GoldenNullableUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenNullableUnionStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenNullableUnionStruct, ___E> for &'a GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenNullableUnionStruct, ___E> for &'a GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenUnion, ___E>,
impl<___E, T0> Encode<GoldenNullableUnionStruct, ___E> for GoldenNullableUnionStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<GoldenUnion, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenNullableUnionStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenNullableUnionStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl FromWire<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn from_wire(wire: GoldenNullableUnionStruct) -> Self
fn from_wire(wire: GoldenNullableUnionStruct) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
impl FromWireRef<GoldenNullableUnionStruct> for GoldenNullableUnionStruct
Sourcefn from_wire_ref(wire: &GoldenNullableUnionStruct) -> Self
fn from_wire_ref(wire: &GoldenNullableUnionStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenNullableUnionStruct
impl IntoNatural for GoldenNullableUnionStruct
Sourcetype Natural = GoldenNullableUnionStruct
type Natural = GoldenNullableUnionStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenNullableUnionStruct
impl Wire for GoldenNullableUnionStruct
Sourcetype Narrowed<'de> = GoldenNullableUnionStruct
type Narrowed<'de> = GoldenNullableUnionStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.