#[repr(C)]pub struct GoldenUintStruct {
pub v: Uint16,
}Expand description
The wire type corresponding to GoldenUintStruct.
Fields
v: Uint16Trait Implementations
Sourceimpl Clone for GoldenUintStruct
impl Clone for GoldenUintStruct
Sourcefn clone(&self) -> GoldenUintStruct
fn clone(&self) -> GoldenUintStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for GoldenUintStruct
impl Constrained for GoldenUintStruct
Sourceimpl Debug for GoldenUintStruct
impl Debug for GoldenUintStruct
Sourceimpl<___D> Decode<___D> for GoldenUintStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for GoldenUintStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<GoldenUintStruct, ___E> for &'a GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<GoldenUintStruct, ___E> for &'a GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUintStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUintStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<GoldenUintStruct, ___E> for GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<GoldenUintStruct, ___E> for GoldenUintStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, GoldenUintStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, GoldenUintStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUintStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUintStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<GoldenUintStruct, ___E> for GoldenUintStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
impl<___E, T0> Encode<GoldenUintStruct, ___E> for GoldenUintStruct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<GoldenUintStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<GoldenUintStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<GoldenUintStruct> for GoldenUintStruct
impl FromWire<GoldenUintStruct> for GoldenUintStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<GoldenUintStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<GoldenUintStruct, Self>
Sourcefn from_wire(wire: GoldenUintStruct) -> Self
fn from_wire(wire: GoldenUintStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<GoldenUintStruct> for GoldenUintStruct
impl FromWireRef<GoldenUintStruct> for GoldenUintStruct
Sourcefn from_wire_ref(wire: &GoldenUintStruct) -> Self
fn from_wire_ref(wire: &GoldenUintStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for GoldenUintStruct
impl IntoNatural for GoldenUintStruct
Sourcetype Natural = GoldenUintStruct
type Natural = GoldenUintStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for GoldenUintStruct
impl Wire for GoldenUintStruct
Sourcetype Narrowed<'de> = GoldenUintStruct
type Narrowed<'de> = GoldenUintStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.