#[repr(C)]pub struct MixedFieldsBody {
pub before: Uint32,
pub first_union: UnionSize8Align4,
pub middle_start: Uint16,
pub middle_end: Uint64,
pub second_union: UnionSize8Align4,
pub after: Uint32,
}Expand description
The wire type corresponding to MixedFieldsBody.
Fields
before: Uint32first_union: UnionSize8Align4middle_start: Uint16middle_end: Uint64second_union: UnionSize8Align4after: Uint32Trait Implementations
Sourceimpl Clone for MixedFieldsBody
impl Clone for MixedFieldsBody
Sourcefn clone(&self) -> MixedFieldsBody
fn clone(&self) -> MixedFieldsBody
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for MixedFieldsBody
impl Constrained for MixedFieldsBody
Sourceimpl Debug for MixedFieldsBody
impl Debug for MixedFieldsBody
Sourceimpl<___D> Decode<___D> for MixedFieldsBodywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for MixedFieldsBodywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<MixedFieldsBody, ___E> for &'a MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<MixedFieldsBody, ___E> for &'a MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsBody>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsBody>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MixedFieldsBody, ___E> for MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<MixedFieldsBody, ___E> for MixedFieldsBodywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsBody>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsBody>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5> Encode<MixedFieldsBody, ___E> for MixedFieldsBody<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<UnionSize8Align4, ___E>,
T2: Encode<Uint16, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<UnionSize8Align4, ___E>,
T5: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5> Encode<MixedFieldsBody, ___E> for MixedFieldsBody<T0, T1, T2, T3, T4, T5>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<UnionSize8Align4, ___E>,
T2: Encode<Uint16, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<UnionSize8Align4, ___E>,
T5: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MixedFieldsBody>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MixedFieldsBody>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<MixedFieldsBody> for MixedFieldsBody
impl FromWire<MixedFieldsBody> for MixedFieldsBody
Sourcefn from_wire(wire: MixedFieldsBody) -> Self
fn from_wire(wire: MixedFieldsBody) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<MixedFieldsBody> for MixedFieldsBody
impl FromWireRef<MixedFieldsBody> for MixedFieldsBody
Sourcefn from_wire_ref(wire: &MixedFieldsBody) -> Self
fn from_wire_ref(wire: &MixedFieldsBody) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for MixedFieldsBody
impl IntoNatural for MixedFieldsBody
Sourcetype Natural = MixedFieldsBody
type Natural = MixedFieldsBody
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for MixedFieldsBody
impl Wire for MixedFieldsBody
Sourcetype Narrowed<'de> = MixedFieldsBody
type Narrowed<'de> = MixedFieldsBody
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.