#[repr(C)]pub struct NoCodingTablesStressor<'de> {Show 14 fields
pub f1: Uint64,
pub f2: Uint64,
pub u1: UnionSize36Align4<'de>,
pub f3: Uint64,
pub f4: Uint64,
pub u2: UnionSize36Align4<'de>,
pub f5: Uint64,
pub f6: Uint64,
pub u3: UnionSize36Align4<'de>,
pub f7: Uint64,
pub p1: Box<'de, Size8Align8>,
pub f8: Uint64,
pub p2: Box<'de, Size8Align8>,
pub f9: Uint64,
}Expand description
The wire type corresponding to NoCodingTablesStressor.
Fields
f1: Uint64f2: Uint64u1: UnionSize36Align4<'de>f3: Uint64f4: Uint64u2: UnionSize36Align4<'de>f5: Uint64f6: Uint64u3: UnionSize36Align4<'de>f7: Uint64p1: Box<'de, Size8Align8>f8: Uint64p2: Box<'de, Size8Align8>f9: Uint64Trait Implementations
Sourceimpl Constrained for NoCodingTablesStressor<'_>
impl Constrained for NoCodingTablesStressor<'_>
Sourceimpl<'de> Debug for NoCodingTablesStressor<'de>
impl<'de> Debug for NoCodingTablesStressor<'de>
Sourceimpl<'de, ___D> Decode<___D> for NoCodingTablesStressor<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
impl<'de, ___D> Decode<___D> for NoCodingTablesStressor<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
Sourceimpl<'a, ___E> Encode<NoCodingTablesStressor<'static>, ___E> for &'a NoCodingTablesStressorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<NoCodingTablesStressor<'static>, ___E> for &'a NoCodingTablesStressorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<NoCodingTablesStressor<'static>, ___E> for NoCodingTablesStressorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<NoCodingTablesStressor<'static>, ___E> for NoCodingTablesStressorwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> Encode<NoCodingTablesStressor<'static>, ___E> for NoCodingTablesStressor<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint64, ___E>,
T2: Encode<UnionSize36Align4<'static>, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<Uint64, ___E>,
T5: Encode<UnionSize36Align4<'static>, ___E>,
T6: Encode<Uint64, ___E>,
T7: Encode<Uint64, ___E>,
T8: Encode<UnionSize36Align4<'static>, ___E>,
T9: Encode<Uint64, ___E>,
T10: Encode<Box<'static, Size8Align8>, ___E>,
T11: Encode<Uint64, ___E>,
T12: Encode<Box<'static, Size8Align8>, ___E>,
T13: Encode<Uint64, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> Encode<NoCodingTablesStressor<'static>, ___E> for NoCodingTablesStressor<T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<Uint64, ___E>,
T1: Encode<Uint64, ___E>,
T2: Encode<UnionSize36Align4<'static>, ___E>,
T3: Encode<Uint64, ___E>,
T4: Encode<Uint64, ___E>,
T5: Encode<UnionSize36Align4<'static>, ___E>,
T6: Encode<Uint64, ___E>,
T7: Encode<Uint64, ___E>,
T8: Encode<UnionSize36Align4<'static>, ___E>,
T9: Encode<Uint64, ___E>,
T10: Encode<Box<'static, Size8Align8>, ___E>,
T11: Encode<Uint64, ___E>,
T12: Encode<Box<'static, Size8Align8>, ___E>,
T13: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<NoCodingTablesStressor<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<NoCodingTablesStressor<'de>> for NoCodingTablesStressor
impl<'de> FromWire<NoCodingTablesStressor<'de>> for NoCodingTablesStressor
Sourcefn from_wire(wire: NoCodingTablesStressor<'de>) -> Self
fn from_wire(wire: NoCodingTablesStressor<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<NoCodingTablesStressor<'de>> for NoCodingTablesStressor
impl<'de> FromWireRef<NoCodingTablesStressor<'de>> for NoCodingTablesStressor
Sourcefn from_wire_ref(wire: &NoCodingTablesStressor<'de>) -> Self
fn from_wire_ref(wire: &NoCodingTablesStressor<'de>) -> Self
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for NoCodingTablesStressor<'de>
impl<'de> IntoNatural for NoCodingTablesStressor<'de>
Sourcetype Natural = NoCodingTablesStressor
type Natural = NoCodingTablesStressor
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for NoCodingTablesStressor<'static>
impl Wire for NoCodingTablesStressor<'static>
Sourcetype Narrowed<'de> = NoCodingTablesStressor<'de>
type Narrowed<'de> = NoCodingTablesStressor<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.