#[repr(C)]pub struct OneLayerStructWithPaddingAlign8 {
pub a: Uint32,
pub b: Uint16,
pub c: Uint64,
}Expand description
The wire type corresponding to OneLayerStructWithPaddingAlign8.
Fields
a: Uint32b: Uint16c: Uint64Trait Implementations
Sourceimpl Clone for OneLayerStructWithPaddingAlign8
impl Clone for OneLayerStructWithPaddingAlign8
Sourcefn clone(&self) -> OneLayerStructWithPaddingAlign8
fn clone(&self) -> OneLayerStructWithPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for OneLayerStructWithPaddingAlign8
impl Constrained for OneLayerStructWithPaddingAlign8
Sourceimpl<___D> Decode<___D> for OneLayerStructWithPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for OneLayerStructWithPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for &'a OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint16, ___E>,
T2: Encode<Uint64, ___E>,
impl<___E, T0, T1, T2> Encode<OneLayerStructWithPaddingAlign8, ___E> for OneLayerStructWithPaddingAlign8<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<Uint16, ___E>,
T2: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<OneLayerStructWithPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl FromWire<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn from_wire(wire: OneLayerStructWithPaddingAlign8) -> Self
fn from_wire(wire: OneLayerStructWithPaddingAlign8) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
impl FromWireRef<OneLayerStructWithPaddingAlign8> for OneLayerStructWithPaddingAlign8
Sourcefn from_wire_ref(wire: &OneLayerStructWithPaddingAlign8) -> Self
fn from_wire_ref(wire: &OneLayerStructWithPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for OneLayerStructWithPaddingAlign8
impl IntoNatural for OneLayerStructWithPaddingAlign8
Sourcetype Natural = OneLayerStructWithPaddingAlign8
type Natural = OneLayerStructWithPaddingAlign8
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for OneLayerStructWithPaddingAlign8
impl Wire for OneLayerStructWithPaddingAlign8
Sourcetype Narrowed<'de> = OneLayerStructWithPaddingAlign8
type Narrowed<'de> = OneLayerStructWithPaddingAlign8
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.