#[repr(C)]pub struct PaddingAlignment2MaskMayBe4Bytes {
pub a: u8,
pub b: Uint16,
pub c: Uint16,
}Expand description
The wire type corresponding to PaddingAlignment2MaskMayBe4Bytes.
Fields
a: u8b: Uint16c: Uint16Trait Implementations
Sourceimpl Clone for PaddingAlignment2MaskMayBe4Bytes
impl Clone for PaddingAlignment2MaskMayBe4Bytes
Sourcefn clone(&self) -> PaddingAlignment2MaskMayBe4Bytes
fn clone(&self) -> PaddingAlignment2MaskMayBe4Bytes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for PaddingAlignment2MaskMayBe4Bytes
impl Constrained for PaddingAlignment2MaskMayBe4Bytes
Sourceimpl<___D> Decode<___D> for PaddingAlignment2MaskMayBe4Byteswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for PaddingAlignment2MaskMayBe4Byteswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for &'a PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Bytes<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<PaddingAlignment2MaskMayBe4Bytes, ___E> for PaddingAlignment2MaskMayBe4Bytes<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment2MaskMayBe4Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
impl FromWire<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
Sourcefn from_wire(wire: PaddingAlignment2MaskMayBe4Bytes) -> Self
fn from_wire(wire: PaddingAlignment2MaskMayBe4Bytes) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
impl FromWireRef<PaddingAlignment2MaskMayBe4Bytes> for PaddingAlignment2MaskMayBe4Bytes
Sourcefn from_wire_ref(wire: &PaddingAlignment2MaskMayBe4Bytes) -> Self
fn from_wire_ref(wire: &PaddingAlignment2MaskMayBe4Bytes) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for PaddingAlignment2MaskMayBe4Bytes
impl IntoNatural for PaddingAlignment2MaskMayBe4Bytes
Sourcetype Natural = PaddingAlignment2MaskMayBe4Bytes
type Natural = PaddingAlignment2MaskMayBe4Bytes
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for PaddingAlignment2MaskMayBe4Bytes
impl Wire for PaddingAlignment2MaskMayBe4Bytes
Sourcetype Narrowed<'de> = PaddingAlignment2MaskMayBe4Bytes
type Narrowed<'de> = PaddingAlignment2MaskMayBe4Bytes
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.