#[repr(C)]pub struct PaddingAlignment4MaskMayBe8Bytes {
pub a: u8,
pub b: Uint32,
pub c: Uint32,
}Expand description
The wire type corresponding to PaddingAlignment4MaskMayBe8Bytes.
Fields
a: u8b: Uint32c: Uint32Trait Implementations
Sourceimpl Clone for PaddingAlignment4MaskMayBe8Bytes
impl Clone for PaddingAlignment4MaskMayBe8Bytes
Sourcefn clone(&self) -> PaddingAlignment4MaskMayBe8Bytes
fn clone(&self) -> PaddingAlignment4MaskMayBe8Bytes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for PaddingAlignment4MaskMayBe8Bytes
impl Constrained for PaddingAlignment4MaskMayBe8Bytes
Sourceimpl<___D> Decode<___D> for PaddingAlignment4MaskMayBe8Byteswhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for PaddingAlignment4MaskMayBe8Byteswhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for &'a PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Byteswhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Bytes<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<PaddingAlignment4MaskMayBe8Bytes, ___E> for PaddingAlignment4MaskMayBe8Bytes<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingAlignment4MaskMayBe8Bytes>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
impl FromWire<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
Sourcefn from_wire(wire: PaddingAlignment4MaskMayBe8Bytes) -> Self
fn from_wire(wire: PaddingAlignment4MaskMayBe8Bytes) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
impl FromWireRef<PaddingAlignment4MaskMayBe8Bytes> for PaddingAlignment4MaskMayBe8Bytes
Sourcefn from_wire_ref(wire: &PaddingAlignment4MaskMayBe8Bytes) -> Self
fn from_wire_ref(wire: &PaddingAlignment4MaskMayBe8Bytes) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for PaddingAlignment4MaskMayBe8Bytes
impl IntoNatural for PaddingAlignment4MaskMayBe8Bytes
Sourcetype Natural = PaddingAlignment4MaskMayBe8Bytes
type Natural = PaddingAlignment4MaskMayBe8Bytes
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for PaddingAlignment4MaskMayBe8Bytes
impl Wire for PaddingAlignment4MaskMayBe8Bytes
Sourcetype Narrowed<'de> = PaddingAlignment4MaskMayBe8Bytes
type Narrowed<'de> = PaddingAlignment4MaskMayBe8Bytes
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.