#[repr(C)]pub struct PaddingBetweenFieldsInt32Int64 {
pub a: Int32,
pub b: Int64,
}Expand description
The wire type corresponding to PaddingBetweenFieldsInt32Int64.
Fields
a: Int32b: Int64Trait Implementations
Sourceimpl Clone for PaddingBetweenFieldsInt32Int64
impl Clone for PaddingBetweenFieldsInt32Int64
Sourcefn clone(&self) -> PaddingBetweenFieldsInt32Int64
fn clone(&self) -> PaddingBetweenFieldsInt32Int64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for PaddingBetweenFieldsInt32Int64
impl Constrained for PaddingBetweenFieldsInt32Int64
Sourceimpl<___D> Decode<___D> for PaddingBetweenFieldsInt32Int64where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for PaddingBetweenFieldsInt32Int64where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for &'a PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int64, ___E>,
impl<___E, T0, T1> Encode<PaddingBetweenFieldsInt32Int64, ___E> for PaddingBetweenFieldsInt32Int64<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
T1: Encode<Int64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt32Int64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
impl FromWire<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
Sourcefn from_wire(wire: PaddingBetweenFieldsInt32Int64) -> Self
fn from_wire(wire: PaddingBetweenFieldsInt32Int64) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
impl FromWireRef<PaddingBetweenFieldsInt32Int64> for PaddingBetweenFieldsInt32Int64
Sourcefn from_wire_ref(wire: &PaddingBetweenFieldsInt32Int64) -> Self
fn from_wire_ref(wire: &PaddingBetweenFieldsInt32Int64) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for PaddingBetweenFieldsInt32Int64
impl IntoNatural for PaddingBetweenFieldsInt32Int64
Sourcetype Natural = PaddingBetweenFieldsInt32Int64
type Natural = PaddingBetweenFieldsInt32Int64
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for PaddingBetweenFieldsInt32Int64
impl Wire for PaddingBetweenFieldsInt32Int64
Sourcetype Narrowed<'de> = PaddingBetweenFieldsInt32Int64
type Narrowed<'de> = PaddingBetweenFieldsInt32Int64
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.