#[repr(C)]pub struct PaddingBetweenFieldsInt8Int16 {
pub a: i8,
pub b: Int16,
}Expand description
The wire type corresponding to PaddingBetweenFieldsInt8Int16.
Fields
a: i8b: Int16Trait Implementations
Sourceimpl Clone for PaddingBetweenFieldsInt8Int16
impl Clone for PaddingBetweenFieldsInt8Int16
Sourcefn clone(&self) -> PaddingBetweenFieldsInt8Int16
fn clone(&self) -> PaddingBetweenFieldsInt8Int16
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for PaddingBetweenFieldsInt8Int16
impl Constrained for PaddingBetweenFieldsInt8Int16
Sourceimpl<___D> Decode<___D> for PaddingBetweenFieldsInt8Int16where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for PaddingBetweenFieldsInt8Int16where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for &'a PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16<T0, T1>
impl<___E, T0, T1> Encode<PaddingBetweenFieldsInt8Int16, ___E> for PaddingBetweenFieldsInt8Int16<T0, T1>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PaddingBetweenFieldsInt8Int16>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl FromWire<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn from_wire(wire: PaddingBetweenFieldsInt8Int16) -> Self
fn from_wire(wire: PaddingBetweenFieldsInt8Int16) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
impl FromWireRef<PaddingBetweenFieldsInt8Int16> for PaddingBetweenFieldsInt8Int16
Sourcefn from_wire_ref(wire: &PaddingBetweenFieldsInt8Int16) -> Self
fn from_wire_ref(wire: &PaddingBetweenFieldsInt8Int16) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for PaddingBetweenFieldsInt8Int16
impl IntoNatural for PaddingBetweenFieldsInt8Int16
Sourcetype Natural = PaddingBetweenFieldsInt8Int16
type Natural = PaddingBetweenFieldsInt8Int16
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for PaddingBetweenFieldsInt8Int16
impl Wire for PaddingBetweenFieldsInt8Int16
Sourcetype Narrowed<'de> = PaddingBetweenFieldsInt8Int16
type Narrowed<'de> = PaddingBetweenFieldsInt8Int16
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.