#[repr(C)]pub struct Sandwich1WithOptUnion {
pub before: Uint32,
pub opt_union: UnionSize8Align4,
pub after: Uint32,
}Expand description
The wire type corresponding to Sandwich1WithOptUnion.
Fields
before: Uint32opt_union: UnionSize8Align4after: Uint32Trait Implementations
Sourceimpl Clone for Sandwich1WithOptUnion
impl Clone for Sandwich1WithOptUnion
Sourcefn clone(&self) -> Sandwich1WithOptUnion
fn clone(&self) -> Sandwich1WithOptUnion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Sandwich1WithOptUnion
impl Constrained for Sandwich1WithOptUnion
Sourceimpl Debug for Sandwich1WithOptUnion
impl Debug for Sandwich1WithOptUnion
Sourceimpl<___D> Decode<___D> for Sandwich1WithOptUnionwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Sandwich1WithOptUnionwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Sandwich1WithOptUnion, ___E> for &'a Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Sandwich1WithOptUnion, ___E> for &'a Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1WithOptUnion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1WithOptUnion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnionwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1WithOptUnion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1WithOptUnion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnion<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<UnionSize8Align4, ___E>,
T2: Encode<Uint32, ___E>,
impl<___E, T0, T1, T2> Encode<Sandwich1WithOptUnion, ___E> for Sandwich1WithOptUnion<T0, T1, T2>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
T1: Encode<UnionSize8Align4, ___E>,
T2: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Sandwich1WithOptUnion>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Sandwich1WithOptUnion>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
impl FromWire<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
Sourcefn from_wire(wire: Sandwich1WithOptUnion) -> Self
fn from_wire(wire: Sandwich1WithOptUnion) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
impl FromWireRef<Sandwich1WithOptUnion> for Sandwich1WithOptUnion
Sourcefn from_wire_ref(wire: &Sandwich1WithOptUnion) -> Self
fn from_wire_ref(wire: &Sandwich1WithOptUnion) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for Sandwich1WithOptUnion
impl IntoNatural for Sandwich1WithOptUnion
Sourcetype Natural = Sandwich1WithOptUnion
type Natural = Sandwich1WithOptUnion
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Sandwich1WithOptUnion
impl Wire for Sandwich1WithOptUnion
Sourcetype Narrowed<'de> = Sandwich1WithOptUnion
type Narrowed<'de> = Sandwich1WithOptUnion
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.