#[repr(C)]pub struct Size8Align8 {
pub data: Uint64,
}Expand description
The wire type corresponding to Size8Align8.
Fields
data: Uint64Trait Implementations
Sourceimpl Clone for Size8Align8
impl Clone for Size8Align8
Sourcefn clone(&self) -> Size8Align8
fn clone(&self) -> Size8Align8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Size8Align8
impl Constrained for Size8Align8
Sourceimpl Debug for Size8Align8
impl Debug for Size8Align8
Sourceimpl<___D> Decode<___D> for Size8Align8where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Size8Align8where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Size8Align8, ___E> for &'a Size8Align8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Size8Align8, ___E> for &'a Size8Align8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size8Align8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size8Align8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Size8Align8, ___E> for Size8Align8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Size8Align8, ___E> for Size8Align8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, Size8Align8>
const COPY_OPTIMIZATION: CopyOptimization<Self, Size8Align8>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size8Align8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size8Align8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<Size8Align8, ___E> for Size8Align8<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<Size8Align8, ___E> for Size8Align8<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Size8Align8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Size8Align8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Size8Align8> for Size8Align8
impl FromWire<Size8Align8> for Size8Align8
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Size8Align8, Self>
const COPY_OPTIMIZATION: CopyOptimization<Size8Align8, Self>
Sourcefn from_wire(wire: Size8Align8) -> Self
fn from_wire(wire: Size8Align8) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<Size8Align8> for Size8Align8
impl FromWireRef<Size8Align8> for Size8Align8
Sourcefn from_wire_ref(wire: &Size8Align8) -> Self
fn from_wire_ref(wire: &Size8Align8) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for Size8Align8
impl IntoNatural for Size8Align8
Sourcetype Natural = Size8Align8
type Natural = Size8Align8
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Size8Align8
impl Wire for Size8Align8
Sourcetype Narrowed<'de> = Size8Align8
type Narrowed<'de> = Size8Align8
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.