#[repr(C)]pub struct StrictBitsUint16Struct {
pub b: StrictBitsUint16,
}Expand description
The wire type corresponding to StrictBitsUint16Struct.
Fields
b: StrictBitsUint16Trait Implementations
Sourceimpl Clone for StrictBitsUint16Struct
impl Clone for StrictBitsUint16Struct
Sourcefn clone(&self) -> StrictBitsUint16Struct
fn clone(&self) -> StrictBitsUint16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictBitsUint16Struct
impl Constrained for StrictBitsUint16Struct
Sourceimpl Debug for StrictBitsUint16Struct
impl Debug for StrictBitsUint16Struct
Sourceimpl<___D> Decode<___D> for StrictBitsUint16Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictBitsUint16Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictBitsUint16Struct, ___E> for &'a StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint16Struct, ___E> for &'a StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint16, ___E>,
impl<___E, T0> Encode<StrictBitsUint16Struct, ___E> for StrictBitsUint16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl FromWire<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint16Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint16Struct, Self>
Sourcefn from_wire(wire: StrictBitsUint16Struct) -> Self
fn from_wire(wire: StrictBitsUint16Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint16Struct> for StrictBitsUint16Struct
impl FromWireRef<StrictBitsUint16Struct> for StrictBitsUint16Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint16Struct) -> Self
fn from_wire_ref(wire: &StrictBitsUint16Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictBitsUint16Struct
impl IntoNatural for StrictBitsUint16Struct
Sourcetype Natural = StrictBitsUint16Struct
type Natural = StrictBitsUint16Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictBitsUint16Struct
impl Wire for StrictBitsUint16Struct
Sourcetype Narrowed<'de> = StrictBitsUint16Struct
type Narrowed<'de> = StrictBitsUint16Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.