#[repr(C)]pub struct StrictBitsUint32Struct {
pub b: StrictBitsUint32,
}Expand description
The wire type corresponding to StrictBitsUint32Struct.
Fields
b: StrictBitsUint32Trait Implementations
Sourceimpl Clone for StrictBitsUint32Struct
impl Clone for StrictBitsUint32Struct
Sourcefn clone(&self) -> StrictBitsUint32Struct
fn clone(&self) -> StrictBitsUint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictBitsUint32Struct
impl Constrained for StrictBitsUint32Struct
Sourceimpl Debug for StrictBitsUint32Struct
impl Debug for StrictBitsUint32Struct
Sourceimpl<___D> Decode<___D> for StrictBitsUint32Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictBitsUint32Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictBitsUint32Struct, ___E> for &'a StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictBitsUint32Struct, ___E> for &'a StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictBitsUint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint32, ___E>,
impl<___E, T0> Encode<StrictBitsUint32Struct, ___E> for StrictBitsUint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictBitsUint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictBitsUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictBitsUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl FromWire<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint32Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictBitsUint32Struct, Self>
Sourcefn from_wire(wire: StrictBitsUint32Struct) -> Self
fn from_wire(wire: StrictBitsUint32Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictBitsUint32Struct> for StrictBitsUint32Struct
impl FromWireRef<StrictBitsUint32Struct> for StrictBitsUint32Struct
Sourcefn from_wire_ref(wire: &StrictBitsUint32Struct) -> Self
fn from_wire_ref(wire: &StrictBitsUint32Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictBitsUint32Struct
impl IntoNatural for StrictBitsUint32Struct
Sourcetype Natural = StrictBitsUint32Struct
type Natural = StrictBitsUint32Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictBitsUint32Struct
impl Wire for StrictBitsUint32Struct
Sourcetype Narrowed<'de> = StrictBitsUint32Struct
type Narrowed<'de> = StrictBitsUint32Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.