#[repr(C)]pub struct StrictEnumInt16Struct {
pub e: StrictEnumInt16,
}Expand description
The wire type corresponding to StrictEnumInt16Struct.
Fields
e: StrictEnumInt16Trait Implementations
Sourceimpl Clone for StrictEnumInt16Struct
impl Clone for StrictEnumInt16Struct
Sourcefn clone(&self) -> StrictEnumInt16Struct
fn clone(&self) -> StrictEnumInt16Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumInt16Struct
impl Constrained for StrictEnumInt16Struct
Sourceimpl Debug for StrictEnumInt16Struct
impl Debug for StrictEnumInt16Struct
Sourceimpl<___D> Decode<___D> for StrictEnumInt16Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumInt16Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumInt16Struct, ___E> for &'a StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt16Struct, ___E> for &'a StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt16Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt16Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt16, ___E>,
impl<___E, T0> Encode<StrictEnumInt16Struct, ___E> for StrictEnumInt16Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt16, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt16Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt16Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumInt16Struct> for StrictEnumInt16Struct
impl FromWire<StrictEnumInt16Struct> for StrictEnumInt16Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt16Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt16Struct) -> Self
fn from_wire(wire: StrictEnumInt16Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt16Struct> for StrictEnumInt16Struct
impl FromWireRef<StrictEnumInt16Struct> for StrictEnumInt16Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt16Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt16Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumInt16Struct
impl IntoNatural for StrictEnumInt16Struct
Sourcetype Natural = StrictEnumInt16Struct
type Natural = StrictEnumInt16Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumInt16Struct
impl Wire for StrictEnumInt16Struct
Sourcetype Narrowed<'de> = StrictEnumInt16Struct
type Narrowed<'de> = StrictEnumInt16Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.