#[repr(C)]pub struct StrictEnumInt32Struct {
pub e: StrictEnumInt32,
}Expand description
The wire type corresponding to StrictEnumInt32Struct.
Fields
e: StrictEnumInt32Trait Implementations
Sourceimpl Clone for StrictEnumInt32Struct
impl Clone for StrictEnumInt32Struct
Sourcefn clone(&self) -> StrictEnumInt32Struct
fn clone(&self) -> StrictEnumInt32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumInt32Struct
impl Constrained for StrictEnumInt32Struct
Sourceimpl Debug for StrictEnumInt32Struct
impl Debug for StrictEnumInt32Struct
Sourceimpl<___D> Decode<___D> for StrictEnumInt32Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumInt32Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumInt32Struct, ___E> for &'a StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt32Struct, ___E> for &'a StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt32, ___E>,
impl<___E, T0> Encode<StrictEnumInt32Struct, ___E> for StrictEnumInt32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl FromWire<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt32Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt32Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt32Struct) -> Self
fn from_wire(wire: StrictEnumInt32Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt32Struct> for StrictEnumInt32Struct
impl FromWireRef<StrictEnumInt32Struct> for StrictEnumInt32Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt32Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt32Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumInt32Struct
impl IntoNatural for StrictEnumInt32Struct
Sourcetype Natural = StrictEnumInt32Struct
type Natural = StrictEnumInt32Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumInt32Struct
impl Wire for StrictEnumInt32Struct
Sourcetype Narrowed<'de> = StrictEnumInt32Struct
type Narrowed<'de> = StrictEnumInt32Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.