#[repr(C)]pub struct StrictEnumInt64Struct {
pub e: StrictEnumInt64,
}Expand description
The wire type corresponding to StrictEnumInt64Struct.
Fields
e: StrictEnumInt64Trait Implementations
Sourceimpl Clone for StrictEnumInt64Struct
impl Clone for StrictEnumInt64Struct
Sourcefn clone(&self) -> StrictEnumInt64Struct
fn clone(&self) -> StrictEnumInt64Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumInt64Struct
impl Constrained for StrictEnumInt64Struct
Sourceimpl Debug for StrictEnumInt64Struct
impl Debug for StrictEnumInt64Struct
Sourceimpl<___D> Decode<___D> for StrictEnumInt64Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumInt64Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumInt64Struct, ___E> for &'a StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumInt64Struct, ___E> for &'a StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt64Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumInt64Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt64, ___E>,
impl<___E, T0> Encode<StrictEnumInt64Struct, ___E> for StrictEnumInt64Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumInt64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumInt64Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumInt64Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl FromWire<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt64Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumInt64Struct, Self>
Sourcefn from_wire(wire: StrictEnumInt64Struct) -> Self
fn from_wire(wire: StrictEnumInt64Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumInt64Struct> for StrictEnumInt64Struct
impl FromWireRef<StrictEnumInt64Struct> for StrictEnumInt64Struct
Sourcefn from_wire_ref(wire: &StrictEnumInt64Struct) -> Self
fn from_wire_ref(wire: &StrictEnumInt64Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumInt64Struct
impl IntoNatural for StrictEnumInt64Struct
Sourcetype Natural = StrictEnumInt64Struct
type Natural = StrictEnumInt64Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumInt64Struct
impl Wire for StrictEnumInt64Struct
Sourcetype Narrowed<'de> = StrictEnumInt64Struct
type Narrowed<'de> = StrictEnumInt64Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.