#[repr(C)]pub struct StrictEnumUint32Struct {
pub e: StrictEnumUint32,
}Expand description
The wire type corresponding to StrictEnumUint32Struct.
Fields
e: StrictEnumUint32Trait Implementations
Sourceimpl Clone for StrictEnumUint32Struct
impl Clone for StrictEnumUint32Struct
Sourcefn clone(&self) -> StrictEnumUint32Struct
fn clone(&self) -> StrictEnumUint32Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumUint32Struct
impl Constrained for StrictEnumUint32Struct
Sourceimpl Debug for StrictEnumUint32Struct
impl Debug for StrictEnumUint32Struct
Sourceimpl<___D> Decode<___D> for StrictEnumUint32Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumUint32Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumUint32Struct, ___E> for &'a StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint32Struct, ___E> for &'a StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumUint32Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumUint32Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint32, ___E>,
impl<___E, T0> Encode<StrictEnumUint32Struct, ___E> for StrictEnumUint32Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint32Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint32Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumUint32Struct> for StrictEnumUint32Struct
impl FromWire<StrictEnumUint32Struct> for StrictEnumUint32Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint32Struct, Self>
Sourcefn from_wire(wire: StrictEnumUint32Struct) -> Self
fn from_wire(wire: StrictEnumUint32Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint32Struct> for StrictEnumUint32Struct
impl FromWireRef<StrictEnumUint32Struct> for StrictEnumUint32Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint32Struct) -> Self
fn from_wire_ref(wire: &StrictEnumUint32Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumUint32Struct
impl IntoNatural for StrictEnumUint32Struct
Sourcetype Natural = StrictEnumUint32Struct
type Natural = StrictEnumUint32Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumUint32Struct
impl Wire for StrictEnumUint32Struct
Sourcetype Narrowed<'de> = StrictEnumUint32Struct
type Narrowed<'de> = StrictEnumUint32Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.