#[repr(C)]pub struct StrictEnumUint8Struct {
pub e: StrictEnumUint8,
}Expand description
The wire type corresponding to StrictEnumUint8Struct.
Fields
e: StrictEnumUint8Trait Implementations
Sourceimpl Clone for StrictEnumUint8Struct
impl Clone for StrictEnumUint8Struct
Sourcefn clone(&self) -> StrictEnumUint8Struct
fn clone(&self) -> StrictEnumUint8Struct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for StrictEnumUint8Struct
impl Constrained for StrictEnumUint8Struct
Sourceimpl Debug for StrictEnumUint8Struct
impl Debug for StrictEnumUint8Struct
Sourceimpl<___D> Decode<___D> for StrictEnumUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for StrictEnumUint8Structwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<StrictEnumUint8Struct, ___E> for &'a StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<StrictEnumUint8Struct, ___E> for &'a StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Structwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumUint8Struct>
const COPY_OPTIMIZATION: CopyOptimization<Self, StrictEnumUint8Struct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint8, ___E>,
impl<___E, T0> Encode<StrictEnumUint8Struct, ___E> for StrictEnumUint8Struct<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<StrictEnumUint8, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StrictEnumUint8Struct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StrictEnumUint8Struct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<StrictEnumUint8Struct> for StrictEnumUint8Struct
impl FromWire<StrictEnumUint8Struct> for StrictEnumUint8Struct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, Self>
const COPY_OPTIMIZATION: CopyOptimization<StrictEnumUint8Struct, Self>
Sourcefn from_wire(wire: StrictEnumUint8Struct) -> Self
fn from_wire(wire: StrictEnumUint8Struct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<StrictEnumUint8Struct> for StrictEnumUint8Struct
impl FromWireRef<StrictEnumUint8Struct> for StrictEnumUint8Struct
Sourcefn from_wire_ref(wire: &StrictEnumUint8Struct) -> Self
fn from_wire_ref(wire: &StrictEnumUint8Struct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for StrictEnumUint8Struct
impl IntoNatural for StrictEnumUint8Struct
Sourcetype Natural = StrictEnumUint8Struct
type Natural = StrictEnumUint8Struct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StrictEnumUint8Struct
impl Wire for StrictEnumUint8Struct
Sourcetype Narrowed<'de> = StrictEnumUint8Struct
type Narrowed<'de> = StrictEnumUint8Struct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.