#[repr(C)]pub struct Struct7Byte {
pub a: Int32,
pub b: Int16,
pub c: i8,
}Expand description
The wire type corresponding to Struct7Byte.
Fields
a: Int32b: Int16c: i8Trait Implementations
Sourceimpl Clone for Struct7Byte
impl Clone for Struct7Byte
Sourcefn clone(&self) -> Struct7Byte
fn clone(&self) -> Struct7Byte
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Struct7Byte
impl Constrained for Struct7Byte
Sourceimpl Debug for Struct7Byte
impl Debug for Struct7Byte
Sourceimpl<___D> Decode<___D> for Struct7Bytewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Struct7Bytewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Struct7Byte, ___E> for &'a Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Struct7Byte, ___E> for &'a Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct7Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct7Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Struct7Byte, ___E> for Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Struct7Byte, ___E> for Struct7Bytewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct7Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct7Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2> Encode<Struct7Byte, ___E> for Struct7Byte<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<Struct7Byte, ___E> for Struct7Byte<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Struct7Byte>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Struct7Byte>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Struct7Byte> for Struct7Byte
impl FromWire<Struct7Byte> for Struct7Byte
Sourcefn from_wire(wire: Struct7Byte) -> Self
fn from_wire(wire: Struct7Byte) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Struct7Byte> for Struct7Byte
impl FromWireRef<Struct7Byte> for Struct7Byte
Sourcefn from_wire_ref(wire: &Struct7Byte) -> Self
fn from_wire_ref(wire: &Struct7Byte) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for Struct7Byte
impl IntoNatural for Struct7Byte
Sourcetype Natural = Struct7Byte
type Natural = Struct7Byte
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Struct7Byte
impl Wire for Struct7Byte
Sourcetype Narrowed<'de> = Struct7Byte
type Narrowed<'de> = Struct7Byte
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.