#[repr(C)]pub struct StructWithOptionals<'de> {
pub s: EmptyStruct,
pub s2: Box<'de, EmptyStruct>,
pub t: TableWithEmptyStruct<'de>,
pub xu: XUnionWithEmptyStruct<'de>,
pub xu2: XUnionWithEmptyStruct<'de>,
pub u: UnionWithEmptyStruct<'de>,
pub u2: UnionWithEmptyStruct<'de>,
}Expand description
The wire type corresponding to StructWithOptionals.
Fields
s: EmptyStructs2: Box<'de, EmptyStruct>t: TableWithEmptyStruct<'de>xu: XUnionWithEmptyStruct<'de>xu2: XUnionWithEmptyStruct<'de>u: UnionWithEmptyStruct<'de>u2: UnionWithEmptyStruct<'de>Trait Implementations
Sourceimpl Constrained for StructWithOptionals<'_>
impl Constrained for StructWithOptionals<'_>
Sourceimpl<'de> Debug for StructWithOptionals<'de>
impl<'de> Debug for StructWithOptionals<'de>
Sourceimpl<'de, ___D> Decode<___D> for StructWithOptionals<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
impl<'de, ___D> Decode<___D> for StructWithOptionals<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
Sourceimpl<'a, ___E> Encode<StructWithOptionals<'static>, ___E> for &'a StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<StructWithOptionals<'static>, ___E> for &'a StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithOptionals<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithOptionals<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionalswhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithOptionals<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithOptionals<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionals<T0, T1, T2, T3, T4, T5, T6>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<EmptyStruct, ___E>,
T1: Encode<Box<'static, EmptyStruct>, ___E>,
T2: Encode<TableWithEmptyStruct<'static>, ___E>,
T3: Encode<XUnionWithEmptyStruct<'static>, ___E>,
T4: Encode<XUnionWithEmptyStruct<'static>, ___E>,
T5: Encode<UnionWithEmptyStruct<'static>, ___E>,
T6: Encode<UnionWithEmptyStruct<'static>, ___E>,
impl<___E, T0, T1, T2, T3, T4, T5, T6> Encode<StructWithOptionals<'static>, ___E> for StructWithOptionals<T0, T1, T2, T3, T4, T5, T6>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<EmptyStruct, ___E>,
T1: Encode<Box<'static, EmptyStruct>, ___E>,
T2: Encode<TableWithEmptyStruct<'static>, ___E>,
T3: Encode<XUnionWithEmptyStruct<'static>, ___E>,
T4: Encode<XUnionWithEmptyStruct<'static>, ___E>,
T5: Encode<UnionWithEmptyStruct<'static>, ___E>,
T6: Encode<UnionWithEmptyStruct<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<StructWithOptionals<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<StructWithOptionals<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<StructWithOptionals<'de>> for StructWithOptionals
impl<'de> FromWire<StructWithOptionals<'de>> for StructWithOptionals
Sourcefn from_wire(wire: StructWithOptionals<'de>) -> Self
fn from_wire(wire: StructWithOptionals<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<StructWithOptionals<'de>> for StructWithOptionals
impl<'de> FromWireRef<StructWithOptionals<'de>> for StructWithOptionals
Sourcefn from_wire_ref(wire: &StructWithOptionals<'de>) -> Self
fn from_wire_ref(wire: &StructWithOptionals<'de>) -> Self
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for StructWithOptionals<'de>
impl<'de> IntoNatural for StructWithOptionals<'de>
Sourcetype Natural = StructWithOptionals
type Natural = StructWithOptionals
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for StructWithOptionals<'static>
impl Wire for StructWithOptionals<'static>
Sourcetype Narrowed<'de> = StructWithOptionals<'de>
type Narrowed<'de> = StructWithOptionals<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.