#[repr(C)]pub struct ThreeByteInArray {
pub elems: [ThreeByte; 3],
}Expand description
The wire type corresponding to ThreeByteInArray.
Fields
elems: [ThreeByte; 3]Trait Implementations
Sourceimpl Clone for ThreeByteInArray
impl Clone for ThreeByteInArray
Sourcefn clone(&self) -> ThreeByteInArray
fn clone(&self) -> ThreeByteInArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ThreeByteInArray
impl Constrained for ThreeByteInArray
Sourceimpl Debug for ThreeByteInArray
impl Debug for ThreeByteInArray
Sourceimpl<___D> Decode<___D> for ThreeByteInArraywhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ThreeByteInArraywhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ThreeByteInArray, ___E> for &'a ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ThreeByteInArray, ___E> for &'a ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ThreeByteInArray, ___E> for ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ThreeByteInArray, ___E> for ThreeByteInArraywhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ThreeByteInArray>
const COPY_OPTIMIZATION: CopyOptimization<Self, ThreeByteInArray>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ThreeByteInArray, ___E> for ThreeByteInArray<T0>
impl<___E, T0> Encode<ThreeByteInArray, ___E> for ThreeByteInArray<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInArray>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInArray>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ThreeByteInArray> for ThreeByteInArray
impl FromWire<ThreeByteInArray> for ThreeByteInArray
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, Self>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInArray, Self>
Sourcefn from_wire(wire: ThreeByteInArray) -> Self
fn from_wire(wire: ThreeByteInArray) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ThreeByteInArray> for ThreeByteInArray
impl FromWireRef<ThreeByteInArray> for ThreeByteInArray
Sourcefn from_wire_ref(wire: &ThreeByteInArray) -> Self
fn from_wire_ref(wire: &ThreeByteInArray) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ThreeByteInArray
impl IntoNatural for ThreeByteInArray
Sourcetype Natural = ThreeByteInArray
type Natural = ThreeByteInArray
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ThreeByteInArray
impl Wire for ThreeByteInArray
Sourcetype Narrowed<'de> = ThreeByteInArray
type Narrowed<'de> = ThreeByteInArray
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.