#[repr(C)]pub struct ThreeByteInStruct {
pub elem1: ThreeByte,
pub elem2: ThreeByte,
pub elem3: ThreeByte,
}Expand description
The wire type corresponding to ThreeByteInStruct.
Fields
elem1: ThreeByteelem2: ThreeByteelem3: ThreeByteTrait Implementations
Sourceimpl Clone for ThreeByteInStruct
impl Clone for ThreeByteInStruct
Sourcefn clone(&self) -> ThreeByteInStruct
fn clone(&self) -> ThreeByteInStruct
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ThreeByteInStruct
impl Constrained for ThreeByteInStruct
Sourceimpl Debug for ThreeByteInStruct
impl Debug for ThreeByteInStruct
Sourceimpl<___D> Decode<___D> for ThreeByteInStructwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ThreeByteInStructwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ThreeByteInStruct, ___E> for &'a ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ThreeByteInStruct, ___E> for &'a ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ThreeByteInStruct, ___E> for ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ThreeByteInStruct, ___E> for ThreeByteInStructwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ThreeByteInStruct>
const COPY_OPTIMIZATION: CopyOptimization<Self, ThreeByteInStruct>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2> Encode<ThreeByteInStruct, ___E> for ThreeByteInStruct<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<ThreeByteInStruct, ___E> for ThreeByteInStruct<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ThreeByteInStruct>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ThreeByteInStruct>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ThreeByteInStruct> for ThreeByteInStruct
impl FromWire<ThreeByteInStruct> for ThreeByteInStruct
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, Self>
const COPY_OPTIMIZATION: CopyOptimization<ThreeByteInStruct, Self>
Sourcefn from_wire(wire: ThreeByteInStruct) -> Self
fn from_wire(wire: ThreeByteInStruct) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ThreeByteInStruct> for ThreeByteInStruct
impl FromWireRef<ThreeByteInStruct> for ThreeByteInStruct
Sourcefn from_wire_ref(wire: &ThreeByteInStruct) -> Self
fn from_wire_ref(wire: &ThreeByteInStruct) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ThreeByteInStruct
impl IntoNatural for ThreeByteInStruct
Sourcetype Natural = ThreeByteInStruct
type Natural = ThreeByteInStruct
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ThreeByteInStruct
impl Wire for ThreeByteInStruct
Sourcetype Narrowed<'de> = ThreeByteInStruct
type Narrowed<'de> = ThreeByteInStruct
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.