#[repr(C)]pub struct TransactionHeader {
pub tx_id: Uint32,
pub flags: [u8; 3],
pub magic_number: u8,
pub ordinal: Uint64,
}Expand description
The wire type corresponding to TransactionHeader.
Fields
tx_id: Uint32flags: [u8; 3]magic_number: u8ordinal: Uint64Trait Implementations
Sourceimpl Clone for TransactionHeader
impl Clone for TransactionHeader
Sourcefn clone(&self) -> TransactionHeader
fn clone(&self) -> TransactionHeader
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TransactionHeader
impl Constrained for TransactionHeader
Sourceimpl Debug for TransactionHeader
impl Debug for TransactionHeader
Sourceimpl<___D> Decode<___D> for TransactionHeaderwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TransactionHeaderwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TransactionHeader, ___E> for &'a TransactionHeaderwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TransactionHeader, ___E> for &'a TransactionHeaderwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TransactionHeader>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TransactionHeader>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TransactionHeader, ___E> for TransactionHeaderwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TransactionHeader, ___E> for TransactionHeaderwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, TransactionHeader>
const COPY_OPTIMIZATION: CopyOptimization<Self, TransactionHeader>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TransactionHeader>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TransactionHeader>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2, T3> Encode<TransactionHeader, ___E> for TransactionHeader<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<TransactionHeader, ___E> for TransactionHeader<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TransactionHeader>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TransactionHeader>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TransactionHeader> for TransactionHeader
impl FromWire<TransactionHeader> for TransactionHeader
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TransactionHeader, Self>
const COPY_OPTIMIZATION: CopyOptimization<TransactionHeader, Self>
Sourcefn from_wire(wire: TransactionHeader) -> Self
fn from_wire(wire: TransactionHeader) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<TransactionHeader> for TransactionHeader
impl FromWireRef<TransactionHeader> for TransactionHeader
Sourcefn from_wire_ref(wire: &TransactionHeader) -> Self
fn from_wire_ref(wire: &TransactionHeader) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for TransactionHeader
impl IntoNatural for TransactionHeader
Sourcetype Natural = TransactionHeader
type Natural = TransactionHeader
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TransactionHeader
impl Wire for TransactionHeader
Sourcetype Narrowed<'de> = TransactionHeader
type Narrowed<'de> = TransactionHeader
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.