#[repr(C)]pub struct TwoLayerStructInnerPaddingAlign4 {
pub s: OneLayerStructWithPaddingAlign4,
pub a: Uint32,
}Expand description
The wire type corresponding to TwoLayerStructInnerPaddingAlign4.
Fields
s: OneLayerStructWithPaddingAlign4a: Uint32Trait Implementations
Sourceimpl Clone for TwoLayerStructInnerPaddingAlign4
impl Clone for TwoLayerStructInnerPaddingAlign4
Sourcefn clone(&self) -> TwoLayerStructInnerPaddingAlign4
fn clone(&self) -> TwoLayerStructInnerPaddingAlign4
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TwoLayerStructInnerPaddingAlign4
impl Constrained for TwoLayerStructInnerPaddingAlign4
Sourceimpl<___D> Decode<___D> for TwoLayerStructInnerPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TwoLayerStructInnerPaddingAlign4where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for &'a TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithPaddingAlign4, ___E>,
T1: Encode<Uint32, ___E>,
impl<___E, T0, T1> Encode<TwoLayerStructInnerPaddingAlign4, ___E> for TwoLayerStructInnerPaddingAlign4<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithPaddingAlign4, ___E>,
T1: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign4>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl FromWire<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn from_wire(wire: TwoLayerStructInnerPaddingAlign4) -> Self
fn from_wire(wire: TwoLayerStructInnerPaddingAlign4) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
impl FromWireRef<TwoLayerStructInnerPaddingAlign4> for TwoLayerStructInnerPaddingAlign4
Sourcefn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign4) -> Self
fn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign4) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for TwoLayerStructInnerPaddingAlign4
impl IntoNatural for TwoLayerStructInnerPaddingAlign4
Sourcetype Natural = TwoLayerStructInnerPaddingAlign4
type Natural = TwoLayerStructInnerPaddingAlign4
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TwoLayerStructInnerPaddingAlign4
impl Wire for TwoLayerStructInnerPaddingAlign4
Sourcetype Narrowed<'de> = TwoLayerStructInnerPaddingAlign4
type Narrowed<'de> = TwoLayerStructInnerPaddingAlign4
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.