#[repr(C)]pub struct TwoLayerStructInnerPaddingAlign8 {
pub s: OneLayerStructWithPaddingAlign8,
pub a: Uint64,
}Expand description
The wire type corresponding to TwoLayerStructInnerPaddingAlign8.
Fields
s: OneLayerStructWithPaddingAlign8a: Uint64Trait Implementations
Sourceimpl Clone for TwoLayerStructInnerPaddingAlign8
impl Clone for TwoLayerStructInnerPaddingAlign8
Sourcefn clone(&self) -> TwoLayerStructInnerPaddingAlign8
fn clone(&self) -> TwoLayerStructInnerPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TwoLayerStructInnerPaddingAlign8
impl Constrained for TwoLayerStructInnerPaddingAlign8
Sourceimpl<___D> Decode<___D> for TwoLayerStructInnerPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TwoLayerStructInnerPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for &'a TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithPaddingAlign8, ___E>,
T1: Encode<Uint64, ___E>,
impl<___E, T0, T1> Encode<TwoLayerStructInnerPaddingAlign8, ___E> for TwoLayerStructInnerPaddingAlign8<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructWithPaddingAlign8, ___E>,
T1: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructInnerPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl FromWire<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn from_wire(wire: TwoLayerStructInnerPaddingAlign8) -> Self
fn from_wire(wire: TwoLayerStructInnerPaddingAlign8) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
impl FromWireRef<TwoLayerStructInnerPaddingAlign8> for TwoLayerStructInnerPaddingAlign8
Sourcefn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign8) -> Self
fn from_wire_ref(wire: &TwoLayerStructInnerPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for TwoLayerStructInnerPaddingAlign8
impl IntoNatural for TwoLayerStructInnerPaddingAlign8
Sourcetype Natural = TwoLayerStructInnerPaddingAlign8
type Natural = TwoLayerStructInnerPaddingAlign8
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TwoLayerStructInnerPaddingAlign8
impl Wire for TwoLayerStructInnerPaddingAlign8
Sourcetype Narrowed<'de> = TwoLayerStructInnerPaddingAlign8
type Narrowed<'de> = TwoLayerStructInnerPaddingAlign8
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.