#[repr(C)]pub struct TwoLayerStructNoPaddingAlign8 {
pub s: OneLayerStructNoPaddingAlign8,
pub a: Uint64,
}Expand description
The wire type corresponding to TwoLayerStructNoPaddingAlign8.
Fields
s: OneLayerStructNoPaddingAlign8a: Uint64Trait Implementations
Sourceimpl Clone for TwoLayerStructNoPaddingAlign8
impl Clone for TwoLayerStructNoPaddingAlign8
Sourcefn clone(&self) -> TwoLayerStructNoPaddingAlign8
fn clone(&self) -> TwoLayerStructNoPaddingAlign8
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for TwoLayerStructNoPaddingAlign8
impl Constrained for TwoLayerStructNoPaddingAlign8
Sourceimpl<___D> Decode<___D> for TwoLayerStructNoPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for TwoLayerStructNoPaddingAlign8where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for &'a TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8where
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, TwoLayerStructNoPaddingAlign8>
const COPY_OPTIMIZATION: CopyOptimization<Self, TwoLayerStructNoPaddingAlign8>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructNoPaddingAlign8, ___E>,
T1: Encode<Uint64, ___E>,
impl<___E, T0, T1> Encode<TwoLayerStructNoPaddingAlign8, ___E> for TwoLayerStructNoPaddingAlign8<T0, T1>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<OneLayerStructNoPaddingAlign8, ___E>,
T1: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TwoLayerStructNoPaddingAlign8>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
impl FromWire<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
Sourceconst COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, Self>
const COPY_OPTIMIZATION: CopyOptimization<TwoLayerStructNoPaddingAlign8, Self>
Sourcefn from_wire(wire: TwoLayerStructNoPaddingAlign8) -> Self
fn from_wire(wire: TwoLayerStructNoPaddingAlign8) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
impl FromWireRef<TwoLayerStructNoPaddingAlign8> for TwoLayerStructNoPaddingAlign8
Sourcefn from_wire_ref(wire: &TwoLayerStructNoPaddingAlign8) -> Self
fn from_wire_ref(wire: &TwoLayerStructNoPaddingAlign8) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for TwoLayerStructNoPaddingAlign8
impl IntoNatural for TwoLayerStructNoPaddingAlign8
Sourcetype Natural = TwoLayerStructNoPaddingAlign8
type Natural = TwoLayerStructNoPaddingAlign8
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for TwoLayerStructNoPaddingAlign8
impl Wire for TwoLayerStructNoPaddingAlign8
Sourcetype Narrowed<'de> = TwoLayerStructNoPaddingAlign8
type Narrowed<'de> = TwoLayerStructNoPaddingAlign8
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.