#[repr(C)]pub struct Uint8Uint16Uint32Uint64 {
pub f1: u8,
pub f2: Uint16,
pub f3: Uint32,
pub f4: Uint64,
}Expand description
The wire type corresponding to Uint8Uint16Uint32Uint64.
Fields
f1: u8f2: Uint16f3: Uint32f4: Uint64Trait Implementations
Sourceimpl Clone for Uint8Uint16Uint32Uint64
impl Clone for Uint8Uint16Uint32Uint64
Sourcefn clone(&self) -> Uint8Uint16Uint32Uint64
fn clone(&self) -> Uint8Uint16Uint32Uint64
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for Uint8Uint16Uint32Uint64
impl Constrained for Uint8Uint16Uint32Uint64
Sourceimpl Debug for Uint8Uint16Uint32Uint64
impl Debug for Uint8Uint16Uint32Uint64
Sourceimpl<___D> Decode<___D> for Uint8Uint16Uint32Uint64where
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for Uint8Uint16Uint32Uint64where
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<Uint8Uint16Uint32Uint64, ___E> for &'a Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<Uint8Uint16Uint32Uint64, ___E> for &'a Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64where
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0, T1, T2, T3> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64<T0, T1, T2, T3>
impl<___E, T0, T1, T2, T3> Encode<Uint8Uint16Uint32Uint64, ___E> for Uint8Uint16Uint32Uint64<T0, T1, T2, T3>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<Uint8Uint16Uint32Uint64>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
impl FromWire<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
Sourcefn from_wire(wire: Uint8Uint16Uint32Uint64) -> Self
fn from_wire(wire: Uint8Uint16Uint32Uint64) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
impl FromWireRef<Uint8Uint16Uint32Uint64> for Uint8Uint16Uint32Uint64
Sourcefn from_wire_ref(wire: &Uint8Uint16Uint32Uint64) -> Self
fn from_wire_ref(wire: &Uint8Uint16Uint32Uint64) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for Uint8Uint16Uint32Uint64
impl IntoNatural for Uint8Uint16Uint32Uint64
Sourcetype Natural = Uint8Uint16Uint32Uint64
type Natural = Uint8Uint16Uint32Uint64
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for Uint8Uint16Uint32Uint64
impl Wire for Uint8Uint16Uint32Uint64
Sourcetype Narrowed<'de> = Uint8Uint16Uint32Uint64
type Narrowed<'de> = Uint8Uint16Uint32Uint64
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.