#[repr(C)]pub struct VectorWithLimitInTable<'de> {
pub t: TableWithVectorWithLimit<'de>,
}Expand description
The wire type corresponding to VectorWithLimitInTable.
Fields
t: TableWithVectorWithLimit<'de>Trait Implementations
Sourceimpl Constrained for VectorWithLimitInTable<'_>
impl Constrained for VectorWithLimitInTable<'_>
Sourceimpl<'de> Debug for VectorWithLimitInTable<'de>
impl<'de> Debug for VectorWithLimitInTable<'de>
Sourceimpl<'de, ___D> Decode<___D> for VectorWithLimitInTable<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
impl<'de, ___D> Decode<___D> for VectorWithLimitInTable<'de>where
___D: InternalHandleDecoder + ?Sized + Decoder<'de>,
Sourceimpl<'a, ___E> Encode<VectorWithLimitInTable<'static>, ___E> for &'a VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<VectorWithLimitInTable<'static>, ___E> for &'a VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTablewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTable<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<TableWithVectorWithLimit<'static>, ___E>,
impl<___E, T0> Encode<VectorWithLimitInTable<'static>, ___E> for VectorWithLimitInTable<T0>where
___E: InternalHandleEncoder + ?Sized + Encoder,
T0: Encode<TableWithVectorWithLimit<'static>, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<VectorWithLimitInTable<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
impl<'de> FromWire<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
Sourcefn from_wire(wire: VectorWithLimitInTable<'de>) -> Self
fn from_wire(wire: VectorWithLimitInTable<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
impl<'de> FromWireRef<VectorWithLimitInTable<'de>> for VectorWithLimitInTable
Sourcefn from_wire_ref(wire: &VectorWithLimitInTable<'de>) -> Self
fn from_wire_ref(wire: &VectorWithLimitInTable<'de>) -> Self
Converts the given reference to this type.
Sourceimpl<'de> IntoNatural for VectorWithLimitInTable<'de>
impl<'de> IntoNatural for VectorWithLimitInTable<'de>
Sourcetype Natural = VectorWithLimitInTable
type Natural = VectorWithLimitInTable
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for VectorWithLimitInTable<'static>
impl Wire for VectorWithLimitInTable<'static>
Sourcetype Narrowed<'de> = VectorWithLimitInTable<'de>
type Narrowed<'de> = VectorWithLimitInTable<'de>
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.